(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    199325,       6342]*)
(*NotebookOutlinePosition[    199961,       6365]*)
(*  CellTagsIndexPosition[    199917,       6361]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\( (*\ Producing\ data\ file\ with\ format\ x\ y\ \ *) \n
    Clear[Putdata]; \n
    Putdata[plotdata__, filename_] := \ 
      Module[{x, y, NDATA, ALLDATA, datastr, i}, \n\ \ Clear[x]; \n\ \ 
        Clear[y]; \n\ \ Clear[NDATA]; \n\ \ Clear[ALLDATA]; \n\ \ 
        Clear[datastr]; \n\ \ ALLDATA\  = \ plotdata[\([1, 1, 1, 1]\)]; \n\ \ 
        NDATA\  = \ Length[ALLDATA]; \n\ \ \ \ \ \ \ \ 
        Put[OutputForm["\<##############\>"], filename]; \n\ \ 
        PutAppend[OutputForm["\<# For gnuplot \>"], filename]; \n\ \ 
        PutAppend[OutputForm["\<##############\>"], filename]; \n\ \ 
        Do[\n\ \ \ x\  = \ \(ALLDATA[\([i]\)]\)[\([1]\)]; \n\ \ \ 
          y\  = \ \(ALLDATA[\([i]\)]\)[\([2]\)]; \n\ \ \ 
          datastr\  = \ 
            ToString[FortranForm[x]]<>"\<   \>"<>ToString[FortranForm[y]]; \n
          \ \ \(PutAppend[OutputForm[datastr], filename]; \)\n
          \ \ , {i, 1, NDATA}]; \n]; \)\)], "Input"],

Cell[BoxData[
    \(\( (*\ \(--\(--\(--\(--\(--\(--\(----\)\)\)\)\)\)\)\ *) \n
     (*\ parameters\ \ \ \ \ \ \ \ \ *) \n
     (*\ \(--\(--\(--\(--\(--\(--\(----\)\)\)\)\)\)\)\ *) \nClear[xm, f, k]; 
    \nmw = 80.41; \nmt = 175; \nmb = 4.3; \nmd = 0.01; \nms = 0; \nmc = 1.4; 
    \nmmk = 0.89; \nmmb = 5.4; \nmcb = mc/mb; \nvcd = 0.22; \nvts = 0.04; \n
    alphas = 0.214; \nalpha = 1/137; \nbrsl = 0.105; \n
    f[x_] := \((1 - 8  x^2 + 8  x^6 - x^8 - 24  x^4  Log[x])\); \n
    k[x_] := \((
        1 - \((2  alphas/\((3  Pi)\))\) 
            \((\((Pi^2 - 31/4)\) \((1 - x)\)^2 + 3/2)\))\); \n
    gf = 1.1\ 10^\((\(-5\))\); \nlambdagut = 10^\((15)\); \nv = 246; \n
    ep = 1/4; \netab = 0.55; \netaktt = 0.57; \netakcc = 1.38; \n
    etakct = 0.47; \nfbbb = 0.215; \nfkbk = 0.173; \n
    tb = \((1.56\ 10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\); \n
    dmbe = \((0.471 \((6.582\ 10^\((\(-25\))\))\)/\((10^\((\(-12\))\))\))\); 
    \ndmke = \((
        0.53\ 10^\((\(-2\))\) 
          \((6.582\ 10^\((\(-25\))\))\)/\((10^\((\(-12\))\))\))\); \n
    xm[ma_, mb_] := \((ma/mb)\)^2; \)\)], "Input"],

Cell[BoxData[
    \(\( (*\ mixing\ parameter\ for\ RI\ \ *) \nClear[ddll, ddlr, ddrl]; \n
    ddll[m_, ac_, dll_] := 
      \((dll\ 1/\((8  Pi^2  m^2)\) \((3  m^2 + ac^2)\) Log[lambdagut/m])\); \n
    ddrr[m_, ac_, drr_] = 0; \n
    ddlr[m_, ac_, tanb_, dlr_] := 
      \((dlr\ v/Sqrt[1 + tanb^2] 
          \((3  ac/\((16  Pi^2  m^2)\) Log[lambdagut/m])\))\); \n
    ddrl[m_, ac_, tanb_, drl_] := 
      \((drl\ v/Sqrt[1 + tanb^2] 
          \((3  ac/\((16  Pi^2  m^2)\) Log[lambdagut/m])\))\); \)\)], "Input"],

Cell[BoxData[
    \(\( (*\ mixing\ parameter\ for\ MI\ *) \nClear[ddll, ddlr, ddrl]; \n
    ddll[m_, ac_, dll_] := dll; \nddrr[m_, ac_, drr_] = drr; \n
    ddlr[m_, ac_, tanb_, dlr_] := 0; \nddrl[m_, ac_, tanb_, drl_] := 0; \)\)],
   "Input"],

Cell[BoxData[
    \(\( (*\ \(--\(--\(--\(--\(--\(----\)\)\)\)\)\)\ *) \n
     (*\ M - M\ mixing\ \ \ \ \ \ *) \n
     (*\ \(--\(--\(--\(--\(--\(----\)\)\)\)\)\)\ *) \n
    Clear[f1, f1p, f2, f3, f4, f5]; \n
    Clear[dmb, dmk, dmbsm, dmksm, dmd, dmkmi, dmbmi]; \n
    f1[x_] = \((
        x \((\((10 - x)\)/\((4 \((1 - x)\))\) - 3/\((2 \((1 - x)\)^2)\) - 
              \((3  x^2  Log[x])\)/\((2 \((1 - x)\)^3)\))\))\); \n
    f1p[x_, y_] := 
      \((x\ y \((
            \((1/4 + 3/\((2 \((1 - y)\))\) - 3/\((4 \((1 - y)\)^2)\))\) 
                Log[y]/\((y - x)\)\n\t\t\t\t + 
              \((1/4 + 3/\((2 \((1 - x)\))\) - 3/\((4 \((1 - x)\)^2)\))\) 
                Log[x]/\((x - y)\)\n\t\t\t\t\t - 
              3/\((4 \((1 - x)\) \((1 - y)\))\))\))\); \n
    f2[x_, y_] := 
      \((\(-\((8 - 2  x)\)\)/\((\((1 - x)\) \((1 - y)\))\) - 
          \((8  y - 2  x)\) Log[y]/\((\((y - x)\) \((1 - y)\)^2)\)\n\t\t\t\t
           + 6  x\ Log[x]/\((\((y - x)\) \((1 - x)\)^2)\))\); \n
    f3[x_] := \((\((1 - x^2 + 2  x\ Log[x])\)/\((1 - x)\)^3)\); \n
    f4[x_] := 
      \((\((17 - 9  x - 9  x^2 + x^3 + 6 \((1 + 3  x)\) Log[x])\)/
          \((6 \((1 - x)\)^5)\))\); \n
    f5[x_] := 
      \((\((1 + 9  x - 9  x^2 - x^3 + 6  x \((1 + x)\) Log[x])\)/
          \((3 \((1 - x)\)^5)\))\); \n
    dmbsm[vtd_] := 
      \((\((gf^2)\)/\((6  Pi^2)\) mw^2  mmb\ fbbb^2  etab\ vtd^2 
          \((f1[\((mt/mw)\)^2])\))\); \n
    dmksm[vtd_] := 
      \((\((gf^2)\)/\((6  Pi^2)\) mw^2  mmk\ fkbk^2 \((vtd\ vts)\)^2 
          \((etaktt\ f1[\((mt/mw)\)^2] + 
              \((vcd/\((vtd\ vts)\))\)^2  etakcc\ f1[\((mc/mw)\)^2] + 
              2 \((vcd\ vtd\ vts)\)/\((vtd\ vts)\)^2\ etakct\ 
                f1p[\((mc/mw)\)^2, \((mt/mw)\)^2])\))\); \ \n
    dmb[vtd_, tanb_, mh_, mgt_, a_, m_, ac_, dll_, drr_, dlr_, drl_] := 
      \((\n\t\t\((gf^2)\)/\((6  Pi^2)\) mw^2  mmb\ fbbb^2  etab\ 
          \((\n\t\t\t
            \((Pi^2  alphas^2)\)/\((gf^2  mw^2 \((mgt/a)\)^2)\) 
              \((\n\t\t\t\t\t
                \((ddll[m, ac, dll]^2 + ddrr[m, ac, drr]^2)\)/9 
                    \((4  a^2  f4[a^2] + 11  f5[a^2])\) + \n\t\t\t\t\t
                  \((\(-5\)/8 \((mmb/\((mb + md)\))\)^2)\) 102/27 
                    \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)\) 
                    a^2  f4[a^2] - \n\t\t\t\t\t
                  \((1/8 \((mmb/\((mb + md)\))\)^2)\) 2/3 
                    \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)\) 
                    a^2  f4[a^2] + \n\t\t\t\t\t
                  \((3/4 \((1/6 + \((mmb/\((mb + md)\))\)^2)\))\) 2/9 
                    \((6  ddll[m, ac, dll]\ ddrr[m, ac, drr] 
                          \((7  a^2  f4[a^2] - f5[a^2])\) - 
                        11  ddlr[m, ac, tanb, dlr] ddrl[m, ac, tanb, drl]\ 
                          f5[a^2])\) + \n\t\t\t\t\t
                  \((3/4 \((1/2 + 1/3 \((mmb/\((mb + md)\))\)^2)\))\) 2/9 
                    \((2  ddll[m, ac, dll]\ ddrr[m, ac, drr] 
                          \((a^2  f4[a^2] + 5  f5[a^2])\) - 
                        15  ddlr[m, ac, tanb, dlr]\ ddrl[m, ac, tanb, drl]\ 
                          f5[a^2])\)\n\t\t\t\t\t)\))\)\n\t\t)\); \n
    dmk[vtd_, tanb_, mh_, mgt_, a_, m_, ac_, dll_, drr_, dlr_, drl_] := 
      \((\n\t\t\((gf^2)\)/\((6  Pi^2)\) mw^2  mmk\ fkbk^2 
          \((\n\t\t\t
            \((Pi^2  alphas^2)\)/\((gf^2  mw^2 \((mgt/a)\)^2)\) 
              \((\n\t\t\t\t\t
                \((ddll[m, ac, dll]^2 + ddrr[m, ac, drr]^2)\)/9 
                    \((4  a^2  f4[a^2] + 11  f5[a^2])\) + \n\t\t\t\t\t
                  \((\(-5\)/8 \((mmb/\((mb + md)\))\)^2)\) 102/27 
                    \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)\) 
                    a^2  f4[a^2] - \n\t\t\t\t\t
                  \((1/8 \((mmb/\((mb + md)\))\)^2)\) 2/3 
                    \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)\) 
                    a^2  f4[a^2] + \n\t\t\t\t\t
                  \((3/4 \((1/6 + \((mmb/\((mb + md)\))\)^2)\))\) 2/9 
                    \((6  ddll[m, ac, dll]\ ddrr[m, ac, drr] 
                          \((7  a^2  f4[a^2] - f5[a^2])\) - 
                        11  ddlr[m, ac, tanb, dlr] ddrl[m, ac, tanb, drl]\ 
                          f5[a^2])\) + \n\t\t\t\t\t
                  \((3/4 \((1/2 + 1/3 \((mmb/\((mb + md)\))\)^2)\))\) 2/9 
                    \((2  ddll[m, ac, dll]\ ddrr[m, ac, drr] 
                          \((a^2  f4[a^2] + 5  f5[a^2])\) - 
                        15  ddlr[m, ac, tanb, dlr]\ ddrl[m, ac, tanb, drl]\ 
                          f5[a^2])\)\n\t\t\t\t\t)\))\)\n\t\t)\); \)\)], 
  "Input"],

Cell[BoxData[
    \(\(dmb[vtd_, tanb_, mh_, mgt_, a_, m_, ac_, dll_, drr_, dlr_, drl_] := 
      \((\n\t\t\((gf^2)\)/\((6  Pi^2)\) mw^2  mmb\ fbbb^2  etab\ vtd^2 
          \((\n\t\t\t
            f1[\((mt/mw)\)^2] + \ \n\t\t\t
              \((\((mt/mw)\)^2 \((mt/mh)\)^2 
                    \((f2[\((mt/mw)\)^2, \((mt/mh)\)^2] + 
                        f3[\((mt/mh)\)^2]/tanb^2)\))\)/\((4\ tanb^2)\) + \n
              \t\t\t\((Pi^2  alphas^2)\)/
                  \((gf^2  vtd^2  mw^2 \((mgt/a)\)^2)\) 
                \((\n\t\t\t\t\t
                  \((ddll[m, ac, dll]^2 + ddrr[m, ac, drr]^2)\)/9 
                      \((4  a^2  f4[a^2] + 11  f5[a^2])\) + \n\t\t\t\t\t
                    \((\(-5\)/8 \((mmb/\((mb + md)\))\)^2)\) 102/27 
                      \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)
                        \) a^2  f4[a^2] - \n\t\t\t\t\t
                    \((1/8 \((mmb/\((mb + md)\))\)^2)\) 2/3 
                      \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)
                        \) a^2  f4[a^2] + \n\t\t\t\t\t
                    \((3/4 \((1/6 + \((mmb/\((mb + md)\))\)^2)\))\) 2/9 
                      \((6  ddll[m, ac, dll]\ ddrr[m, ac, drr] 
                            \((7  a^2  f4[a^2] - f5[a^2])\) - 
                          11  ddlr[m, ac, tanb, dlr] ddrl[m, ac, tanb, drl]\ 
                            f5[a^2])\) + \n\t\t\t\t\t
                    \((3/4 \((1/2 + 1/3 \((mmb/\((mb + md)\))\)^2)\))\) 2/9 
                      \((2  ddll[m, ac, dll]\ ddrr[m, ac, drr] 
                            \((a^2  f4[a^2] + 5  f5[a^2])\) - 
                          15  ddlr[m, ac, tanb, dlr]\ ddrl[m, ac, tanb, drl]\ 
                            f5[a^2])\)\n\t\t\t\t\t)\))\)\n\t\t)\); \n
    dmk[vtd_, tanb_, mh_, mgt_, a_, m_, ac_, dll_, drr_, dlr_, drl_] := 
      \((\n\t\t\((gf^2)\)/\((6  Pi^2)\) mw^2  mmk\ fkbk^2 \((vtd\ vts)\)^2 
          \((\n\t\t\t\t
            etaktt\ f1[\((mt/mw)\)^2] + 
              \((vcd/\((vtd\ vts)\))\)^2  etakcc\ f1[\((mc/mw)\)^2] + \n
              \t\t\t\t\t
              2 \((vcd\ vtd\ vts)\)/\((vtd\ vts)\)^2\ etakct\ 
                f1p[\((mc/mw)\)^2, \((mt/mw)\)^2] + \n\t\t\t\t
              \((\((mt/mw)\)^2 \((mt/mh)\)^2 
                    \((f2[\((mt/mw)\)^2, \((mt/mh)\)^2] + 
                        f3[\((mt/mh)\)^2]/tanb^2)\))\)/\((4\ tanb^2)\) + \n
              \t\t\t\((Pi^2  alphas^2)\)/
                  \((gf^2 \((vtd\ vts)\)^2  mw^2 \((mgt/a)\)^2)\) 
                \((\n\t\t\t\t\t
                  \((ddll[m, ac, dll]^2 + ddrr[m, ac, drr]^2)\)/9 
                      \((4  a^2  f4[a^2] + 11  f5[a^2])\) + \n\t\t\t\t\t
                    \((\(-5\)/8 \((mmb/\((mb + md)\))\)^2)\) 102/27 
                      \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)
                        \) a^2  f4[a^2] - \n\t\t\t\t\t
                    \((1/8 \((mmb/\((mb + md)\))\)^2)\) 2/3 
                      \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)
                        \) a^2  f4[a^2] + \n\t\t\t\t\t
                    \((3/4 \((1/6 + \((mmb/\((mb + md)\))\)^2)\))\) 2/9 
                      \((6  ddll[m, ac, dll]\ ddrr[m, ac, drr] 
                            \((7  a^2  f4[a^2] - f5[a^2])\) - 
                          11  ddlr[m, ac, tanb, dlr] ddrl[m, ac, tanb, drl]\ 
                            f5[a^2])\) + \n\t\t\t\t\t
                    \((3/4 \((1/2 + 1/3 \((mmb/\((mb + md)\))\)^2)\))\) 2/9 
                      \((2  ddll[m, ac, dll]\ ddrr[m, ac, drr] 
                            \((a^2  f4[a^2] + 5  f5[a^2])\) - 
                          15  ddlr[m, ac, tanb, dlr]\ ddrl[m, ac, tanb, drl]\ 
                            f5[a^2])\)\n\t\t\t\t\t)\))\)\n\t\t)\); \n\)\)], 
  "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(N[\((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) dmbsm[0.004]]\), 
  
    \(N[\((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) dmbsm[0.013]]
      \)}], "Input"],

Cell[BoxData[
    \(0.11354025186680412`\)], "Output"],

Cell[BoxData[
    \(1.19926891034311843`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bdbdsu5a = 
      Plot[\n\t\t
        \((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) 
          dmb[0.00815, 30, 200, mgt, 1.001, mgt, 100, Sqrt[5] ep^4, 0, 
            Sqrt[5] ep^4, Sqrt[5] ep^\((10)\)], \n\t\t{mgt, 200, 2000}]\), 
    \(bdbdsu5i = 
      Plot[\n\t\t
        \((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) 
          dmb[0.00815, 30, 200, mgt, 4.5, mgt, 0, Sqrt[5] ep^4, 0, 
            Sqrt[5] ep^4, Sqrt[5] ep^\((10)\)], \n\t\t{mgt, 200, 2000}]\)}], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.0147151 6.092 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -12 -9 ]
[.5 .00222 12 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .13656 -24 -4.5 ]
[.01131 .13656 0 4.5 ]
[.01131 .2584 -24 -4.5 ]
[.01131 .2584 0 4.5 ]
[.01131 .38024 -24 -4.5 ]
[.01131 .38024 0 4.5 ]
[.01131 .50207 -24 -4.5 ]
[.01131 .50207 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(500)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1000)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1500)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13656 m
.03006 .13656 L
s
[(0.02)] .01131 .13656 1 0 Mshowa
.02381 .2584 m
.03006 .2584 L
s
[(0.04)] .01131 .2584 1 0 Mshowa
.02381 .38024 m
.03006 .38024 L
s
[(0.06)] .01131 .38024 1 0 Mshowa
.02381 .50207 m
.03006 .50207 L
s
[(0.08)] .01131 .50207 1 0 Mshowa
.125 Mabswid
.02381 .04518 m
.02756 .04518 L
s
.02381 .07564 m
.02756 .07564 L
s
.02381 .1061 m
.02756 .1061 L
s
.02381 .16702 m
.02756 .16702 L
s
.02381 .19748 m
.02756 .19748 L
s
.02381 .22794 m
.02756 .22794 L
s
.02381 .28886 m
.02756 .28886 L
s
.02381 .31932 m
.02756 .31932 L
s
.02381 .34978 m
.02756 .34978 L
s
.02381 .4107 m
.02756 .4107 L
s
.02381 .44116 m
.02756 .44116 L
s
.02381 .47161 m
.02756 .47161 L
s
.02381 .53253 m
.02756 .53253 L
s
.02381 .56299 m
.02756 .56299 L
s
.02381 .59345 m
.02756 .59345 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .60332 m
.12713 .50056 L
.13597 .41638 L
.14521 .35004 L
.15382 .30209 L
.17214 .22914 L
.1824 .19986 L
.19174 .17815 L
.20897 .14699 L
.22768 .12228 L
.24553 .10462 L
.26446 .09025 L
.29851 .0718 L
.31598 .06484 L
.33477 .05868 L
.37187 .04941 L
.40761 .04299 L
.44198 .03835 L
.47856 .03455 L
.51378 .03169 L
.5512 .02928 L
.58726 .02741 L
.62196 .02592 L
.65886 .02461 L
.6944 .02355 L
.72857 .02268 L
.76496 .02189 L
.79997 .02123 L
.8372 .02063 L
.87306 .02012 L
.90756 .01969 L
.94426 .01929 L
.97619 .01898 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o001Ao`<01?l200Co0P0/o`@0
0ol200Co0P04o`80:Ol400;o0`04o`801?l202Wo1003o`801?l200Co0P03o`00E?l0103oo`02o`04
0?oo00;o00<0ool0:ol01@3oool000;o00@0ool00_l0103oo`02o`030?oo02So00<0ool01?l0103o
o`02o`040?oo00;o00<0ool09_l00`3oo`03o`040?oo00;o00@0ool00_l0103oo`02o`00E?l0103o
o`02o`040?oo00;o00<0ool0:ol01@3oool000;o00@0ool00_l0103oo`02o`030?oo02So00<0ool0
1?l0103oo`02o`040?oo00;o00<0ool09ol00`3oo`02o`040?oo00;o00@0ool00_l0103oo`02o`00
DOl300?o00@0ool00_l0103oo`0]o`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool0:?l0103o
ool300?o00@0ool00_l0103oo`0Zo`050?ooo`000_l0103oo`02o`040?oo00;o0@01o`7o001Ao`03
0?oo00?o00@0ool00_l0103oo`0]o`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool0:?l01@3o
ool000Go00@0ool00_l0103oo`0[o`040?oo00;o00@0ool00_l0103oo`02o`400Ol1o`006ol00`3o
o`0co`030?oo00?o00@0ool00_l0103oo`0[o`<00ol0103oo`02o`040?oo00;o00@0ool0:?l300?o
00<0ool00ol0103oo`02o`040?oo02So00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l001_o
00<0ool0<ol400?o0P04o`80;_l00`3oo`02o`801?l200Co0P0[o`040?ooo`@00ol200Co0P0Zo`80
1?l200Co0P04o`800ol001_o00<0ool0ool3o`006ol00`3oo`3oo`?o000Eool01P06o`006ol00`3o
o`09o`030?oo00[o00<0ool02Ol00`3oo`09o`030?oo00[o00<0ool02Ol00`3oo`09o`030?oo00[o
00<0ool02Ol00`3oo`0:o`030?oo00Wo00<0ool02Ol00`3oo`0:o`030?oo00Wo00<0ool02_l00`3o
o`09oc<03?l001_o00<0ool0WOlV03oo000Ko`030?oo087o701Uo`006ol00`3oo`1ho`T0POl001_o
00<0ool0Kol908[o000Ko`030?oo06Ko2@2Co`006ol00`3oo`1Oo`L0W?l001_o0P1Ko`D0Xol001_o
00<0ool0EOl50:So000Ko`030?oo057o102]o`006ol00`3oo`1=o`@0/Ol001_o00<0ool0Bol20;Go
000Ko`030?oo04So0`2go`006ol00`3oo`16o`80^_l001_o00<0ool0@ol30;co000Ko`80@_l20;oo
000Ko`030?oo03oo0P31o`006ol00`3oo`0mo`80`ol001_o00<0ool0>ol20<Go000Ko`030?oo03[o
00<0ool0aOl001_o00<0ool0>?l20<So000Ko`030?oo03Oo00<0ool0b?l001_o0P0go`030?oo0<Wo
000Ko`030?oo03Go00<0ool0b_l001_o00<0ool0=?l00`3oo`3;o`006ol00`3oo`0do`030?oo0<_o
000Ko`030?oo03?o00<0ool0c?l001_o00<0ool0<_l00`3oo`3=o`006ol00`3oo`0ao`030?oo0<ko
0002o`801?l00`3oo`03o`800ol400Co00<0ool0<?l00`3oo`3?o`0000Go0?oo0008o`040?oo00;o
00<0ool01Ol2037o00<0ool0col00005o`3oo`002?l0103oo`03o`030?oo00Co00<0ool0;ol00`3o
o`3@o`0000Go0?oo0008o`040?oo00Co00<0ool00ol00`3oo`0^o`030?oo0=7o00001Ol0ool000So
00@0ool01Ol00`3oo`02o`030?oo02go00<0ool0d_l00005o`3oo`002?l0103oo`02o`040?oo00Co
00<0ool0;?l00`3oo`3Co`000_l200[o0P04o`801Ol00`3oo`0/o`030?oo0=?o000Ko`030?oo02_o
00<0ool0e?l001_o00<0ool0:ol00`3oo`3Do`006ol202_o00<0ool0eOl001_o00<0ool0:Ol00`3o
o`3Fo`006ol00`3oo`0Yo`030?oo0=Ko000Ko`030?oo02So00<0ool0eol001_o00<0ool0:?l00`3o
o`3Go`006ol00`3oo`0Wo`030?oo0=So000Ko`030?oo02Oo00<0ool0f?l001_o00<0ool09ol00`3o
o`3Ho`006ol202Oo00<0ool0fOl001_o00<0ool09_l00`3oo`3Io`006ol00`3oo`0Vo`030?oo0=Wo
000Ko`030?oo02Go00<0ool0f_l001_o00<0ool09Ol00`3oo`3Jo`006ol00`3oo`0To`030?oo0=_o
000Ko`030?oo02Co00<0ool0fol001_o00<0ool08ol00`3oo`3Lo`006ol202Co00<0ool0g?l001_o
00<0ool08ol00`3oo`3Lo`006ol00`3oo`0So`030?oo0=co000Ko`030?oo02;o00<0ool0gOl001_o
00<0ool08_l00`3oo`3Mo`006ol00`3oo`0Ro`030?oo0=go000Ko`030?oo02;o00<0ool0gOl000;o
0P04o`030?oo00?o0P05o`030?oo00?o00<0ool08_l00`3oo`3Mo`0000Go0?oo0008o`040?oo00Co
00<0ool00ol202;o00<0ool0g_l00005o`3oo`002?l01@3oo`3o00D01?l00`3oo`0Qo`030?oo0=ko
00001Ol0ool000So00H0ool0o`02o`030?oo00?o00<0ool08Ol00`3oo`3No`0000Go0?oo0008o`04
0?oo00;o00<0o`001Ol00`3oo`0Qo`030?oo0=ko00001Ol0ool000So00@0ool00ol200Go00<0ool0
8?l00`3oo`3Oo`000_l200[o0P05o`030?oo00?o00<0ool08?l00`3oo`3Oo`006ol00`3oo`0Po`03
0?oo0=oo000Ko`030?oo023o00<0ool0gol001_o0P0Qo`030?oo0=oo000Ko`030?oo01oo00<0ool0
h?l001_o00<0ool07ol00`3oo`3Po`006ol00`3oo`0Oo`030?oo0>3o000Ko`030?oo01oo00<0ool0
h?l001_o00<0ool07ol00`3oo`3Po`006ol00`3oo`0No`030?oo0>7o000Ko`030?oo01ko00<0ool0
hOl001_o0P0Oo`030?oo0>7o000Ko`030?oo01ko00<0ool0hOl001_o00<0ool07Ol00`3oo`3Ro`00
6ol00`3oo`0Mo`030?oo0>;o000Ko`030?oo01go00<0ool0h_l001_o00<0ool07Ol00`3oo`3Ro`00
6ol00`3oo`0Lo`030?oo0>?o000Ko`030?oo01co00<0ool0hol001_o0P0Mo`030?oo0>?o000Ko`03
0?oo01co00<0ool0hol001_o00<0ool07?l00`3oo`3So`006ol00`3oo`0Lo`030?oo0>?o000Ko`03
0?oo01co00<0ool0hol001_o00<0ool06ol00`3oo`3To`000_l200Co00<0ool00ol200Co0P05o`03
0?oo01_o00<0ool0i?l00005o`3oo`002?l0103oo`02o`040?oo00Co00<0ool06ol00`3oo`3To`00
00Go0?oo0008o`040?oo00;o00@0ool01?l201co00<0ool0i?l00005o`3oo`002?l0103oo`02o`<0
1Ol00`3oo`0Ko`030?oo0>Co00001Ol0ool000So00@0ool00_l00`3oo`05o`030?oo01_o00<0ool0
i?l00005o`3oo`002?l0103oo`02o`030?oo00Go00<0ool06ol00`3oo`3To`000_l200[o0P04o`<0
1?l00`3oo`0Ko`030?oo0>Co000Ko`030?oo01[o00<0ool0iOl001_o00<0ool06_l00`3oo`3Uo`00
6ol00`3oo`0Jo`030?oo0>Go000Ko`806ol00`3oo`3Uo`006ol00`3oo`0Jo`030?oo0>Go000Ko`03
0?oo01[o00<0ool0iOl001_o00<0ool06_l00`3oo`3Uo`006ol00`3oo`0Jo`030?oo0>Go000Ko`03
0?oo01[o00<0ool0iOl001_o00<0ool06_l00`3oo`3Uo`006ol00`3oo`0Io`030?oo0>Ko000Ko`80
6_l00`3oo`3Vo`006ol00`3oo`0Io`030?oo0>Ko000Ko`030?oo01Wo00<0ool0i_l001_o00<0ool0
6Ol00`3oo`3Vo`006ol00`3oo`0Io`030?oo0>Ko000Ko`030?oo01Wo00<0ool0i_l001_o00<0ool0
6Ol00`3oo`3Vo`006ol00`3oo`0Io`030?oo0>Ko000Ko`806_l00`3oo`3Vo`006ol00`3oo`0Io`03
0?oo0>Ko000Ko`030?oo01So00<0ool0iol001_o00<0ool06?l00`3oo`3Wo`006ol00`3oo`0Ho`03
0?oo0>Oo000Ko`030?oo01So00<0ool0iol000;o0P04o`030?oo00?o0P04o`801Ol00`3oo`0Ho`03
0?oo0>Oo00001Ol0ool000So00@0ool00_l0103oo`04o`806Ol00`3oo`3Wo`0000Go0?oo0008o`04
0?oo00;o00@0ool01?l00`3oo`0Ho`030?oo0>Oo00001Ol0ool000So00@0ool00ol200Go00<0ool0
6?l00`3oo`3Wo`0000Go0?oo0008o`040?oo00;o00@0ool01?l00`3oo`0Ho`030?oo0>Oo00001Ol0
ool000So00@0ool00_l0103oo`04o`030?oo01So00<0ool0iol000;o0P0:o`801?l200Go00<0ool0
6?l00`3oo`3Wo`006ol00`3oo`0Ho`030?oo0>Oo000Ko`030?oo01Oo00<0ool0j?l001_o0P0Ho`03
0?oo0>So000Ko`030?oo01Oo00<0ool0j?l001_o00<0ool05ol00`3oo`3Xo`006ol00`3oo`0Go`03
0?oo0>So000Ko`030?oo01Oo00<0ool0j?l001_o00<0ool05ol00`3oo`3Xo`006ol00`3oo`0Go`03
0?oo0>So000Ko`030?oo01Oo00<0ool0j?l001_o0P0Ho`030?oo0>So000Ko`030?oo01Oo00<0ool0
j?l001_o00<0ool05ol00`3oo`3Xo`006ol00`3oo`0Go`030?oo0>So000Ko`030?oo01Oo00<0ool0
j?l001_o00<0ool05_l00`3oo`3Yo`006ol00`3oo`0Fo`030?oo0>Wo000Ko`030?oo01Ko00<0ool0
jOl001_o0P0Go`030?oo0>Wo000Ko`030?oo01Ko00<0ool0jOl001_o00<0ool05_l00`3oo`3Yo`00
6ol00`3oo`0Fo`030?oo0>Wo000Ko`030?oo0?oo0ol001_o00<0ool0ool3o`006ol00`3oo`3oo`?o
000Ko`030?oo0?oo0ol00?oo8Ol00?oo8Ol00?oo8Ol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-220.006, -0.0101738, 
  8.07279, 0.000631021}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.603319 3.06143 [
[.2619 .59082 -9 -9 ]
[.2619 .59082 9 0 ]
[.5 .59082 -12 -9 ]
[.5 .59082 12 0 ]
[.7381 .59082 -12 -9 ]
[.7381 .59082 12 0 ]
[.97619 .59082 -12 -9 ]
[.97619 .59082 12 0 ]
[.01131 .14411 -30 -4.5 ]
[.01131 .14411 0 4.5 ]
[.01131 .29718 -24 -4.5 ]
[.01131 .29718 0 4.5 ]
[.01131 .45025 -30 -4.5 ]
[.01131 .45025 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(500)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(1000)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(1500)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(2000)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .14411 m
.03006 .14411 L
s
[(-0.15)] .01131 .14411 1 0 Mshowa
.02381 .29718 m
.03006 .29718 L
s
[(-0.1)] .01131 .29718 1 0 Mshowa
.02381 .45025 m
.03006 .45025 L
s
[(-0.05)] .01131 .45025 1 0 Mshowa
.125 Mabswid
.02381 .17472 m
.02756 .17472 L
s
.02381 .20533 m
.02756 .20533 L
s
.02381 .23595 m
.02756 .23595 L
s
.02381 .26656 m
.02756 .26656 L
s
.02381 .32779 m
.02756 .32779 L
s
.02381 .3584 m
.02756 .3584 L
s
.02381 .38902 m
.02756 .38902 L
s
.02381 .41963 m
.02756 .41963 L
s
.02381 .48086 m
.02756 .48086 L
s
.02381 .51148 m
.02756 .51148 L
s
.02381 .54209 m
.02756 .54209 L
s
.02381 .5727 m
.02756 .5727 L
s
.02381 .11349 m
.02756 .11349 L
s
.02381 .08288 m
.02756 .08288 L
s
.02381 .05226 m
.02756 .05226 L
s
.02381 .02165 m
.02756 .02165 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .01472 m
.12713 .10595 L
.13597 .1837 L
.15382 .29415 L
.1633 .33607 L
.17345 .37221 L
.19174 .42128 L
.21092 .45778 L
.22904 .48314 L
.24702 .50231 L
.26361 .51625 L
.2819 .52854 L
.29903 .53786 L
.33308 .55191 L
.36798 .56212 L
.40508 .56999 L
.44082 .57564 L
.47519 .57983 L
.51177 .58333 L
.54699 .58602 L
.58441 .58833 L
.62047 .59015 L
.65517 .5916 L
.69207 .5929 L
.72761 .59396 L
.76178 .59484 L
.79816 .59565 L
.83318 .59632 L
.87041 .59694 L
.90627 .59747 L
.94077 .59791 L
.97619 .59832 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o
000Qo`030?oo0?co000Qo`030?oo0?co000Qo`030?oo0?co000Qo`030?oo01Go00<0ool0i?l0027o
00<0ool05Ol00`3oo`3To`008Ol201Ko00<0ool0i?l0027o00<0ool05Ol00`3oo`3To`008Ol00`3o
o`0Eo`030?oo0>Co000Qo`030?oo01Go00<0ool0i?l0027o00<0ool05_l00`3oo`3So`008Ol00`3o
o`0Fo`030?oo0>?o000Qo`030?oo01Ko00<0ool0hol0027o00<0ool05_l00`3oo`3So`008Ol201Oo
00<0ool0hol0027o00<0ool05_l00`3oo`3So`008Ol00`3oo`0Fo`030?oo0>?o000Qo`030?oo01Ko
00<0ool0hol0027o00<0ool05_l00`3oo`3So`008Ol00`3oo`0Fo`030?oo0>?o000Qo`030?oo01Ko
00<0ool0hol0027o00<0ool05_l00`3oo`3So`008Ol201So00<0ool0h_l0027o00<0ool05ol00`3o
o`3Ro`008Ol00`3oo`0Go`030?oo0>;o000Qo`030?oo01Oo00<0ool0h_l0027o00<0ool05ol00`3o
o`3Ro`008Ol00`3oo`0Go`030?oo0>;o000Qo`030?oo01Oo00<0ool0h_l0027o0P0Ho`030?oo0>;o
000Qo`030?oo01Oo00<0ool0h_l0027o00<0ool05ol00`3oo`3Ro`008Ol00`3oo`0Ho`030?oo0>7o
000Qo`030?oo01So00<0ool0hOl0027o00<0ool06?l00`3oo`3Qo`008Ol00`3oo`0Ho`030?oo0>7o
0008o`801?l00`3oo`02o`@00_l300Go00<0ool06?l00`3oo`3Qo`001ol0103oo`0:o`030?oo00Co
00<0ool00_l201Wo00<0ool0hOl000Oo00@0ool02_l00`3oo`04o`030?oo00;o00<0ool06?l00`3o
o`3Qo`0000?o00000P02o`040?oo00[o00@0oooo0`05o`030?oo01So00<0ool0hOl000Oo00@0ool0
2_l01@3oool000Oo00<0ool06?l00`3oo`3Qo`001ol0103oo`08o`<00ol00`3oo`05o`030?oo01So
00<0ool0hOl000So0P0;o`040?ooo`@01?l00`3oo`0Io`030?oo0>3o000Qo`030?oo01Wo00<0ool0
h?l0027o00<0ool06Ol00`3oo`3Po`008Ol201[o00<0ool0h?l0027o00<0ool06Ol00`3oo`3Po`00
8Ol00`3oo`0Io`030?oo0>3o000Qo`030?oo01Wo00<0ool0h?l0027o00<0ool06Ol00`3oo`3Po`00
8Ol00`3oo`0Jo`030?oo0=oo000Qo`030?oo01[o00<0ool0gol0027o00<0ool06_l00`3oo`3Oo`00
8Ol201_o00<0ool0gol0027o00<0ool06_l00`3oo`3Oo`008Ol00`3oo`0Jo`030?oo0=oo000Qo`03
0?oo01_o00<0ool0g_l0027o00<0ool06ol00`3oo`3No`008Ol00`3oo`0Ko`030?oo0=ko000Qo`03
0?oo01_o00<0ool0g_l0027o0P0Lo`030?oo0=ko000Qo`030?oo01co00<0ool0gOl0027o00<0ool0
7?l00`3oo`3Mo`008Ol00`3oo`0Lo`030?oo0=go000Qo`030?oo01co00<0ool0gOl0027o00<0ool0
7?l00`3oo`3Mo`008Ol00`3oo`0Lo`030?oo0=go000Qo`030?oo01go00<0ool0g?l0027o0P0No`03
0?oo0=co000Qo`030?oo01go00<0ool0g?l0027o00<0ool07Ol00`3oo`3Lo`008Ol00`3oo`0Mo`03
0?oo0=co000Qo`030?oo01go00<0ool0g?l0027o00<0ool07_l00`3oo`3Ko`008Ol00`3oo`0No`03
0?oo0=_o000>o`801?l00`3oo`02o`@01?l00`3oo`0No`030?oo0=_o000=o`040?oo00[o00<0ool0
0ol201oo00<0ool0fol000go00@0ool02_l00`3oo`03o`030?oo01ko00<0ool0fol000Oo1002o`04
0?oo00[o00<0ool00ol00`3oo`0Oo`030?oo0=[o000=o`040?oo00[o00<0ool00ol00`3oo`0Oo`03
0?oo0=[o000=o`040?oo00So0`05o`030?oo01oo00<0ool0f_l000ko0P0;o`030?oo00?o00<0ool0
7ol00`3oo`3Jo`008Ol00`3oo`0Oo`030?oo0=[o000Qo`030?oo01oo00<0ool0f_l0027o0P0Qo`03
0?oo0=Wo000Qo`030?oo023o00<0ool0fOl0027o00<0ool08?l00`3oo`3Io`008Ol00`3oo`0Po`03
0?oo0=Wo000Qo`030?oo027o00<0ool0f?l0027o00<0ool08Ol00`3oo`3Ho`008Ol00`3oo`0Qo`03
0?oo0=So000Qo`030?oo02;o00<0ool0eol0027o0P0So`030?oo0=Oo000Qo`030?oo02;o00<0ool0
eol0027o00<0ool08ol00`3oo`3Fo`008Ol00`3oo`0So`030?oo0=Ko000Qo`030?oo02?o00<0ool0
e_l0027o00<0ool09?l00`3oo`3Eo`008Ol00`3oo`0To`030?oo0=Go000Qo`809Ol00`3oo`3Eo`00
8Ol00`3oo`0Uo`030?oo0=Co000Qo`030?oo02Go00<0ool0e?l0027o00<0ool09Ol00`3oo`3Do`00
8Ol00`3oo`0Uo`030?oo0=Co000Qo`030?oo02Ko00<0ool0dol0027o00<0ool09_l00`3oo`3Co`00
8Ol00`3oo`0Vo`030?oo0=?o000Qo`80:?l00`3oo`3Bo`008Ol00`3oo`0Wo`030?oo0=;o000Qo`03
0?oo02So00<0ool0dOl0027o00<0ool0:?l00`3oo`3Ao`008Ol00`3oo`0Yo`030?oo0=3o000Qo`03
0?oo02Wo00<0ool0d?l0027o00<0ool0:_l00`3oo`3?o`002?l200Co00<0ool00ol200?o0`05o`03
0?oo02[o00<0ool0col000Oo00@0ool02?l0103oo`05o`030?oo00;o0P0/o`030?oo0<ko0007o`04
0?oo00So00@0ool01Ol00`3oo`02o`030?oo02_o00<0ool0c_l00003o`0000800_l0103oo`08o`04
0?oo00;o0`05o`030?oo02co00<0ool0cOl000Oo00@0ool02?l0103oo`02o`030?oo00Go00<0ool0
;Ol00`3oo`3<o`001ol0103oo`08o`040?oo00;o00<0ool01Ol00`3oo`0^o`030?oo0<_o0008o`80
2_l200?o1004o`030?oo02oo00<0ool0b_l0027o00<0ool0;ol00`3oo`3:o`008Ol00`3oo`0`o`03
0?oo0<Wo000Qo`80<_l00`3oo`38o`008Ol00`3oo`0bo`030?oo0<Oo000Qo`030?oo03?o00<0ool0
a_l0027o00<0ool0<ol00`3oo`36o`008Ol00`3oo`0do`030?oo0<Go000Qo`030?oo03Go00<0ool0
a?l0027o00<0ool0=_l00`3oo`33o`008Ol203So0P33o`008Ol00`3oo`0io`030?oo0<3o000Qo`03
0?oo03[o00<0ool0_ol0027o00<0ool0>ol00`3oo`2no`008Ol00`3oo`0lo`80__l0027o00<0ool0
?_l20;co000Qo`030?oo043o0P2jo`008Ol00`3oo`12o`80^?l0027o0P15o`80]_l0027o00<0ool0
A_l20;Co000Qo`030?oo04So0P2bo`008Ol00`3oo`1:o`@0[_l0027o00<0ool0C_l40:[o000Qo`03
0?oo05;o1@2Uo`008Ol00`3oo`1Go`@0XOl0027o00<0ool0<Ol300Co0P04o`806ol500_o1003o`80
1?l200Co0P0Wo`@00_l300Co0P04o`80:?l400?o0P04o`801?l200?o000Qo`80=Ol0103oo`02o`04
0?oo00;o00<0ool07Ol500So00D0oooo0002o`040?oo00;o00@0ool00_l00`3oo`0Vo`030?oo00Co
00@0ool00_l0103oo`02o`030?oo02Go00<0ool00ol0103oo`02o`040?oo00;o00@0ool00_l0027o
00<0ool0=?l0103oo`02o`040?oo00;o00<0ool08_l600;o00D0oooo0002o`040?oo00;o00@0ool0
0_l00`3oo`0Vo`030?oo00Co00@0ool00_l0103oo`02o`030?oo02Ko00<0ool00_l0103oo`02o`04
0?oo00;o00@0ool00_l0027o00<0ool0<Ol300?o00@0ool00_l0103oo`0Zo`X00_l0103oo`02o`04
0?oo02So00@0oooo0`03o`040?oo00;o00@0ool0:Ol01@3oool000;o00@0ool00_l0103oo`02o`40
0Ol1o`008Ol00`3oo`0ao`030?oo00?o00@0ool00_l0103oo`0/o`050?ooo`000_lC02;o00D0oooo
0005o`040?oo00;o00@0ool0:_l0103oo`02o`040?oo00;o00@0ool00_l1007o0Ol0027o00<0ool0
<Ol00`3oo`03o`040?oo00;o00@0ool0:_l300?o00@0ool00_l0103oo`02o`040?oo00Ko4P0>o`<0
0ol00`3oo`03o`040?oo00;o00@0ool09ol0103oo`02o`040?oo00;o00@0ool00_l0103oo`02o`00
8Ol00`3oo`0ao`@00ol200Co0P0]o`030?oo00;o0P04o`801?l201Wo7@04o`80:Ol200Co0P04o`80
1?l200?o000Qo`030?oo0;Co?00<o`008Ol00`3oo`3lo`006ooo00Ko000Qo`030?oo00Wo00<0ool0
2Ol00`3oo`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`03
0?oo00[o00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool0
2Ol00`3oo`09o`030?oo00Wo00<0ool02_l00`3oo`0:o`008Ol00`3oo`3lo`008Ol00`3oo`3lo`00
oolQo`00oolQo`00oolQo`00oolQo`00oolQo`00oolQo`00oolQo`00oolQo`00oolQo`00oolQo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-274.374, -0.209942, 8.27049,
   0.00128643}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bdbdsu3a = 
      Plot[\n\t\t
        \((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) 
          dmb[0.00815, 30, 200, mgt, 1.001, mgt, 100, Sqrt[5] ep^3, 0, 
            Sqrt[5] ep^3, Sqrt[5] ep^4], \n\t\t{mgt, 200, 2000}]\), 
    \(bdbdsu3i = 
      Plot[\n\t\t
        \((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) 
          dmb[0.00815, 30, 200, mgt, 4.5, mgt, 0, ep^3/Sqrt[5], 0, 
            ep^3/Sqrt[5], ep^4/Sqrt[5]], \n\t\t{mgt, 200, 2000}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.0147151 0.38081 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -12 -9 ]
[.5 .00222 12 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .10992 -24 -4.5 ]
[.01131 .10992 0 4.5 ]
[.01131 .20512 -18 -4.5 ]
[.01131 .20512 0 4.5 ]
[.01131 .30032 -24 -4.5 ]
[.01131 .30032 0 4.5 ]
[.01131 .39553 -6 -4.5 ]
[.01131 .39553 0 4.5 ]
[.01131 .49073 -24 -4.5 ]
[.01131 .49073 0 4.5 ]
[.01131 .58593 -18 -4.5 ]
[.01131 .58593 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(500)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1000)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1500)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10992 m
.03006 .10992 L
s
[(0.25)] .01131 .10992 1 0 Mshowa
.02381 .20512 m
.03006 .20512 L
s
[(0.5)] .01131 .20512 1 0 Mshowa
.02381 .30032 m
.03006 .30032 L
s
[(0.75)] .01131 .30032 1 0 Mshowa
.02381 .39553 m
.03006 .39553 L
s
[(1)] .01131 .39553 1 0 Mshowa
.02381 .49073 m
.03006 .49073 L
s
[(1.25)] .01131 .49073 1 0 Mshowa
.02381 .58593 m
.03006 .58593 L
s
[(1.5)] .01131 .58593 1 0 Mshowa
.125 Mabswid
.02381 .03376 m
.02756 .03376 L
s
.02381 .0528 m
.02756 .0528 L
s
.02381 .07184 m
.02756 .07184 L
s
.02381 .09088 m
.02756 .09088 L
s
.02381 .12896 m
.02756 .12896 L
s
.02381 .148 m
.02756 .148 L
s
.02381 .16704 m
.02756 .16704 L
s
.02381 .18608 m
.02756 .18608 L
s
.02381 .22416 m
.02756 .22416 L
s
.02381 .2432 m
.02756 .2432 L
s
.02381 .26224 m
.02756 .26224 L
s
.02381 .28128 m
.02756 .28128 L
s
.02381 .31936 m
.02756 .31936 L
s
.02381 .3384 m
.02756 .3384 L
s
.02381 .35744 m
.02756 .35744 L
s
.02381 .37648 m
.02756 .37648 L
s
.02381 .41457 m
.02756 .41457 L
s
.02381 .43361 m
.02756 .43361 L
s
.02381 .45265 m
.02756 .45265 L
s
.02381 .47169 m
.02756 .47169 L
s
.02381 .50977 m
.02756 .50977 L
s
.02381 .52881 m
.02756 .52881 L
s
.02381 .54785 m
.02756 .54785 L
s
.02381 .56689 m
.02756 .56689 L
s
.02381 .60497 m
.02756 .60497 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .60332 m
.12713 .50058 L
.13597 .41641 L
.14521 .35007 L
.15382 .30212 L
.17214 .22916 L
.1824 .19988 L
.19174 .17817 L
.20897 .14701 L
.22768 .1223 L
.24553 .10463 L
.26446 .09026 L
.29851 .07181 L
.31598 .06485 L
.33477 .05868 L
.37187 .04942 L
.40761 .043 L
.44198 .03835 L
.47856 .03456 L
.51378 .0317 L
.5512 .02928 L
.58726 .02741 L
.62196 .02592 L
.65886 .02461 L
.6944 .02355 L
.72857 .02268 L
.76496 .02189 L
.79997 .02123 L
.8372 .02063 L
.87306 .02012 L
.90756 .01969 L
.94426 .01929 L
.97619 .01898 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o001Ao`<01?l200Co0P0/o`@0
0ol200Co0P04o`80:Ol400;o0`04o`801?l202Wo1003o`801?l200Co0P03o`00E?l0103oo`02o`04
0?oo00;o00<0ool0:ol01@3oool000;o00@0ool00_l0103oo`02o`030?oo02So00<0ool01?l0103o
o`02o`040?oo00;o00<0ool09_l00`3oo`03o`040?oo00;o00@0ool00_l0103oo`02o`00E?l0103o
o`02o`040?oo00;o00<0ool0:ol01@3oool000;o00@0ool00_l0103oo`02o`030?oo02So00<0ool0
1?l0103oo`02o`040?oo00;o00<0ool09ol00`3oo`02o`040?oo00;o00@0ool00_l0103oo`02o`00
DOl300?o00@0ool00_l0103oo`0]o`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool0:?l0103o
ool300?o00@0ool00_l0103oo`0Zo`050?ooo`000_l0103oo`02o`040?oo00;o0@01o`7o001Ao`03
0?oo00?o00@0ool00_l0103oo`0]o`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool0:?l01@3o
ool000Go00@0ool00_l0103oo`0[o`040?oo00;o00@0ool00_l0103oo`02o`400Ol1o`006ol00`3o
o`0co`030?oo00?o00@0ool00_l0103oo`0[o`<00ol0103oo`02o`040?oo00;o00@0ool0:?l300?o
00<0ool00ol0103oo`02o`040?oo02So00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l001_o
00<0ool0<ol400?o0P04o`80;_l00`3oo`02o`801?l200Co0P0[o`040?ooo`@00ol200Co0P0Zo`80
1?l200Co0P04o`800ol001_o00<0ool0ool3o`006ol00`3oo`3oo`?o000Eool01P06o`006ol00`3o
o`09o`030?oo00[o00<0ool02Ol00`3oo`09o`030?oo00[o00<0ool02Ol00`3oo`09o`030?oo00[o
00<0ool02Ol00`3oo`0:o`030?oo00Wo00<0ool02Ol00`3oo`0:o`030?oo00Wo00<0ool02_l00`3o
o`09oc<03?l001_o00<0ool0WOlV03oo000Ko`030?oo087o701Uo`006ol00`3oo`1ho`T0POl001_o
0P1`o`T0R_l001_o00<0ool0I_l909?o000Ko`030?oo05oo1`2Lo`006ol00`3oo`1Jo`D0Xol001_o
00<0ool0EOl50:So000Ko`80D_l40:go000Ko`030?oo04go102ao`006ol00`3oo`1;o`80]Ol001_o
00<0ool0B?l30;Oo000Ko`030?oo04Ko0P2jo`006ol204Co0`2lo`006ol00`3oo`11o`80_ol001_o
00<0ool0?ol20<7o000Ko`030?oo03go0P33o`006ol203co0P35o`006ol00`3oo`0jo`030?oo0<Go
000Ko`030?oo03So0P38o`006ol00`3oo`0go`030?oo0<So0002o`801?l00`3oo`02o`@00_l300Go
00<0ool0=_l00`3oo`39o`0000Go0?oo0008o`030?oo00Ko00<0ool00_l203Ko00<0ool0b_l00005
o`3oo`002Ol00`3oo`05o`030?oo00;o00<0ool0=?l00`3oo`3;o`0000Go0?oo000:o`040?ooo`<0
1Ol00`3oo`0do`030?oo0<_o00001Ol0ool000_o00@0ool01ol00`3oo`0co`030?oo0<co00001Ol0
ool000So00@0ool00_l00`3oo`05o`030?oo03;o00<0ool0cOl000;o0P0:o`800ol400Co0P0bo`03
0?oo0<ko000Ko`030?oo033o00<0ool0col001_o00<0ool0<?l00`3oo`3?o`006ol00`3oo`0_o`03
0?oo0=3o000Ko`030?oo02ko00<0ool0dOl001_o0P0^o`030?oo0=;o000Ko`030?oo02co00<0ool0
dol001_o00<0ool0;?l00`3oo`3Co`006ol00`3oo`0[o`030?oo0=Co000Ko`030?oo02_o00<0ool0
e?l001_o0P0[o`030?oo0=Go000Ko`030?oo02Wo00<0ool0e_l001_o00<0ool0:Ol00`3oo`3Fo`00
6ol00`3oo`0Xo`030?oo0=Oo000Ko`030?oo02So00<0ool0eol001_o0P0Xo`030?oo0=So000Ko`03
0?oo02Oo00<0ool0f?l001_o00<0ool09ol00`3oo`3Ho`006ol00`3oo`0Vo`030?oo0=Wo0008o`80
1?l00`3oo`02o`<01Ol00`3oo`0Vo`030?oo0=Wo0007o`040?oo00_o00<0ool00_l202Oo00<0ool0
fOl000Oo00@0ool02ol00`3oo`02o`030?oo02Go00<0ool0f_l000Oo00@0ool02?l300Go00<0ool0
9Ol00`3oo`3Jo`001ol0103oo`08o`030?oo00Go00<0ool09?l00`3oo`3Ko`001ol0103oo`08o`03
0?oo00Go00<0ool09?l00`3oo`3Ko`002?l200Wo1004o`809?l00`3oo`3Lo`006ol00`3oo`0So`03
0?oo0=co000Ko`030?oo02?o00<0ool0g?l001_o00<0ool08ol00`3oo`3Lo`006ol00`3oo`0Ro`03
0?oo0=go000Ko`808ol00`3oo`3Mo`006ol00`3oo`0Ro`030?oo0=go000Ko`030?oo02;o00<0ool0
gOl001_o00<0ool08_l00`3oo`3Mo`006ol00`3oo`0Qo`030?oo0=ko000Ko`808_l00`3oo`3No`00
6ol00`3oo`0Qo`030?oo0=ko000Ko`030?oo027o00<0ool0g_l001_o00<0ool08?l00`3oo`3Oo`00
6ol00`3oo`0Po`030?oo0=oo000Ko`808Ol00`3oo`3Oo`006ol00`3oo`0Po`030?oo0=oo000Ko`03
0?oo023o00<0ool0gol001_o00<0ool07ol00`3oo`3Po`000_l200Co00<0ool00ol00`3oo`02o`<0
1Ol00`3oo`0Oo`030?oo0>3o00001Ol0ool000Wo00<0ool01Ol00`3oo`02o`808?l00`3oo`3Po`00
00Go0?oo000:o`030?oo00Co00<0ool00_l00`3oo`0Oo`030?oo0>3o00001Ol0ool000[o00@0oooo
0`05o`030?oo01oo00<0ool0h?l00005o`3oo`002ol0103oo`07o`030?oo01ko00<0ool0hOl00005
o`3oo`002?l0103oo`02o`030?oo00Go00<0ool07_l00`3oo`3Qo`000_l200Wo1002o`@01?l201oo
00<0ool0hOl001_o00<0ool07_l00`3oo`3Qo`006ol00`3oo`0Mo`030?oo0>;o000Ko`030?oo01go
00<0ool0h_l001_o00<0ool07Ol00`3oo`3Ro`006ol201ko00<0ool0h_l001_o00<0ool07?l00`3o
o`3So`006ol00`3oo`0Lo`030?oo0>?o000Ko`030?oo01co00<0ool0hol001_o00<0ool07?l00`3o
o`3So`006ol201go00<0ool0hol001_o00<0ool07?l00`3oo`3So`006ol00`3oo`0Lo`030?oo0>?o
000Ko`030?oo01_o00<0ool0i?l001_o00<0ool06ol00`3oo`3To`006ol201co00<0ool0i?l001_o
00<0ool06ol00`3oo`3To`006ol00`3oo`0Ko`030?oo0>Co000Co`@01?l00`3oo`0Ko`030?oo0>Co
000Eo`030?oo00?o00<0ool06ol00`3oo`3To`005Ol00`3oo`03o`807?l00`3oo`3To`005Ol00`3o
o`03o`030?oo01[o00<0ool0iOl001Go00<0ool00ol00`3oo`0Jo`030?oo0>Go000Co`<01Ol00`3o
o`0Jo`030?oo0>Go000Eo`030?oo00?o00<0ool06_l00`3oo`3Uo`006ol201_o00<0ool0iOl001_o
00<0ool06_l00`3oo`3Uo`006ol00`3oo`0Jo`030?oo0>Go000Ko`030?oo01[o00<0ool0iOl001_o
00<0ool06_l00`3oo`3Uo`006ol201_o00<0ool0iOl001_o00<0ool06Ol00`3oo`3Vo`006ol00`3o
o`0Io`030?oo0>Ko000Ko`030?oo01Wo00<0ool0i_l001_o00<0ool06Ol00`3oo`3Vo`006ol201[o
00<0ool0i_l001_o00<0ool06Ol00`3oo`3Vo`006ol00`3oo`0Io`030?oo0>Ko000Ko`030?oo01Wo
00<0ool0i_l001_o00<0ool06Ol00`3oo`3Vo`006ol201[o00<0ool0i_l001_o00<0ool06Ol00`3o
o`3Vo`006ol00`3oo`0Ho`030?oo0>Oo00000ol0000200?o00<0ool00_l400;o0`05o`030?oo01So
00<0ool0iol000?o00<0ool01ol00`3oo`06o`030?oo00;o00<0ool06?l00`3oo`3Wo`000ol00`3o
o`08o`030?oo00Go00<0ool00_l201Wo00<0ool0iol000?o00<0ool02Ol0103oool300Go00<0ool0
6?l00`3oo`3Wo`000ol00`3oo`0:o`040?oo00Oo00<0ool06?l00`3oo`3Wo`0000Co00002Ol0103o
o`02o`030?oo00Go00<0ool06?l00`3oo`3Wo`000ol00`3oo`08o`800ol400Co0P0Io`030?oo0>Oo
000Ko`030?oo01So00<0ool0iol001_o00<0ool06?l00`3oo`3Wo`006ol00`3oo`0Ho`030?oo0>Oo
000Ko`030?oo01So00<0ool0iol001_o0P0Ho`030?oo0>So000Ko`030?oo01Oo00<0ool0j?l001_o
00<0ool05ol00`3oo`3Xo`006ol00`3oo`0Go`030?oo0>So000Ko`030?oo01Oo00<0ool0j?l001_o
0P0Ho`030?oo0>So000Ko`030?oo01Oo00<0ool0j?l001_o00<0ool05ol00`3oo`3Xo`006ol00`3o
o`0Go`030?oo0>So000Ko`030?oo01Oo00<0ool0j?l001_o0P0Ho`030?oo0>So000Ko`030?oo01Oo
00<0ool0j?l001_o00<0ool05ol00`3oo`3Xo`006ol00`3oo`0Go`030?oo0>So0007o`@00ol00`3o
o`02o`<01Ol00`3oo`0Fo`030?oo0>Wo0009o`030?oo00[o00<0ool00_l201Oo00<0ool0jOl000Wo
00<0ool02_l00`3oo`02o`030?oo01Ko00<0ool0jOl000Wo00<0ool01ol300Go00<0ool05_l00`3o
o`3Yo`002Ol00`3oo`07o`030?oo00Go00<0ool05_l00`3oo`3Yo`001ol300Wo00<0ool01Ol00`3o
o`0Fo`030?oo0>Wo0009o`030?oo00Oo1004o`805ol00`3oo`3Yo`006ol00`3oo`3oo`?o000Ko`03
0?oo0?oo0ol001_o00<0ool0ool3o`006ol00`3oo`3oo`?o003oob7o003oob7o003oob7o0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-220.006, -0.162755, 8.07279,
   0.0100948}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.603319 4.78348 [
[.2619 .59082 -9 -9 ]
[.2619 .59082 9 0 ]
[.5 .59082 -12 -9 ]
[.5 .59082 12 0 ]
[.7381 .59082 -12 -9 ]
[.7381 .59082 12 0 ]
[.97619 .59082 -12 -9 ]
[.97619 .59082 12 0 ]
[.01131 .0293 -30 -4.5 ]
[.01131 .0293 0 4.5 ]
[.01131 .12497 -24 -4.5 ]
[.01131 .12497 0 4.5 ]
[.01131 .22064 -30 -4.5 ]
[.01131 .22064 0 4.5 ]
[.01131 .31631 -30 -4.5 ]
[.01131 .31631 0 4.5 ]
[.01131 .41198 -30 -4.5 ]
[.01131 .41198 0 4.5 ]
[.01131 .50765 -30 -4.5 ]
[.01131 .50765 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(500)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(1000)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(1500)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(2000)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .0293 m
.03006 .0293 L
s
[(-0.12)] .01131 .0293 1 0 Mshowa
.02381 .12497 m
.03006 .12497 L
s
[(-0.1)] .01131 .12497 1 0 Mshowa
.02381 .22064 m
.03006 .22064 L
s
[(-0.08)] .01131 .22064 1 0 Mshowa
.02381 .31631 m
.03006 .31631 L
s
[(-0.06)] .01131 .31631 1 0 Mshowa
.02381 .41198 m
.03006 .41198 L
s
[(-0.04)] .01131 .41198 1 0 Mshowa
.02381 .50765 m
.03006 .50765 L
s
[(-0.02)] .01131 .50765 1 0 Mshowa
.125 Mabswid
.02381 .05322 m
.02756 .05322 L
s
.02381 .07714 m
.02756 .07714 L
s
.02381 .10105 m
.02756 .10105 L
s
.02381 .14889 m
.02756 .14889 L
s
.02381 .17281 m
.02756 .17281 L
s
.02381 .19672 m
.02756 .19672 L
s
.02381 .24456 m
.02756 .24456 L
s
.02381 .26848 m
.02756 .26848 L
s
.02381 .29239 m
.02756 .29239 L
s
.02381 .34023 m
.02756 .34023 L
s
.02381 .36415 m
.02756 .36415 L
s
.02381 .38806 m
.02756 .38806 L
s
.02381 .4359 m
.02756 .4359 L
s
.02381 .45981 m
.02756 .45981 L
s
.02381 .48373 m
.02756 .48373 L
s
.02381 .53157 m
.02756 .53157 L
s
.02381 .55548 m
.02756 .55548 L
s
.02381 .5794 m
.02756 .5794 L
s
.02381 .00538 m
.02756 .00538 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .01472 m
.12713 .10595 L
.13597 .1837 L
.15382 .29415 L
.1633 .33607 L
.17345 .37221 L
.19174 .42128 L
.21092 .45778 L
.22904 .48314 L
.24702 .50231 L
.26361 .51625 L
.2819 .52854 L
.29903 .53786 L
.33308 .55191 L
.36798 .56212 L
.40508 .56999 L
.44082 .57564 L
.47519 .57983 L
.51177 .58333 L
.54699 .58602 L
.58441 .58833 L
.62047 .59015 L
.65517 .5916 L
.69207 .5929 L
.72761 .59396 L
.76178 .59484 L
.79816 .59565 L
.83318 .59632 L
.87041 .59694 L
.90627 .59747 L
.94077 .59791 L
.97619 .59832 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o
000Qo`030?oo0?co000Qo`80oOl0027o00<0ool0o?l0027o00<0ool05Ol00`3oo`3To`008Ol00`3o
o`0Eo`030?oo0>Co000Qo`030?oo01Go00<0ool0i?l000So0P04o`030?oo00;o1002o`@01?l00`3o
o`0Eo`030?oo0>Co0007o`040?oo00[o00D0oooo0007o`805_l00`3oo`3To`001ol0103oo`0:o`03
0?oo00;o00<0ool01?l00`3oo`0Eo`030?oo0>Co00000ol0000200;o00@0ool02_l00`3oo`03o`03
0?oo00?o00<0ool05_l00`3oo`3So`001ol0103oo`0:o`030?oo00Co00<0ool00_l00`3oo`0Fo`03
0?oo0>?o0007o`040?oo00So0`03o`040?oo00Co00<0ool05_l00`3oo`3So`002?l200_o00<0ool0
0_l200Go00<0ool05_l00`3oo`3So`008Ol201Oo00<0ool0hol0027o00<0ool05_l00`3oo`3So`00
8Ol00`3oo`0Fo`030?oo0>?o000Qo`030?oo01Ko00<0ool0hol0027o00<0ool05_l00`3oo`3So`00
8Ol00`3oo`0Fo`030?oo0>?o000Qo`805ol00`3oo`3So`008Ol00`3oo`0Fo`030?oo0>?o000Qo`03
0?oo01Oo00<0ool0h_l0027o00<0ool05ol00`3oo`3Ro`008Ol00`3oo`0Go`030?oo0>;o000Qo`03
0?oo01Oo00<0ool0h_l0027o0P0Ho`030?oo0>;o000Qo`030?oo01Oo00<0ool0h_l0027o00<0ool0
5ol00`3oo`3Ro`008Ol00`3oo`0Go`030?oo0>;o000Qo`030?oo01Oo00<0ool0h_l000ko0P04o`03
0?oo00;o1004o`030?oo01Oo00<0ool0h_l000go00@0ool02_l00`3oo`03o`806Ol00`3oo`3Qo`00
3Ol0103oo`0:o`030?oo00?o00<0ool06?l00`3oo`3Qo`001ol400;o00@0ool02_l00`3oo`03o`03
0?oo01So00<0ool0hOl000go00@0ool02_l00`3oo`03o`030?oo01So00<0ool0hOl000go00@0ool0
2?l300Go00<0ool06?l00`3oo`3Qo`003_l200_o00<0ool00ol00`3oo`0Ho`030?oo0>7o000Qo`80
6Ol00`3oo`3Qo`008Ol00`3oo`0Ho`030?oo0>7o000Qo`030?oo01So00<0ool0hOl0027o00<0ool0
6?l00`3oo`3Qo`008Ol00`3oo`0Io`030?oo0>3o000Qo`030?oo01Wo00<0ool0h?l0027o0P0Jo`03
0?oo0>3o000Qo`030?oo01Wo00<0ool0h?l0027o00<0ool06Ol00`3oo`3Po`008Ol00`3oo`0Io`03
0?oo0>3o000Qo`030?oo01Wo00<0ool0h?l0027o00<0ool06Ol00`3oo`3Po`008Ol00`3oo`0Jo`03
0?oo0=oo000Qo`806ol00`3oo`3Oo`008Ol00`3oo`0Jo`030?oo0=oo000Qo`030?oo01[o00<0ool0
gol0027o00<0ool06_l00`3oo`3Oo`002?l200Co00<0ool00ol200Co0P05o`030?oo01[o00<0ool0
gol000Oo00@0ool02?l0103oo`02o`040?oo00Co00<0ool06ol00`3oo`3No`001ol0103oo`08o`04
0?oo00;o00@0ool01?l201co00<0ool0g_l00003o`0000800_l0103oo`08o`040?oo00?o0P05o`03
0?oo01_o00<0ool0g_l000Oo00@0ool02?l0103oo`02o`040?oo00Co00<0ool06ol00`3oo`3No`00
1ol0103oo`08o`040?oo00;o00@0ool01?l00`3oo`0Ko`030?oo0=ko0008o`802_l200Co0P05o`03
0?oo01co00<0ool0gOl0027o00<0ool07?l00`3oo`3Mo`008Ol201go00<0ool0gOl0027o00<0ool0
7?l00`3oo`3Mo`008Ol00`3oo`0Lo`030?oo0=go000Qo`030?oo01co00<0ool0gOl0027o00<0ool0
7Ol00`3oo`3Lo`008Ol00`3oo`0Mo`030?oo0=co000Qo`807_l00`3oo`3Lo`008Ol00`3oo`0Mo`03
0?oo0=co000Qo`030?oo01go00<0ool0g?l0027o00<0ool07Ol00`3oo`3Lo`008Ol00`3oo`0No`03
0?oo0=_o000Qo`030?oo01ko00<0ool0fol0027o0P0Oo`030?oo0=_o000Qo`030?oo01ko00<0ool0
fol0027o00<0ool07_l00`3oo`3Ko`008Ol00`3oo`0Oo`030?oo0=[o000Qo`030?oo01oo00<0ool0
f_l000So0P04o`030?oo00?o0P04o`801Ol00`3oo`0Oo`030?oo0=[o0007o`040?oo00So00@0ool0
0_l0103oo`04o`808?l00`3oo`3Jo`001ol0103oo`08o`040?oo00;o00@0ool01?l00`3oo`0Oo`03
0?oo0=[o00000ol0000200;o00@0ool02?l0103oo`02o`<01Ol00`3oo`0Oo`030?oo0=[o0007o`04
0?oo00So00@0ool00_l00`3oo`05o`030?oo023o00<0ool0fOl000Oo00@0ool02?l0103oo`02o`03
0?oo00Go00<0ool08?l00`3oo`3Io`002?l200[o0P04o`<01?l00`3oo`0Po`030?oo0=Wo000Qo`80
8Ol00`3oo`3Io`008Ol00`3oo`0Qo`030?oo0=So000Qo`030?oo027o00<0ool0f?l0027o00<0ool0
8Ol00`3oo`3Ho`008Ol00`3oo`0Ro`030?oo0=Oo000Qo`030?oo02;o00<0ool0eol0027o0P0So`03
0?oo0=Oo000Qo`030?oo02?o00<0ool0e_l0027o00<0ool08ol00`3oo`3Fo`008Ol00`3oo`0So`03
0?oo0=Ko000Qo`030?oo02Co00<0ool0eOl0027o00<0ool09?l00`3oo`3Eo`008Ol202Go00<0ool0
eOl0027o00<0ool09Ol00`3oo`3Do`008Ol00`3oo`0Uo`030?oo0=Co000Qo`030?oo02Go00<0ool0
e?l0027o00<0ool09Ol00`3oo`3Do`002?l200Co00<0ool00ol200Go00<0ool00ol00`3oo`0Vo`03
0?oo0=?o0007o`040?oo00So00@0ool01?l00`3oo`03o`809ol00`3oo`3Co`001ol0103oo`08o`05
0?oo0?l01@04o`030?oo02Ko00<0ool0dol00003o`0000800_l0103oo`08o`060?oo0?l00_l00`3o
o`03o`030?oo02Oo00<0ool0d_l000Oo00@0ool02?l0103oo`02o`030?l000Go00<0ool09ol00`3o
o`3Bo`001ol0103oo`08o`040?oo00?o0P05o`030?oo02So00<0ool0dOl000So0P0:o`801Ol00`3o
o`03o`030?oo02So00<0ool0dOl0027o0P0Zo`030?oo0=3o000Qo`030?oo02Wo00<0ool0d?l0027o
00<0ool0:_l00`3oo`3?o`008Ol00`3oo`0Zo`030?oo0<oo000Qo`030?oo02_o00<0ool0c_l0027o
00<0ool0:ol00`3oo`3>o`008Ol202go00<0ool0cOl0027o00<0ool0;Ol00`3oo`3<o`008Ol00`3o
o`0^o`030?oo0<_o000Qo`030?oo02oo00<0ool0b_l0027o00<0ool0;ol00`3oo`3:o`008Ol00`3o
o`0`o`030?oo0<Wo000Qo`80<_l00`3oo`38o`008Ol00`3oo`0bo`030?oo0<Oo000Qo`030?oo03?o
00<0ool0a_l0027o00<0ool0<ol00`3oo`36o`008Ol00`3oo`0do`030?oo0<Go0008o`801?l00`3o
o`03o`800ol400Co00<0ool0=Ol00`3oo`34o`001ol0103oo`08o`040?oo00;o00<0ool01Ol203Oo
00<0ool0`ol000Oo00@0ool02?l0103oo`03o`030?oo00Co00<0ool0=ol20<?o00000ol0000200;o
00@0ool02?l0103oo`04o`030?oo00?o00<0ool0>Ol00`3oo`30o`001ol0103oo`08o`040?oo00Go
00<0ool00_l00`3oo`0jo`030?oo0;oo0007o`040?oo00So00@0ool00_l0103oo`04o`030?oo03_o
00<0ool0__l000So0P0:o`801?l200Go00<0ool0??l20;ko000Qo`030?oo03ko0P2lo`008Ol2047o
0P2jo`008Ol00`3oo`12o`80^?l0027o00<0ool0A?l20;Ko000Qo`030?oo04Ko0P2do`008Ol00`3o
o`18o`80/_l0027o00<0ool0B_l40:ko000Qo`80Col40:[o000Qo`030?oo05;o1@2Uo`008Ol00`3o
o`1Go`@0XOl0027o00<0ool0<Ol300Co0P04o`806ol500_o1003o`801?l200Co0P0Wo`@00_l300Co
0P04o`80:?l400?o0P04o`801?l200?o000Qo`030?oo03Co00@0ool00_l0103oo`02o`030?oo01go
1@08o`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool09_l00`3oo`04o`040?oo00;o00@0ool0
0_l00`3oo`0Uo`030?oo00?o00@0ool00_l0103oo`02o`040?oo00;o000Qo`030?oo03Co00@0ool0
0_l0103oo`02o`030?oo02;o1P02o`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool09_l00`3o
o`04o`040?oo00;o00@0ool00_l00`3oo`0Vo`030?oo00;o00@0ool00_l0103oo`02o`040?oo00;o
000Qo`80<_l300?o00@0ool00_l0103oo`0Zo`X00_l0103oo`02o`040?oo02So00@0oooo0`03o`04
0?oo00;o00@0ool0:Ol01@3oool000;o00@0ool00_l0103oo`02o`400Ol1o`008Ol00`3oo`0ao`03
0?oo00?o00@0ool00_l0103oo`0/o`050?ooo`000_lC02;o00D0oooo0005o`040?oo00;o00@0ool0
:_l0103oo`02o`040?oo00;o00@0ool00_l1007o0Ol0027o00<0ool0<Ol00`3oo`03o`040?oo00;o
00@0ool0:_l300?o00@0ool00_l0103oo`02o`040?oo00Ko4P0>o`<00ol00`3oo`03o`040?oo00;o
00@0ool09ol0103oo`02o`040?oo00;o00@0ool00_l0103oo`02o`008Ol00`3oo`0ao`@00ol200Co
0P0]o`030?oo00;o0P04o`801?l201Wo7@04o`80:Ol200Co0P04o`801?l200?o000Qo`030?oo0;Co
?00<o`008Ol00`3oo`3lo`006ooo00Ko000Qo`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Wo
00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00[o00<0ool02Ol00`3o
o`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Wo
00<0ool02_l00`3oo`0:o`008Ol00`3oo`3lo`008Ol00`3oo`3lo`00oolQo`00oolQo`00oolQo`00
oolQo`00oolQo`00oolQo`00oolQo`00oolQo`00oolQo`00oolQo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-274.374, -0.134363, 8.27049,
   0.000823318}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(kksu5a = 
      Plot[\n\t\t
        \((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) 
          dmk[0.00815, 30, 100, mgt, 1.001, mgt, 100, Sqrt[5] ep^6, 0, 
            Sqrt[5] ep^8, Sqrt[5] ep^\((12)\)], \n\t\t{mgt, 200, 2000}]\), 
    \(kksu5i = 
      Plot[\n\t\t
        \((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) 
          dmk[0.00815, 30, 200, mgt, 4.5, mgt, 0, ep^6/Sqrt[5], 0, 
            ep^8/Sqrt[5], ep^\((12)\)/Sqrt[5]], \n\t\t{mgt, 200, 2000}]\)}], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.0147151 14318.2 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -12 -9 ]
[.5 .00222 12 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .1579 -42 -4.5 ]
[.01131 .1579 0 4.5 ]
[.01131 .30108 -42 -4.5 ]
[.01131 .30108 0 4.5 ]
[.01131 .44426 -42 -4.5 ]
[.01131 .44426 0 4.5 ]
[.01131 .58744 -42 -4.5 ]
[.01131 .58744 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(500)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1000)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1500)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1579 m
.03006 .1579 L
s
[(0.00001)] .01131 .1579 1 0 Mshowa
.02381 .30108 m
.03006 .30108 L
s
[(0.00002)] .01131 .30108 1 0 Mshowa
.02381 .44426 m
.03006 .44426 L
s
[(0.00003)] .01131 .44426 1 0 Mshowa
.02381 .58744 m
.03006 .58744 L
s
[(0.00004)] .01131 .58744 1 0 Mshowa
.125 Mabswid
.02381 .04335 m
.02756 .04335 L
s
.02381 .07199 m
.02756 .07199 L
s
.02381 .10062 m
.02756 .10062 L
s
.02381 .12926 m
.02756 .12926 L
s
.02381 .18653 m
.02756 .18653 L
s
.02381 .21517 m
.02756 .21517 L
s
.02381 .24381 m
.02756 .24381 L
s
.02381 .27244 m
.02756 .27244 L
s
.02381 .32971 m
.02756 .32971 L
s
.02381 .35835 m
.02756 .35835 L
s
.02381 .38699 m
.02756 .38699 L
s
.02381 .41562 m
.02756 .41562 L
s
.02381 .4729 m
.02756 .4729 L
s
.02381 .50153 m
.02756 .50153 L
s
.02381 .53017 m
.02756 .53017 L
s
.02381 .55881 m
.02756 .55881 L
s
.02381 .61608 m
.02756 .61608 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .60332 m
.12713 .50066 L
.13597 .41651 L
.14521 .35019 L
.15382 .30224 L
.17214 .22926 L
.1824 .19997 L
.19174 .17825 L
.20897 .14708 L
.22768 .12235 L
.24553 .10468 L
.26446 .0903 L
.29851 .07184 L
.31598 .06488 L
.33477 .05871 L
.37187 .04944 L
.40761 .04301 L
.44198 .03837 L
.47856 .03457 L
.51378 .03171 L
.5512 .02929 L
.58726 .02741 L
.62196 .02593 L
.65886 .02462 L
.6944 .02356 L
.72857 .02269 L
.76496 .02189 L
.79997 .02124 L
.8372 .02063 L
.87306 .02013 L
.90756 .0197 L
.94426 .01929 L
.97619 .01898 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o
003oob7o003oob7o003oob7o001No`<01?l200Co0P0Xo`@00ol200Co0P04o`809?l400;o0`04o`80
1?l202Go1003o`801?l200Co0P03o`00HOl0103oo`02o`040?oo00;o00<0ool09ol01@3oool000;o
00@0ool00_l0103oo`02o`030?oo02?o00<0ool01?l0103oo`02o`040?oo00;o00<0ool08_l00`3o
o`03o`040?oo00;o00@0ool00_l0103oo`02o`00HOl0103oo`02o`040?oo00;o00<0ool09ol01@3o
ool000;o00@0ool00_l0103oo`02o`030?oo02?o00<0ool01?l0103oo`02o`040?oo00;o00<0ool0
8ol00`3oo`02o`040?oo00;o00@0ool00_l0103oo`02o`00G_l300?o00@0ool00_l0103oo`0Yo`05
0?ooo`000_l0103oo`02o`040?oo00;o00<0ool08ol0103oool300?o00@0ool00_l0103oo`0Vo`05
0?ooo`000_l0103oo`02o`040?oo00;o0@01o`7o001No`030?oo00?o00@0ool00_l0103oo`0Yo`05
0?ooo`000_l0103oo`02o`040?oo00;o00<0ool08ol01@3oool000Go00@0ool00_l0103oo`0Wo`04
0?oo00;o00@0ool00_l0103oo`02o`400Ol1o`00;Ol00`3oo`0^o`030?oo00?o00@0ool00_l0103o
o`0Wo`<00ol0103oo`02o`040?oo00;o00@0ool08ol300?o00<0ool00ol0103oo`02o`040?oo02Co
00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l002go00<0ool0;_l400?o0P04o`80:_l00`3o
o`02o`801?l200Co0P0Vo`040?ooo`@00ol200Co0P0Vo`801?l200Co0P04o`800ol002go00<0ool0
l?l002OolP07o`00;Ol00`3oo`08o`030?oo00Wo00<0ool02?l00`3oo`09o`030?oo00So00<0ool0
2Ol00`3oo`08o`030?oo00Wo00<0ool02?l00`3oo`09o`030?oo00So00<0ool02Ol00`3oo`08o`03
0?oo00Wo00<0ool02?l00`3oo`09o`030?oo00So00<0ool02Ol00`3o000E00co000]o`030?oo03Ko
00<0ool0=ol00`3oo`0Woc@05Ol00`3oo`0:o`00;Ol00`3oo`21oaT0E_l002go00<0ool0KolB06oo
000]o`030?oo06Ko2@21o`00;Ol00`3oo`1No`P0R_l002go00<0ool0Eol709;o000]o`030?oo05?o
102Io`00;Ol00`3oo`1?o`@0WOl002go00<0ool0Bol40:7o000]o`030?oo04Ko1@2Uo`00;Ol00`3o
o`12o`@0Z_l002go00<0ool0@?l20:ko000]o`030?oo03ko0P2`o`00;Ol00`3oo`0lo`80/_l002go
00<0ool0>_l20;Co000]o`030?oo03So0P2fo`00;Ol00`3oo`0go`030?oo0;Ko000]o`030?oo03Ko
00<0ool0]ol002go00<0ool0=?l20;[o000]o`030?oo03?o00<0ool0^_l002go00<0ool0<_l00`3o
o`2ko`00;Ol00`3oo`0ao`030?oo0;co000]o`030?oo033o00<0ool0_Ol002go00<0ool0;ol00`3o
o`2no`00;Ol00`3oo`0^o`030?oo0;oo000]o`030?oo02go00<0ool0`?l002go00<0ool0;?l00`3o
o`31o`00;Ol00`3oo`0/o`030?oo0<7o000]o`030?oo02_o00<0ool0`_l002go00<0ool0:_l00`3o
o`33o`00;Ol00`3oo`0Yo`030?oo0<Co0002o`801?l00`3oo`03o`801?l200Co0P04o`800ol400Co
00<0ool0:Ol00`3oo`34o`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00Co
00<0ool00ol00`3oo`0Xo`030?oo0<Go00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00;o
00@0ool01?l00`3oo`03o`80:Ol00`3oo`35o`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103o
o`02o`040?oo00Co00<0ool00ol00`3oo`0Wo`030?oo0<Ko00001Ol0ool000So00@0ool00_l0103o
o`02o`040?oo00;o00@0ool01?l00`3oo`03o`030?oo02Oo00<0ool0a_l00005o`3oo`002?l0103o
o`02o`040?oo00;o00@0ool00_l0103oo`02o`<01Ol00`3oo`0Vo`030?oo0<Oo0002o`802_l200Co
0P04o`801?l200Go00<0ool00ol00`3oo`0Vo`030?oo0<Oo000]o`030?oo02Go00<0ool0b?l002go
00<0ool09Ol00`3oo`38o`00;Ol00`3oo`0To`030?oo0<Wo000]o`030?oo02Co00<0ool0bOl002go
00<0ool08ol00`3oo`3:o`00;Ol00`3oo`0So`030?oo0<[o000]o`030?oo02?o00<0ool0b_l002go
00<0ool08_l00`3oo`3;o`00;Ol00`3oo`0Ro`030?oo0<_o000]o`030?oo027o00<0ool0c?l002go
00<0ool08Ol00`3oo`3<o`00;Ol00`3oo`0Po`030?oo0<go000]o`030?oo023o00<0ool0cOl002go
00<0ool08?l00`3oo`3=o`00;Ol00`3oo`0Po`030?oo0<go000]o`030?oo01oo00<0ool0c_l002go
00<0ool07ol00`3oo`3>o`00;Ol00`3oo`0Oo`030?oo0<ko000]o`030?oo01oo00<0ool0c_l002go
00<0ool07_l00`3oo`3?o`00;Ol00`3oo`0No`030?oo0<oo000]o`030?oo01ko00<0ool0col002go
00<0ool07_l00`3oo`3?o`00;Ol00`3oo`0No`030?oo0<oo000]o`030?oo01go00<0ool0d?l002go
00<0ool07Ol00`3oo`3@o`00;Ol00`3oo`0Mo`030?oo0=3o000]o`030?oo01go00<0ool0d?l000;o
0P04o`030?oo00?o0P04o`801?l200Co0P03o`@01?l00`3oo`0Lo`030?oo0=7o00001Ol0ool000So
00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l00`3oo`05o`807Ol00`3oo`3Ao`0000Go0?oo
0008o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00?o00<0ool01?l00`3oo`0Lo`030?oo0=7o
00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00;o00@0ool01?l00`3oo`03o`030?oo01co
00<0ool0dOl00005o`3oo`002?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`05o`030?oo00;o
00<0ool07?l00`3oo`3Ao`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00;o
00@0ool01?l00`3oo`0Ko`030?oo0=;o0002o`802_l200Co0P04o`801?l200Co0P05o`030?oo01_o
00<0ool0d_l002go00<0ool06ol00`3oo`3Bo`00;Ol00`3oo`0Ko`030?oo0=;o000]o`030?oo01_o
00<0ool0d_l002go00<0ool06ol00`3oo`3Bo`00;Ol00`3oo`0Jo`030?oo0=?o000]o`030?oo01[o
00<0ool0dol002go00<0ool06_l00`3oo`3Co`00;Ol00`3oo`0Jo`030?oo0=?o000]o`030?oo01[o
00<0ool0dol002go00<0ool06_l00`3oo`3Co`00;Ol00`3oo`0Jo`030?oo0=?o000]o`030?oo01Wo
00<0ool0e?l002go00<0ool06Ol00`3oo`3Do`00;Ol00`3oo`0Io`030?oo0=Co000]o`030?oo01Wo
00<0ool0e?l002go00<0ool06Ol00`3oo`3Do`00;Ol00`3oo`0Io`030?oo0=Co000]o`030?oo01Wo
00<0ool0e?l002go00<0ool06Ol00`3oo`3Do`00;Ol00`3oo`0Ho`030?oo0=Go000]o`030?oo01So
00<0ool0eOl002go00<0ool06?l00`3oo`3Eo`00;Ol00`3oo`0Ho`030?oo0=Go000]o`030?oo01So
00<0ool0eOl002go00<0ool06?l00`3oo`3Eo`00;Ol00`3oo`0Ho`030?oo0=Go000]o`030?oo01Oo
00<0ool0e_l002go00<0ool05ol00`3oo`3Fo`000_l200Co00<0ool00ol200Co0P04o`801?l200Co
0P05o`030?oo01Oo00<0ool0e_l00005o`3oo`002?l0103oo`02o`040?oo00;o00@0ool00_l0103o
o`02o`040?oo00Co0P0Ho`030?oo0=Ko00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00;o
00@0ool01Ol00`3oo`02o`030?oo01Oo00<0ool0e_l00005o`3oo`002?l0103oo`02o`040?oo00;o
00@0ool00_l0103oo`03o`801Ol00`3oo`0Go`030?oo0=Ko00001Ol0ool000So00@0ool00_l0103o
o`02o`040?oo00;o00@0ool01Ol00`3oo`02o`030?oo01Oo00<0ool0e_l00005o`3oo`002?l0103o
o`02o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00Co00<0ool05_l00`3oo`3Go`000_l200[o
0P04o`801?l200Co0P04o`801Ol00`3oo`0Fo`030?oo0=Oo000]o`030?oo01Ko00<0ool0eol002go
00<0ool05_l00`3oo`3Go`00;Ol00`3oo`0Fo`030?oo0=Oo000]o`030?oo01Ko00<0ool0eol002go
00<0ool05_l00`3oo`3Go`00;Ol00`3oo`0Eo`030?oo0=So000]o`030?oo01Go00<0ool0f?l002go
00<0ool05Ol00`3oo`3Ho`00;Ol00`3oo`0Eo`030?oo0=So000]o`030?oo01Go00<0ool0f?l002go
00<0ool05Ol00`3oo`3Ho`00;Ol00`3oo`0Eo`030?oo0=So000]o`030?oo01Go00<0ool0f?l002go
00<0ool05Ol00`3oo`3Ho`00;Ol00`3oo`0Eo`030?oo0=So000]o`030?oo01Go00<0ool0f?l002go
00<0ool05Ol00`3oo`3Ho`00;Ol00`3oo`0Eo`030?oo0=So000]o`030?oo01Go00<0ool0f?l002go
00<0ool05Ol00`3oo`3Ho`00;Ol00`3oo`0Eo`030?oo0=So000]o`030?oo01Co00<0ool0fOl002go
00<0ool05?l00`3oo`3Io`00;Ol00`3oo`0Do`030?oo0=Wo000]o`030?oo01Co00<0ool0fOl002go
00<0ool05?l00`3oo`3Io`00;Ol00`3oo`0Do`030?oo0=Wo0002o`801?l00`3oo`03o`801?l200Co
0P04o`801Ol00`3oo`03o`030?oo01Co00<0ool0fOl00005o`3oo`002?l0103oo`02o`040?oo00;o
00@0ool00_l0103oo`04o`030?oo00?o0P0Eo`030?oo0=Wo00001Ol0ool000So00@0ool00_l0103o
o`02o`040?oo00;o00D0ool0o`0500Co00<0ool05?l00`3oo`3Io`0000Go0?oo0008o`040?oo00;o
00@0ool00_l0103oo`02o`060?oo0?l00_l00`3oo`03o`030?oo01Co00<0ool0fOl00005o`3oo`00
2?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`02o`030?l000Go00<0ool05?l00`3oo`3Io`00
00Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00?o0P05o`030?oo01Co00<0ool0
fOl000;o0P0:o`801?l200Co0P04o`801Ol00`3oo`03o`030?oo0?3o000]o`030?oo0?3o000]o`03
0?oo0?3o000]o`030?oo0?3o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o
003oob7o003oob7o0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-391.51, -6.25695*^-6, 
  8.69644, 2.89223*^-7}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.603319 179752 [
[.2619 .59082 -9 -9 ]
[.2619 .59082 9 0 ]
[.5 .59082 -12 -9 ]
[.5 .59082 12 0 ]
[.7381 .59082 -12 -9 ]
[.7381 .59082 12 0 ]
[.97619 .59082 -12 -9 ]
[.97619 .59082 12 0 ]
[.01131 .06406 -39 -6.25 ]
[.01131 .06406 0 6.25 ]
[.01131 .15394 -51 -6.25 ]
[.01131 .15394 0 6.25 ]
[.01131 .24381 -39 -6.25 ]
[.01131 .24381 0 6.25 ]
[.01131 .33369 -51 -6.25 ]
[.01131 .33369 0 6.25 ]
[.01131 .42357 -39 -6.25 ]
[.01131 .42357 0 6.25 ]
[.01131 .51344 -39 -6.25 ]
[.01131 .51344 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(500)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(1000)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(1500)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(2000)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .06406 m
.03006 .06406 L
s
gsave
.01131 .06406 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .15394 m
.03006 .15394 L
s
gsave
.01131 .15394 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .24381 m
.03006 .24381 L
s
gsave
.01131 .24381 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .33369 m
.03006 .33369 L
s
gsave
.01131 .33369 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .42357 m
.03006 .42357 L
s
gsave
.01131 .42357 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .51344 m
.03006 .51344 L
s
gsave
.01131 .51344 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.125 Mabswid
.02381 .08204 m
.02756 .08204 L
s
.02381 .10001 m
.02756 .10001 L
s
.02381 .11799 m
.02756 .11799 L
s
.02381 .13596 m
.02756 .13596 L
s
.02381 .17191 m
.02756 .17191 L
s
.02381 .18989 m
.02756 .18989 L
s
.02381 .20786 m
.02756 .20786 L
s
.02381 .22584 m
.02756 .22584 L
s
.02381 .26179 m
.02756 .26179 L
s
.02381 .27976 m
.02756 .27976 L
s
.02381 .29774 m
.02756 .29774 L
s
.02381 .31571 m
.02756 .31571 L
s
.02381 .35167 m
.02756 .35167 L
s
.02381 .36964 m
.02756 .36964 L
s
.02381 .38762 m
.02756 .38762 L
s
.02381 .40559 m
.02756 .40559 L
s
.02381 .44154 m
.02756 .44154 L
s
.02381 .45952 m
.02756 .45952 L
s
.02381 .47749 m
.02756 .47749 L
s
.02381 .49547 m
.02756 .49547 L
s
.02381 .53142 m
.02756 .53142 L
s
.02381 .54939 m
.02756 .54939 L
s
.02381 .56737 m
.02756 .56737 L
s
.02381 .58534 m
.02756 .58534 L
s
.02381 .04609 m
.02756 .04609 L
s
.02381 .02811 m
.02756 .02811 L
s
.02381 .01014 m
.02756 .01014 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .01472 m
.12713 .10595 L
.13597 .1837 L
.15382 .29415 L
.1633 .33607 L
.17345 .37221 L
.19174 .42128 L
.21092 .45778 L
.22904 .48314 L
.24702 .50231 L
.26361 .51625 L
.2819 .52854 L
.29903 .53786 L
.33308 .55191 L
.36798 .56212 L
.40508 .56999 L
.44082 .57564 L
.47519 .57983 L
.51177 .58333 L
.54699 .58602 L
.58441 .58833 L
.62047 .59015 L
.65517 .5916 L
.69207 .5929 L
.72761 .59396 L
.76178 .59484 L
.79816 .59565 L
.83318 .59632 L
.87041 .59694 L
.90627 .59747 L
.94077 .59791 L
.97619 .59832 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o
003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o000eo`030?oo0>So000eo`030?oo0>So
000eo`030?oo0>So000eo`80jOl003Go00<0ool05?l00`3oo`3Ao`00=Ol00`3oo`0Do`030?oo0=7o
000eo`030?oo01Co00<0ool0dOl003Go0P0Eo`030?oo0=7o000eo`030?oo01Co00<0ool0dOl003Go
00<0ool05?l00`3oo`3Ao`00=Ol00`3oo`0Do`030?oo0=7o000eo`805Ol00`3oo`3Ao`005?l200?o
00@0ool00ol400?o0P0<o`030?oo01Co00<0ool0dOl001?o00@0ool00ol00`3o0005o`050?ooo`00
0_l00`3oo`09o`030?oo01Co00<0ool0dOl001Ko00<0ool00_l00`3oo`04o`050?ooo`000_l00`3o
o`09o`030?oo01Co00<0ool0dOl000go1003o`800ol20003o`3o00Co00D0oooo0002o`030?oo00Wo
0`0Eo`030?oo0=3o000Fo`040?oo00;o00<0ool00ol01@3oool000;o00<0ool01_l0103oo`0Go`03
0?oo0=3o000Co`040?oo00Wo0`03o`040?oo00Oo00D0o`3o000Go`030?oo0=3o000Do`803?l00`3o
o`02o`802?l01@3o0?l001Oo00<0ool0d?l002co0`02o`<000?o00005_l00`3oo`3@o`00<Ol01@3o
ool001Oo00<0ool0d?l003;o00@0ool05ol00`3oo`3@o`00=Ol00`3oo`0Eo`030?oo0=3o000eo`03
0?oo01Go00<0ool0d?l003Go0P0Fo`030?oo0=3o000eo`030?oo01Go00<0ool0d?l003Go00<0ool0
5Ol00`3oo`3@o`00=Ol00`3oo`0Eo`030?oo0=3o000eo`805_l00`3oo`3@o`00=Ol00`3oo`0Eo`03
0?oo0=3o000eo`030?oo01Ko00<0ool0col003Go00<0ool05_l00`3oo`3?o`00=Ol201Oo00<0ool0
col000Oo1003o`030?oo00;o0`03o`040?oo00?o1003o`803?l00`3oo`0Fo`030?oo0<oo0007o`03
0?oo00co00L0oooo0?l000Go00D0oooo0002o`030?oo00Wo00<0ool05_l00`3oo`3?o`002?l00`3o
o`0;o`030?oo00;o00<0ool01?l01@3oool000;o00<0ool02Ol00`3oo`0Fo`030?oo0<oo00000ol0
000200Co00<0ool01ol300?o0P000ol0o`04o`050?ooo`000_l00`3oo`09o`<05_l00`3oo`3?o`00
2_l00`3oo`06o`030?oo00?o00@0ool01Ol01@3oool000;o00<0ool01_l0103oo`0Ho`030?oo0<oo
0007o`040?oo00So00<0ool02_l300?o00@0ool01ol01@3o0?l001So00<0ool0col000So0P09o`@0
2ol00`3oo`02o`802?l01@3o0?l001Wo00<0ool0c_l002co0`02o`<000?o00006?l00`3oo`3>o`00
<Ol01@3oool001Wo00<0ool0c_l003;o00@0ool06Ol00`3oo`3>o`00=Ol00`3oo`0Go`030?oo0<ko
000eo`806?l00`3oo`3>o`00=Ol00`3oo`0Go`030?oo0<ko000eo`030?oo01So00<0ool0cOl003Go
00<0ool06?l00`3oo`3=o`00=Ol00`3oo`0Ho`030?oo0<go000eo`806Ol00`3oo`3=o`00=Ol00`3o
o`0Ho`030?oo0<go000eo`030?oo01Wo00<0ool0c?l003Go00<0ool06Ol00`3oo`3<o`00=Ol201[o
00<0ool0c?l001?o1002o`040?oo00?o1003o`803?l00`3oo`0Io`030?oo0<co000Co`030?oo00Co
00<0o`001Ol01@3oool000;o00<0ool02Ol00`3oo`0Io`030?oo0<co000Do`030?oo00Co00<0ool0
1?l01@3oool000;o00<0ool02Ol00`3oo`0Jo`030?oo0<_o000=o`@01?l0103oool20003o`3o00Co
00D0oooo0002o`030?oo00Wo0`0Jo`030?oo0<_o000Fo`040?oo00;o00<0ool00ol01@3oool000;o
00<0ool01_l0103oo`0Lo`030?oo0<_o000Co`040?oo00Wo0`03o`040?oo00Oo00D0o`3o000Lo`03
0?oo0<_o000Do`803?l00`3oo`02o`802?l01@3o0?l001co00<0ool0bol002co0`02o`<000?o0000
6ol00`3oo`3;o`00<Ol01@3oool001go00<0ool0b_l003;o00@0ool07Ol00`3oo`3:o`00=Ol00`3o
o`0Ko`030?oo0<[o000eo`807?l00`3oo`3:o`00=Ol00`3oo`0Ko`030?oo0<[o000eo`030?oo01co
00<0ool0bOl003Go00<0ool07?l00`3oo`39o`00=Ol201go00<0ool0bOl003Go00<0ool07?l00`3o
o`39o`00=Ol00`3oo`0Lo`030?oo0<Wo000eo`030?oo01go00<0ool0b?l003Go00<0ool07Ol00`3o
o`38o`00=Ol201ko00<0ool0b?l000Oo1003o`030?oo00;o0`03o`040?oo00?o1003o`803?l00`3o
o`0Mo`030?oo0<So0009o`030?oo00[o00L0oooo0?l000Go00D0oooo0002o`030?oo00Wo00<0ool0
7_l00`3oo`37o`002Ol00`3oo`0:o`030?oo00;o00<0ool01?l01@3oool000;o00<0ool02Ol00`3o
o`0No`030?oo0<Oo00000ol0000200Co00<0ool01ol300?o0P000ol0o`04o`050?ooo`000_l00`3o
o`09o`<07_l00`3oo`37o`002Ol00`3oo`07o`030?oo00?o00@0ool01Ol01@3oool000;o00<0ool0
1_l0103oo`0Po`030?oo0<Oo0007o`<02Ol00`3oo`0:o`<00ol0103oo`07o`050?l0o`008?l00`3o
o`37o`002Ol00`3oo`07o`@02ol00`3oo`02o`802?l01@3o0?l0027o00<0ool0a_l002co0`02o`<0
00?o00008?l00`3oo`36o`00<Ol01@3oool0027o00<0ool0a_l003;o00@0ool08Ol00`3oo`36o`00
=Ol00`3oo`0Po`030?oo0<Go000eo`808Ol00`3oo`35o`00=Ol00`3oo`0Po`030?oo0<Go000eo`03
0?oo023o00<0ool0aOl003Go00<0ool08Ol00`3oo`34o`00=Ol202;o00<0ool0a?l003Go00<0ool0
8Ol00`3oo`34o`00=Ol00`3oo`0Ro`030?oo0<?o000eo`030?oo02;o00<0ool0`ol003Go0P0To`03
0?oo0<;o000Co`@00_l0103oo`03o`@00ol200co00<0ool08ol00`3oo`32o`005Ol00`3oo`02o`03
0?l000Go00D0oooo0002o`030?oo00Wo00<0ool08ol00`3oo`32o`005Ol00`3oo`03o`030?oo00Co
00D0oooo0002o`030?oo00Wo00<0ool09?l00`3oo`31o`003Ol400Co00@0oooo0P000ol0o`04o`05
0?ooo`000_l00`3oo`09o`030?oo02Co00<0ool0`Ol001Go00D0oooo0002o`030?oo00?o00D0oooo
0002o`030?oo00Wo0`0Uo`030?oo0<3o000Co`<02_l300?o00@0ool02?l0103oo`0Wo`030?oo0<3o
000Eo`030?oo00[o00<0ool00_l200So00D0o`3o000Xo`030?oo0;oo000ao`050?l0o`00:?l00`3o
o`2oo`00;?l300;o0`000ol0000Xo`030?oo0;ko000ao`050?ooo`00:Ol00`3oo`2no`00<_l0103o
o`0Zo`030?oo0;go000eo`030?oo02So00<0ool0_Ol003Go0P0Zo`030?oo0;co000eo`030?oo02[o
00<0ool0^ol003Go00<0ool0:ol00`3oo`2jo`00=Ol00`3oo`0[o`030?oo0;[o000eo`80;Ol00`3o
o`2io`00=Ol00`3oo`0]o`030?oo0;So000eo`030?oo02ko00<0ool0]ol003Go00<0ool0;ol00`3o
o`2fo`00=Ol2033o00<0ool0]_l001?o0`03o`040?oo00?o1003o`803?l00`3oo`0`o`030?oo0;Go
000Fo`070?ooo`3o0005o`050?ooo`000_l00`3oo`09o`030?oo037o00<0ool0]?l001Ko00<0ool0
0_l00`3oo`04o`050?ooo`000_l00`3oo`09o`030?oo03;o00<0ool0/ol000go1002o`<00ol20003
o`3o00Co00D0oooo0002o`030?oo00Wo0`0co`80/ol001?o00<0ool00ol0103oo`05o`050?ooo`00
0_l00`3oo`09o`030?oo03Go00<0ool0/?l001?o00<0ool02_l300?o00@0ool02?l0103oo`0ho`03
0?oo0:oo000Co`@02ol00`3oo`02o`802Ol0103oo`0io`80[ol002co0`03o`040?oo03_o00<0ool0
[?l003?o00@0o`00>ol20:co000bo`8000?o0?l0?Ol30:Wo000eo`030?oo03oo0P2Wo`00=Ol00`3o
o`11o`<0Y?l003Go0P15o`<0XOl003Go00<0ool0Aol209oo000eo`030?oo04Wo0`2Lo`00=Ol00`3o
o`1<o`@0V?l003Go0P0^o`<01?l200Co0P0Do`@03Ol400?o0P04o`801?l202;o1002o`<01?l200Co
0P0So`@00ol200Co0P04o`800ol003Go00<0ool0<?l0103oo`02o`040?oo00;o00<0ool05Ol600Wo
00D0oooo0002o`040?oo00;o00@0ool00_l00`3oo`0Qo`030?oo00Co00@0ool00_l0103oo`02o`03
0?oo023o00<0ool00ol0103oo`02o`040?oo00;o00@0ool00_l003Go00<0ool0<?l0103oo`02o`04
0?oo00;o00<0ool06ol80003o`3o00;o00@0ool00_l0103oo`02o`040?oo02?o00<0ool01?l0103o
o`02o`040?oo00;o00<0ool08Ol00`3oo`02o`040?oo00;o00@0ool00_l0103oo`02o`00=Ol00`3o
o`0]o`<00ol0103oo`02o`040?oo02Go2@02o`040?oo00;o00@0ool08ol0103oool300?o00@0ool0
0_l0103oo`0To`050?ooo`000_l0103oo`02o`040?oo00;o0@01o`7o000eo`80;_l00`3oo`03o`04
0?oo00;o00@0ool09_l01@3oool000;o4P0No`050?ooo`001Ol0103oo`02o`040?oo02Go00@0ool0
0_l0103oo`02o`040?oo00;o0@01o`7o000eo`030?oo02go00<0ool00ol0103oo`02o`040?oo02Co
0`03o`040?oo00;o00@0ool00_l0103oo`05oa003?l300?o00<0ool00ol0103oo`02o`040?oo02;o
00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l003Go00<0ool0;Ol400?o0P04o`809ol00`3o
o`02o`801?l200Co0P0Fob409?l200Co0P04o`801?l200?o000eo`030?oo0:go;`0<o`00<?oY00Oo
000eo`030?oo00So00<0ool02Ol00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00So
00<0ool02?l00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00So00<0ool02?l00`3o
o`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00So00<0ool02Ol00`3oo`0:o`00=Ol00`3o
o`0eo`030?oo03Co00<0ool0=?l00`3oo`0eo`030?oo00[o000eo`030?oo0>So000eo`030?oo0>So
003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o
003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-487.597, -3.75733*^-6, 
  9.04585, 2.39638*^-8}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(kksu3a = 
      Plot[\n\t\t
        \((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) 
          dmk[0.00815, 60, 200, mgt, 1.001, mgt, 100, Sqrt[5] ep^5, 0, 
            Sqrt[5] ep^7, Sqrt[5] ep^9], \n\t\t{mgt, 200, 2000}]\), 
    \(kksu3i = 
      Plot[\n\t\t
        \((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) 
          dmk[0.00815, 30, 200, mgt, 4.5, mgt, 0, ep^5/Sqrt[5], 0, 
            ep^7/Sqrt[5], ep^9/Sqrt[5]], \n\t\t{mgt, 200, 2000}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.0147151 894.888 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -12 -9 ]
[.5 .00222 12 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .1042 -36 -4.5 ]
[.01131 .1042 0 4.5 ]
[.01131 .19369 -36 -4.5 ]
[.01131 .19369 0 4.5 ]
[.01131 .28318 -36 -4.5 ]
[.01131 .28318 0 4.5 ]
[.01131 .37267 -36 -4.5 ]
[.01131 .37267 0 4.5 ]
[.01131 .46216 -36 -4.5 ]
[.01131 .46216 0 4.5 ]
[.01131 .55165 -36 -4.5 ]
[.01131 .55165 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(500)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1000)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1500)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1042 m
.03006 .1042 L
s
[(0.0001)] .01131 .1042 1 0 Mshowa
.02381 .19369 m
.03006 .19369 L
s
[(0.0002)] .01131 .19369 1 0 Mshowa
.02381 .28318 m
.03006 .28318 L
s
[(0.0003)] .01131 .28318 1 0 Mshowa
.02381 .37267 m
.03006 .37267 L
s
[(0.0004)] .01131 .37267 1 0 Mshowa
.02381 .46216 m
.03006 .46216 L
s
[(0.0005)] .01131 .46216 1 0 Mshowa
.02381 .55165 m
.03006 .55165 L
s
[(0.0006)] .01131 .55165 1 0 Mshowa
.125 Mabswid
.02381 .03261 m
.02756 .03261 L
s
.02381 .05051 m
.02756 .05051 L
s
.02381 .06841 m
.02756 .06841 L
s
.02381 .08631 m
.02756 .08631 L
s
.02381 .1221 m
.02756 .1221 L
s
.02381 .14 m
.02756 .14 L
s
.02381 .1579 m
.02756 .1579 L
s
.02381 .17579 m
.02756 .17579 L
s
.02381 .21159 m
.02756 .21159 L
s
.02381 .22949 m
.02756 .22949 L
s
.02381 .24739 m
.02756 .24739 L
s
.02381 .26528 m
.02756 .26528 L
s
.02381 .30108 m
.02756 .30108 L
s
.02381 .31898 m
.02756 .31898 L
s
.02381 .33687 m
.02756 .33687 L
s
.02381 .35477 m
.02756 .35477 L
s
.02381 .39057 m
.02756 .39057 L
s
.02381 .40847 m
.02756 .40847 L
s
.02381 .42636 m
.02756 .42636 L
s
.02381 .44426 m
.02756 .44426 L
s
.02381 .48006 m
.02756 .48006 L
s
.02381 .49795 m
.02756 .49795 L
s
.02381 .51585 m
.02756 .51585 L
s
.02381 .53375 m
.02756 .53375 L
s
.02381 .56955 m
.02756 .56955 L
s
.02381 .58744 m
.02756 .58744 L
s
.02381 .60534 m
.02756 .60534 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .60332 m
.12713 .50066 L
.13597 .41651 L
.14521 .35019 L
.15382 .30224 L
.17214 .22926 L
.1824 .19997 L
.19174 .17825 L
.20897 .14708 L
.22768 .12235 L
.24553 .10468 L
.26446 .0903 L
.29851 .07184 L
.31598 .06488 L
.33477 .05871 L
.37187 .04944 L
.40761 .04301 L
.44198 .03837 L
.47856 .03457 L
.51378 .03171 L
.5512 .02929 L
.58726 .02741 L
.62196 .02593 L
.65886 .02462 L
.6944 .02356 L
.72857 .02269 L
.76496 .02189 L
.79997 .02124 L
.8372 .02063 L
.87306 .02013 L
.90756 .0197 L
.94426 .01929 L
.97619 .01898 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o
003oob7o001Jo`<01?l200Co0P0Yo`@00ol200Co0P04o`809_l400;o0`04o`801?l202Ko1003o`80
1?l200Co0P03o`00GOl0103oo`02o`040?oo00;o00<0ool0:?l01@3oool000;o00@0ool00_l0103o
o`02o`030?oo02Go00<0ool01?l0103oo`02o`040?oo00;o00<0ool08ol00`3oo`03o`040?oo00;o
00@0ool00_l0103oo`02o`00GOl0103oo`02o`040?oo00;o00<0ool0:?l01@3oool000;o00@0ool0
0_l0103oo`02o`030?oo02Go00<0ool01?l0103oo`02o`040?oo00;o00<0ool09?l00`3oo`02o`04
0?oo00;o00@0ool00_l0103oo`02o`00F_l300?o00@0ool00_l0103oo`0Zo`050?ooo`000_l0103o
o`02o`040?oo00;o00<0ool09Ol0103oool300?o00@0ool00_l0103oo`0Wo`050?ooo`000_l0103o
o`02o`040?oo00;o0@01o`7o001Jo`030?oo00?o00@0ool00_l0103oo`0Zo`050?ooo`000_l0103o
o`02o`040?oo00;o00<0ool09Ol01@3oool000Go00@0ool00_l0103oo`0Xo`040?oo00;o00@0ool0
0_l0103oo`02o`400Ol1o`009ol00`3oo`0`o`030?oo00?o00@0ool00_l0103oo`0Xo`<00ol0103o
o`02o`040?oo00;o00@0ool09Ol300?o00<0ool00ol0103oo`02o`040?oo02Go00@0ool00_l0103o
o`02o`040?oo00;o00@0ool00_l002Oo00<0ool0<?l400?o0P04o`80:ol00`3oo`02o`801?l200Co
0P0Xo`040?ooo`@00ol200Co0P0Wo`801?l200Co0P04o`800ol002Oo00<0ool0m_l0027on007o`00
9ol00`3oo`08o`030?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool02?l00`3oo`09o`03
0?oo00Wo00<0ool02Ol00`3oo`09o`030?oo00So00<0ool02Ol00`3oo`09o`030?oo00Wo00<0ool0
2Ol00`3oo`08o`030?oo00Wo00<0ool02Ol00`3oo`09o`d03?l002Oo00<0ool0>?l00`3oo`0ho`03
0?oo037o=P0<o`030?oo00[o000Wo`030?oo08go6P1?o`009ol00`3oo`1koa80JOl002Oo0P1Zoa80
Nol002Oo00<0ool0H?l908go000Wo`030?oo05[o1P2Fo`009ol00`3oo`1Fo`@0W?l002Oo0P1Bo`D0
X?l002Oo00<0ool0COl40:Go000Wo`030?oo04Wo102Yo`009ol00`3oo`17o`80[Ol002Oo00<0ool0
A?l30:oo000Wo`80@ol20;;o000Wo`030?oo043o0P2do`009ol00`3oo`0no`80]_l002Oo00<0ool0
??l20;So000Wo`80>ol20;[o000Wo`030?oo03So0P2lo`009ol00`3oo`0go`030?oo0;co0002o`80
1?l00`3oo`03o`801?l200Co0P03o`@01?l00`3oo`0fo`030?oo0;go00001Ol0ool000So00@0ool0
0_l0103oo`02o`040?oo00Co00<0ool00ol00`3oo`0eo`030?oo0;ko00001Ol0ool000So00@0ool0
0_l0103oo`02o`040?oo00Co00<0ool00ol203Go00<0ool0_ol00005o`3oo`002?l0103oo`02o`04
0?oo00;o00@0ool01?l00`3oo`03o`030?oo03?o00<0ool0`?l00005o`3oo`002?l0103oo`02o`04
0?oo00;o00@0ool01?l00`3oo`03o`030?oo037o0P33o`0000Go0?oo0008o`040?oo00;o00@0ool0
0_l0103oo`02o`<01Ol00`3oo`0`o`030?oo0<?o0002o`802_l200Co0P04o`801Ol00`3oo`03o`80
<?l00`3oo`34o`009ol00`3oo`0^o`030?oo0<Go000Wo`030?oo02go00<0ool0a_l002Oo00<0ool0
;Ol00`3oo`36o`009ol202go00<0ool0aol002Oo00<0ool0:ol00`3oo`38o`009ol00`3oo`0Zo`03
0?oo0<Wo000Wo`030?oo02[o00<0ool0bOl002Oo00<0ool0:Ol00`3oo`3:o`009ol202[o00<0ool0
b_l002Oo00<0ool0:?l00`3oo`3;o`009ol00`3oo`0Xo`030?oo0<_o000Wo`030?oo02Oo00<0ool0
c?l002Oo0P0Xo`030?oo0<co000Wo`030?oo02Ko00<0ool0cOl002Oo00<0ool09_l00`3oo`3=o`00
0_l200Co00<0ool00ol200Co0P04o`800ol400Co00<0ool09Ol00`3oo`3>o`0000Go0?oo0008o`04
0?oo00;o00@0ool00_l0103oo`02o`030?oo00Go00<0ool09Ol00`3oo`3>o`0000Go0?oo0008o`04
0?oo00;o00@0ool00_l0103oo`03o`030?oo00Co0P0Uo`030?oo0<oo00001Ol0ool000So00@0ool0
0_l0103oo`02o`040?oo00Co00<0ool00ol00`3oo`0To`030?oo0<oo00001Ol0ool000So00@0ool0
0_l0103oo`02o`040?oo00Go00<0ool00_l00`3oo`0To`030?oo0<oo00001Ol0ool000So00@0ool0
0_l0103oo`02o`040?oo00;o00@0ool01?l00`3oo`0So`030?oo0=3o0002o`802_l200Co0P04o`80
1?l200Go0P0To`030?oo0=3o000Wo`030?oo02;o00<0ool0dOl002Oo00<0ool08_l00`3oo`3Ao`00
9ol00`3oo`0Qo`030?oo0=;o000Wo`030?oo027o00<0ool0d_l002Oo0P0Ro`030?oo0=;o000Wo`03
0?oo027o00<0ool0d_l002Oo00<0ool08?l00`3oo`3Co`009ol00`3oo`0Po`030?oo0=?o000Wo`80
8Ol00`3oo`3Co`009ol00`3oo`0Po`030?oo0=?o000Wo`030?oo023o00<0ool0dol002Oo00<0ool0
7ol00`3oo`3Do`009ol2023o00<0ool0e?l002Oo00<0ool07ol00`3oo`3Do`009ol00`3oo`0Oo`03
0?oo0=Co000Wo`030?oo01ko00<0ool0eOl000;o0P04o`030?oo00?o0P04o`801?l200Co0P05o`03
0?oo01ko00<0ool0eOl00005o`3oo`002?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`04o`80
7ol00`3oo`3Eo`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`05o`030?oo00;o00<0ool0
7_l00`3oo`3Eo`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`03o`801Ol00`3oo`0No`03
0?oo0=Go00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00Go00<0ool00_l00`3oo`0Mo`03
0?oo0=Ko00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00;o00@0ool01?l201ko00<0ool0
e_l000;o0P0:o`801?l200Co0P04o`801Ol00`3oo`0Mo`030?oo0=Ko000Wo`030?oo01go00<0ool0
e_l002Oo00<0ool07Ol00`3oo`3Fo`009ol00`3oo`0Lo`030?oo0=Oo000Wo`807Ol00`3oo`3Go`00
9ol00`3oo`0Lo`030?oo0=Oo000Wo`030?oo01co00<0ool0eol002Oo00<0ool07?l00`3oo`3Go`00
9ol201go00<0ool0eol002Oo00<0ool06ol00`3oo`3Ho`009ol00`3oo`0Ko`030?oo0=So000Wo`03
0?oo01_o00<0ool0f?l002Oo00<0ool06ol00`3oo`3Ho`009ol201co00<0ool0f?l002Oo00<0ool0
6_l00`3oo`3Io`009ol00`3oo`0Jo`030?oo0=Wo0002o`801?l00`3oo`03o`801?l200Co0P05o`03
0?oo00?o00<0ool06_l00`3oo`3Io`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`04o`03
0?oo00?o0P0Ko`030?oo0=Wo00001Ol0ool000So00@0ool00_l0103oo`02o`050?oo0?l01@04o`03
0?oo01[o00<0ool0fOl00005o`3oo`002?l0103oo`02o`040?oo00;o00H0ool0o`02o`030?oo00?o
00<0ool06_l00`3oo`3Io`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`02o`030?l000Go
00<0ool06Ol00`3oo`3Jo`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`03o`801Ol201[o
00<0ool0f_l000;o0P0:o`801?l200Co0P05o`030?oo00?o00<0ool06Ol00`3oo`3Jo`009ol00`3o
o`0Io`030?oo0=[o000Wo`030?oo01Wo00<0ool0f_l002Oo00<0ool06Ol00`3oo`3Jo`009ol201Wo
00<0ool0fol002Oo00<0ool06?l00`3oo`3Ko`009ol00`3oo`0Ho`030?oo0=_o000Wo`030?oo01So
00<0ool0fol002Oo0P0Io`030?oo0=_o000Wo`030?oo01So00<0ool0fol002Oo00<0ool06?l00`3o
o`3Ko`009ol00`3oo`0Ho`030?oo0=_o000Wo`030?oo01Oo00<0ool0g?l002Oo0P0Ho`030?oo0=co
000Wo`030?oo01Oo00<0ool0g?l002Oo00<0ool05ol00`3oo`3Lo`000_l200Co00<0ool00ol200Co
0P04o`800ol300Go00<0ool05ol00`3oo`3Lo`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103o
o`05o`030?oo00;o0P0Ho`030?oo0=co00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00Go
00<0ool00_l00`3oo`0Go`030?oo0=co00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00;o
0`05o`030?oo01Oo00<0ool0g?l00005o`3oo`002?l0103oo`02o`040?oo00;o00@0ool00_l00`3o
o`05o`030?oo01Oo00<0ool0g?l00005o`3oo`002?l0103oo`02o`040?oo00;o00@0ool00_l00`3o
o`05o`030?oo01Oo00<0ool0g?l000;o0P0:o`801?l200Co0P03o`@01?l201Oo00<0ool0gOl002Oo
00<0ool05_l00`3oo`3Mo`009ol00`3oo`0Fo`030?oo0=go000Wo`030?oo01Ko00<0ool0gOl002Oo
0P0Go`030?oo0=go000Wo`030?oo01Ko00<0ool0gOl002Oo00<0ool05_l00`3oo`3Mo`009ol00`3o
o`0Fo`030?oo0=go000Wo`805ol00`3oo`3Mo`009ol00`3oo`0Fo`030?oo0=go000Wo`030?oo01Ko
00<0ool0gOl002Oo00<0ool05_l00`3oo`3Mo`009ol00`3oo`0Eo`030?oo0=ko000Wo`805_l00`3o
o`3No`009ol00`3oo`0Eo`030?oo0=ko000Wo`030?oo01Go00<0ool0g_l000;o0P04o`030?oo00?o
0P04o`801?l200Co0P05o`030?oo01Go00<0ool0g_l00005o`3oo`002?l0103oo`02o`040?oo00;o
00@0ool00_l0103oo`04o`805_l00`3oo`3No`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103o
o`02o`040?oo00Co00<0ool05Ol00`3oo`3No`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103o
o`02o`<01Ol00`3oo`0Eo`030?oo0=ko00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00;o
00<0ool01Ol00`3oo`0Eo`030?oo0=ko00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00;o
00<0ool01Ol00`3oo`0Eo`030?oo0=ko0002o`802_l200Co0P04o`801?l300Co0P0Fo`030?oo0=ko
000Wo`030?oo01Go00<0ool0g_l002Oo00<0ool05?l00`3oo`3Oo`009ol00`3oo`0Do`030?oo0=oo
000Wo`805Ol00`3oo`3Oo`009ol00`3oo`0Do`030?oo0=oo000Wo`030?oo01Co00<0ool0gol002Oo
00<0ool05?l00`3oo`3Oo`009ol00`3oo`0Do`030?oo0=oo000Wo`80mol002Oo00<0ool0m_l002Oo
00<0ool0m_l002Oo00<0ool0m_l00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo
8Ol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-331.471, -8.93107*^-5, 
  8.47812, 4.5114*^-6}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.603319 11234.5 [
[.2619 .59082 -9 -9 ]
[.2619 .59082 9 0 ]
[.5 .59082 -12 -9 ]
[.5 .59082 12 0 ]
[.7381 .59082 -12 -9 ]
[.7381 .59082 12 0 ]
[.97619 .59082 -12 -9 ]
[.97619 .59082 12 0 ]
[.01131 .04159 -48 -4.5 ]
[.01131 .04159 0 4.5 ]
[.01131 .15394 -48 -4.5 ]
[.01131 .15394 0 4.5 ]
[.01131 .26628 -48 -4.5 ]
[.01131 .26628 0 4.5 ]
[.01131 .37863 -48 -4.5 ]
[.01131 .37863 0 4.5 ]
[.01131 .49097 -48 -4.5 ]
[.01131 .49097 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(500)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(1000)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(1500)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(2000)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .04159 m
.03006 .04159 L
s
[(-0.00005)] .01131 .04159 1 0 Mshowa
.02381 .15394 m
.03006 .15394 L
s
[(-0.00004)] .01131 .15394 1 0 Mshowa
.02381 .26628 m
.03006 .26628 L
s
[(-0.00003)] .01131 .26628 1 0 Mshowa
.02381 .37863 m
.03006 .37863 L
s
[(-0.00002)] .01131 .37863 1 0 Mshowa
.02381 .49097 m
.03006 .49097 L
s
[(-0.00001)] .01131 .49097 1 0 Mshowa
.125 Mabswid
.02381 .06406 m
.02756 .06406 L
s
.02381 .08653 m
.02756 .08653 L
s
.02381 .109 m
.02756 .109 L
s
.02381 .13147 m
.02756 .13147 L
s
.02381 .17641 m
.02756 .17641 L
s
.02381 .19888 m
.02756 .19888 L
s
.02381 .22134 m
.02756 .22134 L
s
.02381 .24381 m
.02756 .24381 L
s
.02381 .28875 m
.02756 .28875 L
s
.02381 .31122 m
.02756 .31122 L
s
.02381 .33369 m
.02756 .33369 L
s
.02381 .35616 m
.02756 .35616 L
s
.02381 .4011 m
.02756 .4011 L
s
.02381 .42357 m
.02756 .42357 L
s
.02381 .44604 m
.02756 .44604 L
s
.02381 .4685 m
.02756 .4685 L
s
.02381 .51344 m
.02756 .51344 L
s
.02381 .53591 m
.02756 .53591 L
s
.02381 .55838 m
.02756 .55838 L
s
.02381 .58085 m
.02756 .58085 L
s
.02381 .01912 m
.02756 .01912 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .01472 m
.12713 .10595 L
.13597 .1837 L
.15382 .29415 L
.1633 .33607 L
.17345 .37221 L
.19174 .42128 L
.21092 .45778 L
.22904 .48314 L
.24702 .50231 L
.26361 .51625 L
.2819 .52854 L
.29903 .53786 L
.33308 .55191 L
.36798 .56212 L
.40508 .56999 L
.44082 .57564 L
.47519 .57983 L
.51177 .58333 L
.54699 .58602 L
.58441 .58833 L
.62047 .59015 L
.65517 .5916 L
.69207 .5929 L
.72761 .59396 L
.76178 .59484 L
.79816 .59565 L
.83318 .59632 L
.87041 .59694 L
.90627 .59747 L
.94077 .59791 L
.97619 .59832 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o
003oob7o003oob7o003oob7o003oob7o003oob7o000bo`030?oo0>_o000bo`030?oo0>_o000bo`03
0?oo0>_o000bo`030?oo0>_o000bo`030?oo01Co00<0ool0e?l003;o0P0Eo`030?oo0=Co000bo`03
0?oo01Co00<0ool0e?l003;o00<0ool05?l00`3oo`3Do`00<_l00`3oo`0Do`030?oo0=Co0008o`80
1?l00`3oo`03o`801?l200Co0P04o`800ol300Co00<0ool05?l00`3oo`3Do`001ol0103oo`08o`04
0?oo00;o00@0ool00_l0103oo`02o`040?oo00Go00@0oooo0`0Eo`030?oo0=?o0007o`040?oo00So
00@0ool00_l0103oo`02o`040?oo00;o00@0ool01Ol01@3oool001Oo00<0ool0dol00003o`000080
0_l0103oo`08o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00;o0`04o`030?oo01Go00<0ool0
dol000Oo00@0ool02?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`02o`030?oo00Co00<0ool0
5Ol00`3oo`3Co`001ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00;o00<0ool0
1?l00`3oo`0Eo`030?oo0=?o0008o`802_l200Co0P04o`801?l200?o1003o`805_l00`3oo`3Co`00
<_l00`3oo`0Eo`030?oo0=?o000bo`030?oo01Go00<0ool0dol003;o00<0ool05Ol00`3oo`3Co`00
<_l00`3oo`0Eo`030?oo0=?o000bo`030?oo01Ko00<0ool0d_l003;o0P0Go`030?oo0=;o000bo`03
0?oo01Ko00<0ool0d_l003;o00<0ool05_l00`3oo`3Bo`00<_l00`3oo`0Fo`030?oo0=;o000bo`03
0?oo01Ko00<0ool0d_l003;o0P0Go`030?oo0=;o000bo`030?oo01Ko00<0ool0d_l003;o00<0ool0
5_l00`3oo`3Bo`00<_l00`3oo`0Fo`030?oo0=;o000bo`030?oo01Oo00<0ool0dOl003;o0P0Ho`03
0?oo0=7o000bo`030?oo01Oo00<0ool0dOl003;o00<0ool05ol00`3oo`3Ao`00<_l00`3oo`0Go`03
0?oo0=7o0008o`801?l00`3oo`03o`801?l200Co0P04o`801Ol00`3oo`02o`030?oo01Oo00<0ool0
dOl000Oo00@0ool02?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`04o`030?oo00;o00<0ool0
5ol00`3oo`3Ao`001ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`02o`050?oo0?l01@03o`<0
5ol00`3oo`3Ao`0000?o00000P02o`040?oo00So00@0ool00_l0103oo`02o`040?oo00;o00H0ool0
o`02o`030?oo00;o00<0ool05ol00`3oo`3Ao`001ol0103oo`08o`040?oo00;o00@0ool00_l0103o
o`02o`040?oo00;o00<0o`001?l00`3oo`0Go`030?oo0=7o0007o`040?oo00So00@0ool00_l0103o
o`02o`040?oo00;o00@0ool00ol200Co00<0ool06?l00`3oo`3@o`002?l200[o0P04o`801?l200Co
0P05o`030?oo00;o00<0ool06?l00`3oo`3@o`00<_l201Wo00<0ool0d?l003;o00<0ool06?l00`3o
o`3@o`00<_l00`3oo`0Ho`030?oo0=3o000bo`030?oo01So00<0ool0d?l003;o00<0ool06?l00`3o
o`3@o`00<_l201Wo00<0ool0d?l003;o00<0ool06Ol00`3oo`3?o`00<_l00`3oo`0Io`030?oo0<oo
000bo`030?oo01Wo00<0ool0col003;o00<0ool06Ol00`3oo`3?o`00<_l201[o00<0ool0col003;o
00<0ool06Ol00`3oo`3?o`00<_l00`3oo`0Jo`030?oo0<ko000bo`030?oo01[o00<0ool0c_l003;o
00<0ool06_l00`3oo`3>o`00<_l00`3oo`0Jo`030?oo0<ko000bo`806ol00`3oo`3>o`00<_l00`3o
o`0Jo`030?oo0<ko000bo`030?oo01[o00<0ool0c_l003;o00<0ool06ol00`3oo`3=o`002?l200Co
00<0ool00ol200Co0P04o`801?l200Co0P04o`030?oo01_o00<0ool0cOl000Oo00@0ool02?l0103o
o`02o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00?o0`0Ko`030?oo0<go0007o`040?oo00So
00@0ool00_l0103oo`02o`040?oo00;o00@0ool01Ol01@3oool001go00<0ool0cOl00003o`000080
0_l0103oo`08o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00?o0P04o`030?oo01_o00<0ool0
cOl000Oo00@0ool02?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`05o`050?ooo`007Ol00`3o
o`3=o`001ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00;o00@0ool00ol00`3o
o`0Lo`030?oo0<co0008o`802_l200Co0P04o`801?l200Co0P04o`807Ol00`3oo`3<o`00<_l00`3o
o`0Lo`030?oo0<co000bo`030?oo01co00<0ool0c?l003;o00<0ool07?l00`3oo`3<o`00<_l00`3o
o`0Lo`030?oo0<co000bo`030?oo01go00<0ool0bol003;o0P0No`030?oo0<_o000bo`030?oo01go
00<0ool0bol003;o00<0ool07Ol00`3oo`3;o`00<_l00`3oo`0No`030?oo0<[o000bo`030?oo01ko
00<0ool0b_l003;o0P0Oo`030?oo0<[o000bo`030?oo01ko00<0ool0b_l003;o00<0ool07ol00`3o
o`39o`00<_l00`3oo`0Oo`030?oo0<Wo000bo`030?oo01oo00<0ool0bOl003;o0P0Qo`030?oo0<So
000bo`030?oo023o00<0ool0b?l003;o00<0ool08?l00`3oo`38o`00<_l00`3oo`0Qo`030?oo0<Oo
0008o`801?l00`3oo`03o`801?l200Co0P04o`800ol400?o00<0ool08Ol00`3oo`37o`001ol0103o
o`08o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00;o00<0ool01?l3027o00<0ool0aol000Oo
00@0ool02?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`03o`030?oo00?o00<0ool08_l00`3o
o`36o`0000?o00000P02o`040?oo00So00@0ool00_l0103oo`02o`040?oo00;o00@0ool01?l00`3o
o`02o`030?oo02;o00<0ool0a_l000Oo00@0ool02?l0103oo`02o`040?oo00;o00@0ool00_l0103o
o`05o`050?ooo`009?l00`3oo`36o`001ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`02o`04
0?oo00;o00@0ool00ol00`3oo`0So`030?oo0<Go0008o`802_l200Co0P04o`801?l200Co0P04o`03
0?oo02?o00<0ool0aOl003;o0P0Uo`030?oo0<Co000bo`030?oo02Co00<0ool0a?l003;o00<0ool0
9?l00`3oo`34o`00<_l00`3oo`0Uo`030?oo0<?o000bo`030?oo02Go00<0ool0`ol003;o0P0Vo`03
0?oo0<?o000bo`030?oo02Ko00<0ool0`_l003;o00<0ool09_l00`3oo`32o`00<_l00`3oo`0Wo`03
0?oo0<7o000bo`030?oo02Oo00<0ool0`Ol003;o0P0Yo`030?oo0<3o000bo`030?oo02So00<0ool0
`?l003;o00<0ool0:Ol00`3oo`2oo`00<_l00`3oo`0Yo`030?oo0;oo000bo`030?oo02[o00<0ool0
__l003;o00<0ool0:ol00`3oo`2mo`00<_l202go00<0ool0_?l003;o00<0ool0;?l00`3oo`2lo`00
<_l00`3oo`0]o`030?oo0;_o000bo`030?oo02ko00<0ool0^_l000So0P04o`030?oo00?o0P04o`80
1?l200Co0P03o`@00ol00`3oo`0_o`030?oo0;Wo0007o`040?oo00So00@0ool00_l0103oo`02o`04
0?oo00;o00@0ool01?l00`3oo`02o`<0<?l00`3oo`2ho`001ol0103oo`08o`040?oo00;o00@0ool0
0_l0103oo`02o`040?oo00Co00<0ool00_l00`3oo`0`o`030?oo0;So00000ol0000200;o00@0ool0
2?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`04o`030?oo00;o00<0ool0<Ol00`3oo`2go`00
1ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00Co00<0ool00_l00`3oo`0bo`03
0?oo0;Ko0007o`040?oo00So00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l300Co00<0ool0
<ol00`3oo`2eo`002?l200[o0P04o`801?l200Co0P05o`030?oo00;o0P0eo`80]Ol003;o00<0ool0
=_l00`3oo`2bo`00<_l00`3oo`0go`030?oo0;7o000bo`030?oo03So0P2ao`00<_l00`3oo`0jo`03
0?oo0:ko000bo`80??l20:ko000bo`030?oo03go0`2[o`00<_l00`3oo`10o`80ZOl003;o00<0ool0
@_l30:Ko000bo`030?oo04Go0`2So`00<_l00`3oo`18o`80XOl003;o0P1;o`<0W_l003;o00<0ool0
COl609So000bo`030?oo02go0`04o`801?l201Oo1`08o`@00ol200Co0P04o`808ol400;o0`04o`80
1?l202Co1003o`801?l200Co0P03o`00<_l00`3oo`0`o`040?oo00;o00@0ool00_l00`3oo`0Ko`@0
1_l01@3oool000;o00@0ool00_l0103oo`02o`030?oo02;o00<0ool01?l0103oo`02o`040?oo00;o
00<0ool08Ol00`3oo`03o`040?oo00;o00@0ool00_l0103oo`02o`00<_l00`3oo`0`o`040?oo00;o
00@0ool00_l00`3oo`0Oo`L00ol0103oo`02o`040?oo00;o00@0ool09?l00`3oo`04o`040?oo00;o
00@0ool00_l00`3oo`0Ro`030?oo00;o00@0ool00_l0103oo`02o`040?oo00;o000bo`80;_l300?o
00@0ool00_l0103oo`0Wo`P00_l0103oo`02o`040?oo02Co00@0oooo0`03o`040?oo00;o00@0ool0
9Ol01@3oool000;o00@0ool00_l0103oo`02o`400Ol1o`00<_l00`3oo`0]o`030?oo00?o00@0ool0
0_l0103oo`0Wo`050?ooo`000_lB01oo00D0oooo0005o`040?oo00;o00@0ool09_l0103oo`02o`04
0?oo00;o00@0ool00_l1007o0Ol003;o00<0ool0;Ol00`3oo`03o`040?oo00;o00@0ool09Ol300?o
00@0ool00_l0103oo`02o`040?oo00Go4@0<o`<00ol00`3oo`03o`040?oo00;o00@0ool08ol0103o
o`02o`040?oo00;o00@0ool00_l0103oo`02o`00<_l00`3oo`0]o`@00ol200Co0P0Xo`030?oo00;o
0P04o`801?l201Oo:P0Lo`801?l200Co0P04o`800ol003;o00<0ool0^?lW00co000]on`01ol003;o
00<0ool02Ol00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00Wo00<0ool02?l00`3o
o`08o`030?oo00So00<0ool02?l00`3oo`09o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00So
00<0ool02Ol00`3oo`08o`030?oo00So00<0ool02?l00`3oo`09o`030?oo00[o000bo`030?oo03Go
00<0ool0=Ol00`3oo`0eo`030?oo03Ko00<0ool02_l003;o00<0ool0jol003;o00<0ool0jol00?oo
8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo
8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-454.722, -5.96689*^-5, 
  8.9263, 3.78354*^-7}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Clear[co, cogl, fw, fgl, mgab, dmev]; \n
    dmev = 0.47/\((\((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\))\); \n
    co = \((gf^2)\)/\((6  Pi^2)\) mw^2  mmb\ fbbb^2; \n
    cogl[a_] := \((\((Pi^2  alphas^2)\)/\((gf^2  mw^2 \((1/a)\)^2)\))\); \n
    fw[vtd_] := \((\((vtd)\)^2  f1[\((mt/mw)\)^2])\); \n
    fgl[m_, ac_, a_, dll_, drr_, dlr_, drl_] := 
      \((\n\t\t\((ddll[m, ac, dll]^2 + ddrr[m, ac, drr]^2)\)/9 
            \((4  a^2  f4[a^2] + 11  f5[a^2])\) + \n\t\t\t\t\t
          \((\(-5\)/8 \((mmb/\((mb + md)\))\)^2)\) 102/27 
            \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)\) a^2 
             f4[a^2] - \n\t\t\t\t\t
          \((1/8 \((mmb/\((mb + md)\))\)^2)\) 2/3 
            \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)\) a^2 
             f4[a^2]\n\t)\); \n
    mgab[vtd_, m_, ac_, a_, dll_, drr_, dlr_, drl_] := 
      Sqrt[Abs[\n\t\t\t
          \((cogl[a] fgl[m, ac, a, dll, drr, dlr, drl])\)/
            \((dmev/co - fw[vtd])\)\n\t\t]]; \)], "Input"],

Cell[BoxData[
    \(\(mgab[vtd_, m_, ac_, a_, dll_, drr_, dlr_, drl_] := 
      Sqrt[Abs[\((\n\t\t\t\t
              \((Pi^2  alphas^2)\)/\((gf^2  mw^2 \((1/a)\)^2)\) 
                \((\n\t\t\t\t\tddll[m, ac, dll]^2 + ddrr[m, ac, drr]^2)\)/9 
                \((4  a^2  f4[a^2] + 11  f5[a^2] + \n\t\t\t\t\t
                    \((\(-5\)/8 \((mmb/\((mb + md)\))\)^2)\) 102/27 
                      \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)
                        \) a^2  f4[a^2] - \n\t\t\t\t\t
                    \((1/8 \((mmb/\((mb + md)\))\)^2)\) 2/3 
                      \((ddrl[m, ac, tanb, drl]^2 + ddlr[m, ac, tanb, dlr]^2)
                        \) a^2  f4[a^2])\))\)/
            \((\n\t\t\t\t\t
              0.47/\((\((10^\((\(-12\))\))\)/\((6.582\ 10^\((\(-25\))\))\) 
                      \((gf^2)\)/\((6  Pi^2)\) mw^2  mmb\ fbbb^2)\) - \n\t\t\t
                \((vtd)\)^2  f1[\((mt/mw)\)^2]\n\t\t\t\t\t)\)\n\t\t\t]]; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pmgabsu5a = 
      Plot[mgab[0.00815, 200, 200, a, Sqrt[5] ep^4, 0, Sqrt[5] ep^4, 
          Sqrt[5] ep^\((10)\)], {a, 1.001, 5}]\), 
    \(pmgabsu5i = 
      Plot[mgab[0.00815, 2000, 0, a, 1/Sqrt[5] ep^4, 0, 1/Sqrt[5] ep^4, 
          1/Sqrt[5] ep^\((10)\)], {a, 1.001, 5}]\), 
    \(pmgabsu3a = 
      Plot[mgab[0.00815, 200, 200, a, Sqrt[5] ep^3, 0, Sqrt[5] ep^3, 
          Sqrt[5] ep^4], {a, 1.001, 5}]\), 
    \(pmgabsu3i = 
      Plot[mgab[0.00815, 2000, 0, a, 1/Sqrt[5] ep^3, 0, 1/Sqrt[5] ep^3, 
          1/Sqrt[5] ep^4], {a, 1.001, 5}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214583 0.238155 0.0147151 0.00333362 [
[.26173 .00222 -3 -9 ]
[.26173 .00222 3 0 ]
[.49988 .00222 -3 -9 ]
[.49988 .00222 3 0 ]
[.73804 .00222 -3 -9 ]
[.73804 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01107 .09806 -12 -4.5 ]
[.01107 .09806 0 4.5 ]
[.01107 .1814 -12 -4.5 ]
[.01107 .1814 0 4.5 ]
[.01107 .26474 -12 -4.5 ]
[.01107 .26474 0 4.5 ]
[.01107 .34808 -18 -4.5 ]
[.01107 .34808 0 4.5 ]
[.01107 .43142 -18 -4.5 ]
[.01107 .43142 0 4.5 ]
[.01107 .51476 -18 -4.5 ]
[.01107 .51476 0 4.5 ]
[.01107 .5981 -18 -4.5 ]
[.01107 .5981 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26173 .01472 m
.26173 .02097 L
s
[(2)] .26173 .00222 0 1 Mshowa
.49988 .01472 m
.49988 .02097 L
s
[(3)] .49988 .00222 0 1 Mshowa
.73804 .01472 m
.73804 .02097 L
s
[(4)] .73804 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0712 .01472 m
.0712 .01847 L
s
.11883 .01472 m
.11883 .01847 L
s
.16646 .01472 m
.16646 .01847 L
s
.2141 .01472 m
.2141 .01847 L
s
.30936 .01472 m
.30936 .01847 L
s
.35699 .01472 m
.35699 .01847 L
s
.40462 .01472 m
.40462 .01847 L
s
.45225 .01472 m
.45225 .01847 L
s
.54751 .01472 m
.54751 .01847 L
s
.59514 .01472 m
.59514 .01847 L
s
.64277 .01472 m
.64277 .01847 L
s
.6904 .01472 m
.6904 .01847 L
s
.78567 .01472 m
.78567 .01847 L
s
.8333 .01472 m
.8333 .01847 L
s
.88093 .01472 m
.88093 .01847 L
s
.92856 .01472 m
.92856 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02357 .09806 m
.02982 .09806 L
s
[(25)] .01107 .09806 1 0 Mshowa
.02357 .1814 m
.02982 .1814 L
s
[(50)] .01107 .1814 1 0 Mshowa
.02357 .26474 m
.02982 .26474 L
s
[(75)] .01107 .26474 1 0 Mshowa
.02357 .34808 m
.02982 .34808 L
s
[(100)] .01107 .34808 1 0 Mshowa
.02357 .43142 m
.02982 .43142 L
s
[(125)] .01107 .43142 1 0 Mshowa
.02357 .51476 m
.02982 .51476 L
s
[(150)] .01107 .51476 1 0 Mshowa
.02357 .5981 m
.02982 .5981 L
s
[(175)] .01107 .5981 1 0 Mshowa
.125 Mabswid
.02357 .03138 m
.02732 .03138 L
s
.02357 .04805 m
.02732 .04805 L
s
.02357 .06472 m
.02732 .06472 L
s
.02357 .08139 m
.02732 .08139 L
s
.02357 .11472 m
.02732 .11472 L
s
.02357 .13139 m
.02732 .13139 L
s
.02357 .14806 m
.02732 .14806 L
s
.02357 .16473 m
.02732 .16473 L
s
.02357 .19806 m
.02732 .19806 L
s
.02357 .21473 m
.02732 .21473 L
s
.02357 .2314 m
.02732 .2314 L
s
.02357 .24807 m
.02732 .24807 L
s
.02357 .28141 m
.02732 .28141 L
s
.02357 .29807 m
.02732 .29807 L
s
.02357 .31474 m
.02732 .31474 L
s
.02357 .33141 m
.02732 .33141 L
s
.02357 .36475 m
.02732 .36475 L
s
.02357 .38141 m
.02732 .38141 L
s
.02357 .39808 m
.02732 .39808 L
s
.02357 .41475 m
.02732 .41475 L
s
.02357 .44809 m
.02732 .44809 L
s
.02357 .46475 m
.02732 .46475 L
s
.02357 .48142 m
.02732 .48142 L
s
.02357 .49809 m
.02732 .49809 L
s
.02357 .53143 m
.02732 .53143 L
s
.02357 .5481 m
.02732 .5481 L
s
.02357 .56476 m
.02732 .56476 L
s
.02357 .58143 m
.02732 .58143 L
s
.02357 .61477 m
.02732 .61477 L
s
.25 Mabswid
.02357 0 m
.02357 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19734 m
.02499 .35575 L
.02605 .35452 L
.02846 .35167 L
.03279 .3464 L
.04262 .33379 L
.06244 .30555 L
.08265 .27251 L
.10458 .23043 L
.12534 .18118 L
.13524 .15188 L
.14008 .13509 L
.14451 .11743 L
.14913 .09506 L
.15126 .08238 L
.15353 .06554 L
.15479 .05312 L
.15594 .03644 L
.15709 .03785 L
.15817 .05322 L
.15944 .0656 L
.1606 .07476 L
.16324 .09149 L
.16802 .11488 L
.17326 .13531 L
.18386 .16816 L
.20337 .21406 L
.22428 .25241 L
.26565 .31092 L
.30549 .35442 L
.34382 .38865 L
.3846 .41917 L
.42387 .44419 L
.46162 .46505 L
.50182 .48447 L
.54051 .50091 L
.58165 .51636 L
.62127 .52958 L
.65938 .54097 L
.69994 .55188 L
.73899 .56136 L
.78049 .57046 L
.82047 .57841 L
.85893 .58538 L
.89985 .59217 L
.93926 .59815 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o001Do`@0?Ol2043o00<0ool0??l300Oo001Do`030?oo03go
00@0ool0?ol00`3oo`0oo`030?oo00Co001Eo`030?oo03oo00<0ool0>_l5043o00<0ool01?l005Ko
00<0ool0??l203go00@0ool0?_l300Oo000Eo`030?oo03oo00<0ool0?Ol00`3oo`0ko`030?l003ko
00<0ool01ol001Go00<0ool0??l0103oo`0lo`040?oo03ko0P0no`030?oo00Oo000Eo`030?oo03go
0P0no`80@?l00`3oo`0lo`@01_l001Go00<0ool0ool9o`003_oo01<0000Eo`030?oo00[o00<0ool0
2_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`03
0?oo00Wo00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0
2_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`05o`005Ol00`3oo`0no`030?oo03go00<0ool0
?_l00`3oo`0no`030?oo00Go000Eo`030?oo0?oo2Ol001Go00<0ool0ool9o`005Ol20?oo2_l001Go
00<0ool08Ol00`3oo`3To`005Ol00`3oo`0Qo`030?oo0>Co000Eo`030?oo027o00<0ool0i?l001Go
0P0Ro`80iOl001Go00<0ool08Ol20>Go000Eo`030?oo027o0P3Uo`005Ol00`3oo`0Qo`80iOl001Go
00<0ool08?l00`3o003Uo`005Ol2027o00<0o`00iOl001Go00<0ool08?l00`3o003Uo`005Ol00`3o
o`0Po`030?l00>Go000Eo`030?oo023o00<0o`00iOl001Go0P0Qo`030?l00>Go000Eo`030?oo023o
00@0ool0i?l001Go00<0ool08?l0103oo`3To`005Ol00`3oo`0Oo`050?ooo`00i?l000Oo1002o`<0
1Ol00`3oo`0Oo`050?ooo`00i?l000Oo00<0ool01_l00`3oo`02o`<07ol01@3oool00>Co0008o`03
0?oo00Go00<0ool00_l00`3oo`0Oo`030?oo00;o00<0ool0hOl000Wo00@0oooo0`05o`030?oo01oo
00<0ool00_l00`3oo`3Qo`002_l0103oo`07o`030?oo01ko00<0ool00ol00`3oo`3Qo`001ol0103o
o`02o`030?oo00Go0P0Oo`030?oo00?o00<0ool0hOl000So0P03o`@01?l00`3oo`0No`030?oo00?o
00<0ool0hOl001Go00<0ool07_l00`3oo`04o`030?oo0>3o000Eo`030?oo01ko00<0ool01?l00`3o
o`3Po`005Ol00`3oo`0Mo`030?oo00Go00<0ool0h?l001Go0P0No`030?oo00Ko00<0ool0gol001Go
00<0ool07Ol00`3oo`06o`030?oo0=oo000Eo`030?oo01go00<0ool01_l00`3oo`3Oo`005Ol00`3o
o`0Lo`030?oo00So00<0ool0g_l001Go0P0Mo`030?oo00So00<0ool0g_l001Go00<0ool06ol00`3o
o`09o`030?oo0=ko000Eo`030?oo01_o00<0ool02_l00`3oo`3Mo`005Ol00`3oo`0Ko`030?oo00[o
00<0ool0gOl001Go00<0ool06_l00`3oo`0;o`030?oo0=go000Eo`806ol00`3oo`0<o`030?oo0=co
000Eo`030?oo01[o00<0ool03?l00`3oo`3Lo`005Ol00`3oo`0Jo`030?oo00co00<0ool0g?l000Oo
0`04o`801Ol00`3oo`0Io`030?oo00ko00<0ool0fol000[o00@0ool00_l00`3oo`02o`030?oo01Wo
00<0ool03_l00`3oo`3Ko`002_l0103oo`02o`030?oo00;o0`0Io`030?oo00oo00<0ool0f_l000Oo
0`03o`040?oo00Co00<0ool06?l00`3oo`0@o`030?oo0=[o0007o`030?oo00?o00@0ool01?l00`3o
o`0Ho`030?oo017o00<0ool0fOl000Oo00<0ool00ol0103oo`04o`030?oo01Oo00<0ool04_l00`3o
o`3Io`001ol400?o0P05o`806?l00`3oo`0Bo`030?oo0=Wo000Eo`030?oo01Ko00<0ool05?l00`3o
o`3Ho`005Ol00`3oo`0Fo`030?oo01Co00<0ool0f?l001Go00<0ool05_l00`3oo`0Eo`030?oo0=Oo
000Eo`030?oo01Go00<0ool05_l00`3oo`3Go`005Ol201Ko00<0ool05_l00`3oo`3Go`005Ol00`3o
o`0Do`030?oo01So00<0ool0e_l001Go00<0ool05?l00`3oo`0Ho`030?oo0=Ko000Eo`030?oo01?o
00<0ool06_l00`3oo`3Eo`005Ol201Co00<0ool06_l00`3oo`3Eo`005Ol00`3oo`0Bo`030?oo01co
00<0ool0e?l001Go00<0ool04_l00`3oo`0Lo`030?oo0=Co000Eo`030?oo017o00<0ool07_l00`3o
o`3Co`005Ol00`3oo`0Ao`030?oo01ko00<0ool0dol001Go0P0Ao`030?oo023o00<0ool0d_l001Go
00<0ool04?l00`3oo`0Po`030?oo0=;o000Eo`030?oo00oo00<0ool08_l00`3oo`3Ao`002?l00`3o
o`02o`<01Ol00`3oo`0?o`030?oo02?o00<0ool0d?l000So00<0ool01Ol00`3oo`02o`<03_l00`3o
o`0To`030?oo0=3o0009o`030?oo00Co00<0ool00_l00`3oo`0>o`030?oo02Go00<0ool0col000Wo
00@0oooo0`05o`030?oo00go00<0ool09ol00`3oo`3>o`002_l0103oo`07o`030?oo00co00<0ool0
:Ol00`3oo`3=o`001ol0103oo`02o`030?oo00Go00<0ool03?l00`3oo`0Yo`030?oo0<go0007o`@0
0_l400Co0P0<o`030?oo02_o00<0ool0c?l001Go00<0ool02_l00`3oo`0]o`030?oo0<_o000Eo`03
0?oo00[o00<0ool0;_l00`3oo`3:o`005Ol00`3oo`09o`030?oo02oo00<0ool0b_l001Go0P09o`03
0?oo037o00<0ool0bOl001Go00<0ool02?l00`3oo`0bo`030?oo0<So000Eo`030?oo00Oo00<0ool0
=?l00`3oo`37o`005Ol00`3oo`06o`030?oo03Go00<0ool0aol001Go00<0ool01_l00`3oo`0fo`03
0?oo0<Ko000Eo`801_l00`3oo`0ho`030?oo0<Go000Eo`030?oo00Go00<0ool0>Ol00`3oo`34o`00
5Ol00`3oo`04o`030?oo03_o00<0ool0`ol001Go00<0ool00ol00`3oo`0mo`030?oo0<;o000Eo`80
1?l00`3oo`0no`030?oo0<7o000Eo`030?oo00;o00<0ool0@?l00`3oo`30o`005Ol01@3oool004?o
00<0ool0`?l001Go00@0ool0AOl00`3oo`2oo`0000?o00000P03o`801?l200Go00<0o`00Aol00`3o
o`2no`000ol01@3oool000;o00@0ool00_l00`3oo`02o`<0B?l00`3oo`2mo`000ol01@3oool000;o
00@0ool00_l00`3oo`02o`80B_l00`3oo`2lo`000ol01@3oool000;o00@0ool00_l00`3oo`02o`80
Bol00`3oo`2ko`000ol01@3oool000;o00@0ool00_l00`3oo`02o`030?oo04_o00<0ool0^_l00004
o`0000?o00@0ool00_l0103oo`04o`80COl00`3oo`2io`000ol00`3oo`02o`801?l200Go00<0ool0
COl00`3oo`2ho`005Ol00`3oo`1>o`030?oo0;Oo000Eo`030?oo04oo0P2go`005Ol00`3oo`1Ao`03
0?oo0;Co000Eo`80Dol00`3oo`2co`005Ol00`3oo`1Co`030?oo0;;o000Eo`030?oo05Co00<0ool0
/Ol001Go00<0ool0EOl20;7o000Eo`80F?l00`3oo`2^o`005Ol00`3oo`1Ho`030?oo0:go000Eo`03
0?oo05Wo0P2]o`005Ol00`3oo`1Ko`030?oo0:[o000Eo`030?oo05co00<0ool0ZOl001Go0P1No`80
ZOl001Go00<0ool0Gol00`3oo`2Vo`005Ol00`3oo`1Po`80Y_l00003o`0000800_l400;o0`05o`03
0?oo06;o00<0ool0Xol000?o00D0oooo0008o`030?oo00;o00<0ool0Hol20:?o0003o`030?oo00;o
00<0ool01Ol00`3oo`02o`<0IOl20:7o0003o`030?oo00?o00@0oooo0`05o`030?oo06Oo00<0ool0
W_l000?o00<0ool01?l0103oo`07o`030?oo06So0P2No`0000Co00000ol0103oo`02o`030?oo00Go
00<0ool0J_l00`3oo`2Ko`000ol00`3oo`02o`800ol400Co0P1/o`80Vol001Go00<0ool0KOl209Wo
000Eo`030?oo06oo00<0ool0U_l001Go00<0ool0L?l209Ko000Eo`030?oo07;o0P2Do`005Ol207Go
0P2Bo`005Ol00`3oo`1fo`80T?l001Go00<0ool0N?l208ko000Eo`030?oo07[o0P2<o`005Ol207go
0P2:o`005Ol00`3oo`1no`<0Qol001Go00<0ool0POl308Co000Eo`030?oo08Co0P22o`005Ol00`3o
o`26o`<0Ool001Go0P2:o`<0O?l001Go00<0ool0S?l207[o000Eo`030?oo08ko0P1ho`0000?o0000
0P02o`<01?l200Go00<0ool0T?l207Ko0003o`030?oo00Co00@0ool00_l00`3oo`02o`<0T_l207Co
0003o`030?oo00Co00@0ool00_l00`3oo`02o`030?oo09Co0`1ao`000ol0103oool300?o00@0ool0
1?l00`3oo`2Go`<0K_l000?o00D0oooo0005o`040?oo00Co00<0ool0V_l406[o00001?l00003o`03
0?oo00?o00@0ool01?l00`3oo`2No`<0Iol000?o00@0oooo1003o`801Ol20:;o101So`005Ol00`3o
o`2Uo`@0Gol001Go00<0ool0ZOl305co000Eo`030?oo0:co101Ho`005Ol20;7o101Do`005Ol00`3o
o`2do`<0DOl001Go00<0ool0]ol404go000Eo`030?oo0;_o1019o`005Ol00`3oo`2oo`@0AOl001Go
0P34o`H0?ol001Go00<0ool0bOl403_o000Eo`030?oo0<go100go`005Ol00`3oo`3Ao`@0<ol001Go
0P3Fo`H0;Ol001Go00<0ool0fol802Go000Eo`030?oo0>?o1P0Oo`005Ol00`3oo`3Yo`D06_l00003
o`0000800ol00`3oo`02o`<01Ol00`3oo`3^o`H05?l000?o00<0ool00_l00`3oo`05o`030?oo00;o
0`3do`L03Ol000?o00<0ool00ol00`3oo`04o`030?oo00;o00<0ool0nol600Oo0003o`030?oo00?o
00@0oooo0`05o`030?oo0?oo2Ol000?o00<0ool01?l0103oo`07o`030?oo0?oo2Ol00004o`0000?o
00@0ool00_l00`3oo`05o`80ool:o`000ol0103oool400;o1004o`030?oo0?oo2Ol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.669621, -13.9117, 
  0.0154368, 1.10281}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214583 0.238155 0.0147151 0.0166681 [
[.26173 .00222 -3 -9 ]
[.26173 .00222 3 0 ]
[.49988 .00222 -3 -9 ]
[.49988 .00222 3 0 ]
[.73804 .00222 -3 -9 ]
[.73804 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01107 .09806 -6 -4.5 ]
[.01107 .09806 0 4.5 ]
[.01107 .1814 -12 -4.5 ]
[.01107 .1814 0 4.5 ]
[.01107 .26474 -12 -4.5 ]
[.01107 .26474 0 4.5 ]
[.01107 .34808 -12 -4.5 ]
[.01107 .34808 0 4.5 ]
[.01107 .43142 -12 -4.5 ]
[.01107 .43142 0 4.5 ]
[.01107 .51476 -12 -4.5 ]
[.01107 .51476 0 4.5 ]
[.01107 .5981 -12 -4.5 ]
[.01107 .5981 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26173 .01472 m
.26173 .02097 L
s
[(2)] .26173 .00222 0 1 Mshowa
.49988 .01472 m
.49988 .02097 L
s
[(3)] .49988 .00222 0 1 Mshowa
.73804 .01472 m
.73804 .02097 L
s
[(4)] .73804 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0712 .01472 m
.0712 .01847 L
s
.11883 .01472 m
.11883 .01847 L
s
.16646 .01472 m
.16646 .01847 L
s
.2141 .01472 m
.2141 .01847 L
s
.30936 .01472 m
.30936 .01847 L
s
.35699 .01472 m
.35699 .01847 L
s
.40462 .01472 m
.40462 .01847 L
s
.45225 .01472 m
.45225 .01847 L
s
.54751 .01472 m
.54751 .01847 L
s
.59514 .01472 m
.59514 .01847 L
s
.64277 .01472 m
.64277 .01847 L
s
.6904 .01472 m
.6904 .01847 L
s
.78567 .01472 m
.78567 .01847 L
s
.8333 .01472 m
.8333 .01847 L
s
.88093 .01472 m
.88093 .01847 L
s
.92856 .01472 m
.92856 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02357 .09806 m
.02982 .09806 L
s
[(5)] .01107 .09806 1 0 Mshowa
.02357 .1814 m
.02982 .1814 L
s
[(10)] .01107 .1814 1 0 Mshowa
.02357 .26474 m
.02982 .26474 L
s
[(15)] .01107 .26474 1 0 Mshowa
.02357 .34808 m
.02982 .34808 L
s
[(20)] .01107 .34808 1 0 Mshowa
.02357 .43142 m
.02982 .43142 L
s
[(25)] .01107 .43142 1 0 Mshowa
.02357 .51476 m
.02982 .51476 L
s
[(30)] .01107 .51476 1 0 Mshowa
.02357 .5981 m
.02982 .5981 L
s
[(35)] .01107 .5981 1 0 Mshowa
.125 Mabswid
.02357 .03138 m
.02732 .03138 L
s
.02357 .04805 m
.02732 .04805 L
s
.02357 .06472 m
.02732 .06472 L
s
.02357 .08139 m
.02732 .08139 L
s
.02357 .11472 m
.02732 .11472 L
s
.02357 .13139 m
.02732 .13139 L
s
.02357 .14806 m
.02732 .14806 L
s
.02357 .16473 m
.02732 .16473 L
s
.02357 .19806 m
.02732 .19806 L
s
.02357 .21473 m
.02732 .21473 L
s
.02357 .2314 m
.02732 .2314 L
s
.02357 .24807 m
.02732 .24807 L
s
.02357 .28141 m
.02732 .28141 L
s
.02357 .29807 m
.02732 .29807 L
s
.02357 .31474 m
.02732 .31474 L
s
.02357 .33141 m
.02732 .33141 L
s
.02357 .36475 m
.02732 .36475 L
s
.02357 .38141 m
.02732 .38141 L
s
.02357 .39808 m
.02732 .39808 L
s
.02357 .41475 m
.02732 .41475 L
s
.02357 .44809 m
.02732 .44809 L
s
.02357 .46475 m
.02732 .46475 L
s
.02357 .48142 m
.02732 .48142 L
s
.02357 .49809 m
.02732 .49809 L
s
.02357 .53143 m
.02732 .53143 L
s
.02357 .5481 m
.02732 .5481 L
s
.02357 .56476 m
.02732 .56476 L
s
.02357 .58143 m
.02732 .58143 L
s
.02357 .61477 m
.02732 .61477 L
s
.25 Mabswid
.02357 0 m
.02357 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19734 m
.02499 .35575 L
.02605 .35452 L
.02846 .35167 L
.03279 .3464 L
.04262 .33379 L
.06244 .30555 L
.08265 .27251 L
.10458 .23043 L
.12534 .18118 L
.13524 .15188 L
.14008 .13509 L
.14451 .11743 L
.14913 .09506 L
.15126 .08238 L
.15353 .06554 L
.15479 .05312 L
.15594 .03644 L
.15709 .03785 L
.15817 .05322 L
.15944 .0656 L
.1606 .07476 L
.16324 .09149 L
.16802 .11488 L
.17326 .13531 L
.18386 .16816 L
.20337 .21406 L
.22428 .25241 L
.26565 .31092 L
.30549 .35442 L
.34382 .38865 L
.3846 .41917 L
.42387 .44419 L
.46162 .46505 L
.50182 .48447 L
.54051 .50091 L
.58165 .51636 L
.62127 .52958 L
.65938 .54097 L
.69994 .55188 L
.73899 .56136 L
.78049 .57046 L
.82047 .57841 L
.85893 .58538 L
.89985 .59217 L
.93926 .59815 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o001Ao`@0?Ol2043o00<0ool0??l300[o001Ao`030?oo03go00@0ool0
?ol00`3oo`0oo`030?oo00Oo001Bo`030?oo03oo00<0ool0>_l5043o00<0ool01ol005?o00<0ool0
??l203go00@0ool0?_l300[o001Do`030?oo03go00<0ool0>ol00`3o000no`030?oo00[o000Bo`03
0?oo03co00@0ool0??l0103oo`0no`80?_l00`3oo`0:o`004_l00`3oo`0mo`80?_l2043o00<0ool0
??l400Wo000Bo`030?oo0?oo3?l001;o00<0ool0ool<o`002ooo01<00ol001;o00<0ool02_l00`3o
o`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02Ol00`3oo`0:o`030?oo00[o
00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3o
o`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00So000Bo`030?oo03ko00<0ool0?Ol00`3o
o`0no`030?oo03ko00<0ool02?l001;o00<0ool0ool<o`004_l00`3oo`3oo`co000Bo`80ool=o`00
4_l00`3oo`0Qo`030?oo0>Oo000Bo`030?oo027o00<0ool0iol001;o00<0ool08Ol00`3oo`3Wo`00
4_l2027o0P3Yo`004_l00`3oo`0Po`80jOl001;o00<0ool08?l20>Wo000Bo`030?oo023o00<0o`00
j?l001;o00<0ool08?l00`3o003Xo`004_l2027o00<0o`00j?l001;o00<0ool08?l00`3o003Xo`00
4_l00`3oo`0Po`030?l00>So000Bo`030?oo01oo00@0ool0j?l001;o0P0Po`040?oo0>So000Bo`03
0?oo01oo00D0oooo003Wo`004_l00`3oo`0Oo`050?ooo`00iol000Wo0`06o`030?oo01oo00D0oooo
003Wo`003?l00`3oo`03o`030?oo01oo00D0oooo003Wo`003?l00`3oo`03o`808?l01@3oool00>Oo
0009o`<01_l00`3oo`0Oo`030?oo00;o00<0ool0i?l000Wo00<0ool01_l00`3oo`0Oo`030?oo00;o
00<0ool0i?l000Wo00<0ool01_l00`3oo`0No`030?oo00?o00<0ool0i?l000Wo1005o`807ol00`3o
o`03o`030?oo0>Co000Bo`030?oo01ko00<0ool00ol00`3oo`3To`004_l00`3oo`0No`030?oo00?o
00<0ool0i?l001;o00<0ool07Ol00`3oo`05o`030?oo0>?o000Bo`030?oo01go00<0ool01Ol00`3o
o`3So`004_l201go00<0ool01_l00`3oo`3So`004_l00`3oo`0Lo`030?oo00Ko00<0ool0hol001;o
00<0ool07?l00`3oo`06o`030?oo0>?o000Bo`030?oo01co00<0ool01ol00`3oo`3Ro`004_l201co
00<0ool02?l00`3oo`3Ro`004_l00`3oo`0Ko`030?oo00So00<0ool0h_l001;o00<0ool06ol00`3o
o`09o`030?oo0>7o000Bo`030?oo01[o00<0ool02_l00`3oo`3Qo`004_l00`3oo`0Jo`030?oo00[o
00<0ool0hOl001;o0P0Ko`030?oo00_o00<0ool0h?l001;o00<0ool06Ol00`3oo`0<o`030?oo0>3o
000Bo`030?oo01Wo00<0ool03Ol00`3oo`3Oo`000ol400?o0P06o`030?oo01So00<0ool03_l00`3o
o`3Oo`001Ol01@3oool000;o00<0ool00ol201Wo00<0ool03ol00`3oo`3No`001Ol01@3oool000;o
00<0ool00ol00`3oo`0Ho`030?oo00oo00<0ool0g_l000Go00D0oooo0002o`030?oo00?o00<0ool0
5ol00`3oo`0Ao`030?oo0=go0005o`050?ooo`000_l00`3oo`03o`030?oo01Oo00<0ool04Ol00`3o
o`3Mo`000ol300?o00@0ool01Ol00`3oo`0Go`030?oo01;o00<0ool0g?l000Go00<0ool00_l200Ko
0P0Go`030?oo01?o00<0ool0g?l001;o00<0ool05_l00`3oo`0Do`030?oo0=_o000Bo`030?oo01Ko
00<0ool05?l00`3oo`3Ko`004_l00`3oo`0Eo`030?oo01Ko00<0ool0f_l001;o00<0ool05Ol00`3o
o`0Fo`030?oo0=[o000Bo`805Ol00`3oo`0Go`030?oo0=[o000Bo`030?oo01Co00<0ool06?l00`3o
o`3Io`004_l00`3oo`0Do`030?oo01So00<0ool0fOl001;o00<0ool04ol00`3oo`0Jo`030?oo0=So
000Bo`805?l00`3oo`0Jo`030?oo0=So000Bo`030?oo01;o00<0ool07?l00`3oo`3Go`004_l00`3o
o`0Bo`030?oo01co00<0ool0eol001;o00<0ool04Ol00`3oo`0No`030?oo0=Ko000Bo`030?oo017o
00<0ool07_l00`3oo`3Fo`004_l2017o00<0ool08?l00`3oo`3Eo`004_l00`3oo`0@o`030?oo023o
00<0ool0eOl001;o00<0ool03ol00`3oo`0Ro`030?oo0=Co0003o`@00_l300Ko00<0ool03ol00`3o
o`0So`030?oo0=?o0005o`030?oo00Co00<0ool00ol200oo00<0ool09?l00`3oo`3Co`001Ol00`3o
o`04o`030?oo00?o00<0ool03_l00`3oo`0Uo`030?oo0=;o0005o`040?ooo`<01_l00`3oo`0=o`03
0?oo02Oo00<0ool0dOl000Go00D0oooo0008o`030?oo00co00<0ool0:Ol00`3oo`3@o`000ol300?o
00<0ool01_l00`3oo`0<o`030?oo02Wo00<0ool0d?l000Go00@0oooo1005o`803?l00`3oo`0[o`03
0?oo0<oo000Bo`030?oo00[o00<0ool0;Ol00`3oo`3>o`004_l00`3oo`0:o`030?oo02ko00<0ool0
cOl001;o00<0ool02Ol00`3oo`0_o`030?oo0<go000Bo`802Ol00`3oo`0ao`030?oo0<co000Bo`03
0?oo00So00<0ool0<_l00`3oo`3;o`004_l00`3oo`07o`030?oo03Co00<0ool0b_l001;o00<0ool0
1_l00`3oo`0eo`030?oo0<[o000Bo`030?oo00Ko00<0ool0=_l00`3oo`39o`004_l200Ko00<0ool0
>?l00`3oo`38o`004_l00`3oo`05o`030?oo03Wo00<0ool0aol001;o00<0ool01?l00`3oo`0ko`03
0?oo0<Ko000Bo`030?oo00?o00<0ool0??l00`3oo`36o`004_l200Co00<0ool0?Ol00`3oo`35o`00
4_l00`3oo`02o`030?oo03oo00<0ool0a?l001;o00D0oooo0013o`030?oo0<?o000Bo`040?oo04Go
00<0ool0`_l000?o1003o`801_l00`3o0017o`030?oo0<7o0003o`030?oo00?o00@0ool01Ol304Oo
00<0ool0`Ol000Co00<0ool00_l0103oo`05o`80BOl00`3oo`30o`001Ol01@3oool000;o00<0ool0
0ol00`3oo`19o`030?oo0;oo0006o`040?oo00;o00<0ool00ol00`3oo`1:o`030?oo0;ko0003o`04
0?oo00;o00@0ool01Ol204co0P2no`001?l200Co0P06o`030?oo04go00<0ool0^ol001;o00<0ool0
C_l00`3oo`2jo`004_l00`3oo`1?o`030?oo0;Wo000Bo`030?oo053o00<0ool0^?l001;o0P1Bo`80
^?l001;o00<0ool0Dol00`3oo`2eo`004_l00`3oo`1Do`030?oo0;Co000Bo`030?oo05Go0P2do`00
4_l00`3oo`1Go`030?oo0;7o000Bo`80FOl00`3oo`2`o`004_l00`3oo`1Io`80/?l001;o00<0ool0
Fol00`3oo`2]o`004_l00`3oo`1Lo`030?oo0:co000Bo`80G_l20:co000Bo`030?oo05oo00<0ool0
ZOl001;o00<0ool0H?l20:Wo0003o`@00_l300Ko00<0ool0H_l00`3oo`2Vo`000ol00`3oo`06o`03
0?oo00?o00<0ool0Hol20:Ko0004o`030?oo00Go00<0ool00ol206Ko0P2To`001Ol0103oool300Ko
00<0ool0Iol00`3oo`2Qo`001_l0103oo`08o`030?oo06So0P2Qo`000ol0103oo`02o`030?oo00Ko
00<0ool0J_l00`3oo`2No`001?l200?o1005o`80K?l209ko000Bo`030?oo06go0P2Lo`004_l00`3o
o`1_o`030?oo09Wo000Bo`030?oo073o0P2Io`004_l00`3oo`1bo`80Uol001;o0P1eo`80UOl001;o
00<0ool0M_l209?o000Bo`030?oo07So0P2Ao`004_l00`3oo`1jo`80Sol001;o0P1mo`80SOl001;o
00<0ool0O_l308[o000Bo`030?oo087o0P28o`004_l00`3oo`23o`80Q_l001;o00<0ool0QOl208Co
000Bo`80R?l208;o000Bo`030?oo08Wo0`1oo`004_l00`3oo`2<o`<0O?l000Co0P04o`801_l00`3o
o`2?o`80N_l000?o00@0ool00_l0103oo`05o`80T_l307Oo0006o`040?oo00;o00<0ool00ol00`3o
o`2Do`<0M?l000Co0P03o`040?oo00Go00<0ool0Uol4073o0006o`040?oo00;o00<0ool00ol00`3o
o`2Ko`@0K?l000?o00@0ool00_l0103oo`05o`030?oo09oo0`1Yo`001?l200Co0P06o`80Xol306Ko
000Bo`030?oo0:Go101Ro`004_l00`3oo`2Yo`<0Gol001;o00<0ool0[?l405_o000Bo`80/Ol405Oo
000Bo`030?oo0;Co0`1Do`004_l00`3oo`2go`@0D?l001;o00<0ool0^ol404co000Bo`030?oo0;oo
0`19o`004_l20<?o1015o`004_l00`3oo`36o`@0@Ol001;o00<0ool0b_l403go000Bo`030?oo0<ko
1P0go`004_l00`3oo`3Do`D0<_l001;o0P3Jo`D0;Ol001;o00<0ool0g_l802Go000Bo`030?oo0>Ko
2@0Lo`001?l200?o0`06o`030?oo0>oo1@0Go`000ol0103oo`05o`030?oo00?o0P3eo`L04?l000Ko
00<0ool00ol00`3oo`03o`030?oo0?_o1P0:o`001?l200?o0`06o`030?oo0?oo3?l000Ko00@0ool0
2?l00`3oo`3oo`co0003o`040?oo00;o00<0ool01_l00`3oo`3oo`co0004o`800ol400Go0P3oo`go
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.721845, -2.7298, 0.0153973,
   0.219997}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214583 0.238155 0.0147151 0.000833406 [
[.26173 .00222 -3 -9 ]
[.26173 .00222 3 0 ]
[.49988 .00222 -3 -9 ]
[.49988 .00222 3 0 ]
[.73804 .00222 -3 -9 ]
[.73804 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01107 .09806 -18 -4.5 ]
[.01107 .09806 0 4.5 ]
[.01107 .1814 -18 -4.5 ]
[.01107 .1814 0 4.5 ]
[.01107 .26474 -18 -4.5 ]
[.01107 .26474 0 4.5 ]
[.01107 .34808 -18 -4.5 ]
[.01107 .34808 0 4.5 ]
[.01107 .43142 -18 -4.5 ]
[.01107 .43142 0 4.5 ]
[.01107 .51476 -18 -4.5 ]
[.01107 .51476 0 4.5 ]
[.01107 .5981 -18 -4.5 ]
[.01107 .5981 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26173 .01472 m
.26173 .02097 L
s
[(2)] .26173 .00222 0 1 Mshowa
.49988 .01472 m
.49988 .02097 L
s
[(3)] .49988 .00222 0 1 Mshowa
.73804 .01472 m
.73804 .02097 L
s
[(4)] .73804 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0712 .01472 m
.0712 .01847 L
s
.11883 .01472 m
.11883 .01847 L
s
.16646 .01472 m
.16646 .01847 L
s
.2141 .01472 m
.2141 .01847 L
s
.30936 .01472 m
.30936 .01847 L
s
.35699 .01472 m
.35699 .01847 L
s
.40462 .01472 m
.40462 .01847 L
s
.45225 .01472 m
.45225 .01847 L
s
.54751 .01472 m
.54751 .01847 L
s
.59514 .01472 m
.59514 .01847 L
s
.64277 .01472 m
.64277 .01847 L
s
.6904 .01472 m
.6904 .01847 L
s
.78567 .01472 m
.78567 .01847 L
s
.8333 .01472 m
.8333 .01847 L
s
.88093 .01472 m
.88093 .01847 L
s
.92856 .01472 m
.92856 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02357 .09806 m
.02982 .09806 L
s
[(100)] .01107 .09806 1 0 Mshowa
.02357 .1814 m
.02982 .1814 L
s
[(200)] .01107 .1814 1 0 Mshowa
.02357 .26474 m
.02982 .26474 L
s
[(300)] .01107 .26474 1 0 Mshowa
.02357 .34808 m
.02982 .34808 L
s
[(400)] .01107 .34808 1 0 Mshowa
.02357 .43142 m
.02982 .43142 L
s
[(500)] .01107 .43142 1 0 Mshowa
.02357 .51476 m
.02982 .51476 L
s
[(600)] .01107 .51476 1 0 Mshowa
.02357 .5981 m
.02982 .5981 L
s
[(700)] .01107 .5981 1 0 Mshowa
.125 Mabswid
.02357 .03138 m
.02732 .03138 L
s
.02357 .04805 m
.02732 .04805 L
s
.02357 .06472 m
.02732 .06472 L
s
.02357 .08139 m
.02732 .08139 L
s
.02357 .11472 m
.02732 .11472 L
s
.02357 .13139 m
.02732 .13139 L
s
.02357 .14806 m
.02732 .14806 L
s
.02357 .16473 m
.02732 .16473 L
s
.02357 .19806 m
.02732 .19806 L
s
.02357 .21473 m
.02732 .21473 L
s
.02357 .2314 m
.02732 .2314 L
s
.02357 .24807 m
.02732 .24807 L
s
.02357 .28141 m
.02732 .28141 L
s
.02357 .29807 m
.02732 .29807 L
s
.02357 .31474 m
.02732 .31474 L
s
.02357 .33141 m
.02732 .33141 L
s
.02357 .36475 m
.02732 .36475 L
s
.02357 .38141 m
.02732 .38141 L
s
.02357 .39808 m
.02732 .39808 L
s
.02357 .41475 m
.02732 .41475 L
s
.02357 .44809 m
.02732 .44809 L
s
.02357 .46475 m
.02732 .46475 L
s
.02357 .48142 m
.02732 .48142 L
s
.02357 .49809 m
.02732 .49809 L
s
.02357 .53143 m
.02732 .53143 L
s
.02357 .5481 m
.02732 .5481 L
s
.02357 .56476 m
.02732 .56476 L
s
.02357 .58143 m
.02732 .58143 L
s
.02357 .61477 m
.02732 .61477 L
s
.25 Mabswid
.02357 0 m
.02357 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19734 m
.02499 .35575 L
.02605 .35452 L
.02846 .35167 L
.03279 .3464 L
.04262 .33379 L
.06244 .30555 L
.08265 .27251 L
.10458 .23043 L
.12534 .18118 L
.13524 .15188 L
.14008 .13509 L
.14451 .11743 L
.14913 .09506 L
.15126 .08238 L
.15353 .06554 L
.15479 .05312 L
.15594 .03644 L
.15709 .03785 L
.15817 .05322 L
.15944 .0656 L
.1606 .07476 L
.16324 .09149 L
.16802 .11488 L
.17326 .13531 L
.18386 .16816 L
.20337 .21406 L
.22428 .25241 L
.26565 .31092 L
.30549 .35442 L
.34382 .38865 L
.3846 .41917 L
.42387 .44419 L
.46162 .46505 L
.50182 .48447 L
.54051 .50091 L
.58165 .51636 L
.62127 .52958 L
.65938 .54097 L
.69994 .55188 L
.73899 .56136 L
.78049 .57046 L
.82047 .57841 L
.85893 .58538 L
.89985 .59217 L
.93926 .59815 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o001Do`@0?Ol2043o00<0ool0??l300Oo001Do`030?oo03go
00@0ool0?ol00`3oo`0oo`030?oo00Co001Eo`030?oo03oo00<0ool0>_l5043o00<0ool01?l005Ko
00<0ool0??l203go00@0ool0?_l300Oo000Eo`030?oo03oo00<0ool0?Ol00`3oo`0ko`030?l003ko
00<0ool01ol001Go00<0ool0??l0103oo`0lo`040?oo03ko0P0no`030?oo00Oo000Eo`030?oo03go
0P0no`80@?l00`3oo`0lo`@01_l001Go00<0ool0ool9o`003_oo01<0000Eo`030?oo00[o00<0ool0
2_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`03
0?oo00Wo00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0
2_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`05o`005Ol00`3oo`0no`030?oo03go00<0ool0
?_l00`3oo`0no`030?oo00Go000Eo`030?oo0?oo2Ol001Go00<0ool0ool9o`005Ol20?oo2_l001Go
00<0ool08Ol00`3oo`3To`005Ol00`3oo`0Qo`030?oo0>Co000Eo`030?oo027o00<0ool0i?l001Go
0P0Ro`80iOl001Go00<0ool08Ol20>Go000Eo`030?oo027o0P3Uo`005Ol00`3oo`0Qo`80iOl001Go
00<0ool08?l00`3o003Uo`005Ol2027o00<0o`00iOl001Go00<0ool08?l00`3o003Uo`005Ol00`3o
o`0Po`030?l00>Go000Eo`030?oo023o00<0o`00iOl001Go0P0Qo`030?l00>Go000Eo`030?oo023o
00@0ool0i?l001Go00<0ool08?l0103oo`3To`005Ol00`3oo`0Oo`050?ooo`00i?l00003o`000080
0ol200Co0P05o`030?oo01oo00D0oooo003To`000ol01@3oool000;o00@0ool00_l00`3oo`02o`<0
7ol01@3oool00>Co0003o`050?ooo`000_l0103oo`02o`030?oo00;o00<0ool07ol00`3oo`02o`03
0?oo0>7o0003o`050?ooo`000_l0103oo`02o`030?oo00;o00<0ool07ol00`3oo`02o`030?oo0>7o
0003o`050?ooo`000_l0103oo`02o`030?oo00;o00<0ool07_l00`3oo`03o`030?oo0>7o00001?l0
0003o`040?oo00;o00@0ool01?l201oo00<0ool00ol00`3oo`3Qo`000ol00`3oo`02o`801?l200Go
00<0ool07_l00`3oo`03o`030?oo0>7o000Eo`030?oo01ko00<0ool01?l00`3oo`3Po`005Ol00`3o
o`0No`030?oo00Co00<0ool0h?l001Go00<0ool07Ol00`3oo`05o`030?oo0>3o000Eo`807_l00`3o
o`06o`030?oo0=oo000Eo`030?oo01go00<0ool01_l00`3oo`3Oo`005Ol00`3oo`0Mo`030?oo00Ko
00<0ool0gol001Go00<0ool07?l00`3oo`08o`030?oo0=ko000Eo`807Ol00`3oo`08o`030?oo0=ko
000Eo`030?oo01_o00<0ool02Ol00`3oo`3No`005Ol00`3oo`0Ko`030?oo00[o00<0ool0gOl001Go
00<0ool06ol00`3oo`0:o`030?oo0=go000Eo`030?oo01[o00<0ool02ol00`3oo`3Mo`005Ol201_o
00<0ool03?l00`3oo`3Lo`005Ol00`3oo`0Jo`030?oo00co00<0ool0g?l001Go00<0ool06_l00`3o
o`0<o`030?oo0=co00000ol0000200?o0P04o`801Ol00`3oo`0Io`030?oo00ko00<0ool0fol00003
o`3o00Co00@0ool00_l0103oo`04o`030?oo01Wo00<0ool03_l00`3oo`3Ko`000_l00`3oo`02o`04
0?oo00;o00@0ool01?l301Wo00<0ool03ol00`3oo`3Jo`000ol01@3oool000;o00@0ool00_l00`3o
o`02o`030?oo01So00<0ool04?l00`3oo`3Jo`001?l0103oo`02o`040?oo00;o00<0ool00_l00`3o
o`0Ho`030?oo017o00<0ool0fOl00005o`3oo`000_l0103oo`02o`040?oo00Co00<0ool05ol00`3o
o`0Bo`030?oo0=Wo0002o`801?l200Co0P05o`806?l00`3oo`0Bo`030?oo0=Wo000Eo`030?oo01Ko
00<0ool05?l00`3oo`3Ho`005Ol00`3oo`0Fo`030?oo01Co00<0ool0f?l001Go00<0ool05_l00`3o
o`0Eo`030?oo0=Oo000Eo`030?oo01Go00<0ool05_l00`3oo`3Go`005Ol201Ko00<0ool05_l00`3o
o`3Go`005Ol00`3oo`0Do`030?oo01So00<0ool0e_l001Go00<0ool05?l00`3oo`0Ho`030?oo0=Ko
000Eo`030?oo01?o00<0ool06_l00`3oo`3Eo`005Ol201Co00<0ool06_l00`3oo`3Eo`005Ol00`3o
o`0Bo`030?oo01co00<0ool0e?l001Go00<0ool04_l00`3oo`0Lo`030?oo0=Co000Eo`030?oo017o
00<0ool07_l00`3oo`3Co`005Ol00`3oo`0Ao`030?oo01ko00<0ool0dol001Go0P0Ao`030?oo023o
00<0ool0d_l001Go00<0ool04?l00`3oo`0Po`030?oo0=;o000Eo`030?oo00oo00<0ool08_l00`3o
o`3Ao`000_l200Co0P04o`801Ol00`3oo`0?o`030?oo02?o00<0ool0d?l00005o`3oo`000_l0103o
o`02o`040?oo00Co0`0>o`030?oo02Co00<0ool0d?l000Co00@0ool00_l0103oo`02o`030?oo00;o
00<0ool03_l00`3oo`0Uo`030?oo0<oo0002o`800ol0103oo`02o`040?oo00Co00<0ool03Ol00`3o
o`0Wo`030?oo0<ko0004o`040?oo00;o00@0ool00_l00`3oo`02o`030?oo00co00<0ool0:Ol00`3o
o`3=o`0000Go0?oo0002o`040?oo00;o00@0ool01?l00`3oo`0<o`030?oo02Wo00<0ool0cOl000;o
0P04o`801?l200Go0P0<o`030?oo02_o00<0ool0c?l001Go00<0ool02_l00`3oo`0]o`030?oo0<_o
000Eo`030?oo00[o00<0ool0;_l00`3oo`3:o`005Ol00`3oo`09o`030?oo02oo00<0ool0b_l001Go
0P09o`030?oo037o00<0ool0bOl001Go00<0ool02?l00`3oo`0bo`030?oo0<So000Eo`030?oo00Oo
00<0ool0=?l00`3oo`37o`005Ol00`3oo`06o`030?oo03Go00<0ool0aol001Go00<0ool01_l00`3o
o`0fo`030?oo0<Ko000Eo`801_l00`3oo`0ho`030?oo0<Go000Eo`030?oo00Go00<0ool0>Ol00`3o
o`34o`005Ol00`3oo`04o`030?oo03_o00<0ool0`ol001Go00<0ool00ol00`3oo`0mo`030?oo0<;o
000Eo`801?l00`3oo`0no`030?oo0<7o000Eo`030?oo00;o00<0ool0@?l00`3oo`30o`005Ol01@3o
ool004?o00<0ool0`?l001Go00@0ool0AOl00`3oo`2oo`000ol00`3oo`02o`801?l200Go00<0o`00
Aol00`3oo`2no`000ol01@3oool000;o00@0ool00_l00`3oo`02o`<0B?l00`3oo`2mo`001@02o`04
0?oo00;o00@0ool01?l204[o00<0ool0_?l000040?oo00?o00@0ool00_l0103oo`04o`80Bol00`3o
o`2ko`0000Co0?l00ol0103oo`02o`040?oo00Co00<0ool0Bol00`3oo`2jo`000_l200?o00@0ool0
0_l0103oo`04o`80COl00`3oo`2io`000ol00`3oo`02o`801?l200Go00<0ool0COl00`3oo`2ho`00
5Ol00`3oo`1>o`030?oo0;Oo000Eo`030?oo04oo0P2go`005Ol00`3oo`1Ao`030?oo0;Co000Eo`80
Dol00`3oo`2co`005Ol00`3oo`1Co`030?oo0;;o000Eo`030?oo05Co00<0ool0/Ol001Go00<0ool0
EOl20;7o000Eo`80F?l00`3oo`2^o`005Ol00`3oo`1Ho`030?oo0:go000Eo`030?oo05Wo0P2]o`00
5Ol00`3oo`1Ko`030?oo0:[o000Eo`030?oo05co00<0ool0ZOl001Go0P1No`80ZOl001Go00<0ool0
Gol00`3oo`2Vo`005Ol00`3oo`1Po`80Y_l00004o`0000Co0P04o`801Ol00`3oo`1Ro`030?oo0:?o
0004o`040?oo00;o00@0ool00_l00`3oo`02o`030?oo06?o0P2So`001?l0103oo`02o`040?oo00;o
00<0ool00_l306Go0P2Qo`0000Co00000ol0103oo`02o`040?oo00Co00<0ool0Iol00`3oo`2No`00
00?o0?l01?l0103oo`02o`040?oo00Co00<0ool0J?l209ko00000ol0o`04o`040?oo00;o00@0ool0
1?l00`3oo`1Zo`030?oo09_o00000ol0000200?o0P04o`801Ol206co0P2Ko`005Ol00`3oo`1]o`80
VOl001Go00<0ool0Kol00`3oo`2Fo`005Ol00`3oo`1`o`80U_l001Go00<0ool0L_l209Co000Eo`80
MOl209;o000Eo`030?oo07Ko0P2@o`005Ol00`3oo`1ho`80S_l001Go00<0ool0N_l208co000Eo`80
OOl208[o000Eo`030?oo07ko0`27o`005Ol00`3oo`21o`<0Q?l001Go00<0ool0Q?l208;o000Eo`03
0?oo08Ko0`1oo`005Ol208[o0`1lo`005Ol00`3oo`2<o`80N_l001Go00<0ool0S_l207So0002o`80
1?l200Co0P05o`030?oo093o0P1fo`0000Go0?oo0002o`040?oo00;o00@0ool01?l309;o0P1do`00
00Go0?oo0002o`040?oo00;o00@0ool01?l00`3oo`2Do`<0LOl00004o`0000?o00@0ool00_l0103o
o`04o`030?oo09Oo0`1^o`0000?o0?l01?l0103oo`02o`040?oo00Co00<0ool0V_l406[o00000ol0
o`04o`040?oo00;o00@0ool01?l00`3oo`2No`<0Iol000;o0`03o`801?l200Go0P2Ro`@0Hol001Go
00<0ool0YOl405oo000Eo`030?oo0:Wo0`1Lo`005Ol00`3oo`2/o`@0F?l001Go0P2ao`@0E?l001Go
00<0ool0]?l3057o000Eo`030?oo0;Oo101=o`005Ol00`3oo`2ko`@0BOl001Go00<0ool0_ol404Go
000Eo`80a?l603oo000Eo`030?oo0<Wo100ko`005Ol00`3oo`3=o`@0=ol001Go00<0ool0dOl403?o
000Eo`80e_l602go000Eo`030?oo0=_o200Uo`005Ol00`3oo`3So`H07ol001Go00<0ool0jOl501[o
0002o`030?oo00?o0P04o`801Ol00`3oo`3^o`H05?l000;o00<0ool00_l0103oo`02o`040?oo00Co
0`3do`L03Ol000?o00D0oooo0002o`040?oo00;o00<0ool00_l00`3oo`3ko`H01ol000?o00D0oooo
0002o`040?oo00;o00<0ool00_l00`3oo`3oo`Wo0004o`040?oo00;o00@0ool00_l00`3oo`02o`03
0?oo0?oo2Ol00005o`3oo`000_l0103oo`02o`040?oo00Co0P3oo`[o00000ol0000200?o0P04o`80
1Ol00`3oo`3oo`Wo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.669621, -55.6468, 
  0.0154368, 4.41124}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214583 0.238155 0.0147151 0.00416703 [
[.26173 .00222 -3 -9 ]
[.26173 .00222 3 0 ]
[.49988 .00222 -3 -9 ]
[.49988 .00222 3 0 ]
[.73804 .00222 -3 -9 ]
[.73804 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01107 .09806 -12 -4.5 ]
[.01107 .09806 0 4.5 ]
[.01107 .1814 -12 -4.5 ]
[.01107 .1814 0 4.5 ]
[.01107 .26474 -12 -4.5 ]
[.01107 .26474 0 4.5 ]
[.01107 .34808 -12 -4.5 ]
[.01107 .34808 0 4.5 ]
[.01107 .43142 -18 -4.5 ]
[.01107 .43142 0 4.5 ]
[.01107 .51476 -18 -4.5 ]
[.01107 .51476 0 4.5 ]
[.01107 .5981 -18 -4.5 ]
[.01107 .5981 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26173 .01472 m
.26173 .02097 L
s
[(2)] .26173 .00222 0 1 Mshowa
.49988 .01472 m
.49988 .02097 L
s
[(3)] .49988 .00222 0 1 Mshowa
.73804 .01472 m
.73804 .02097 L
s
[(4)] .73804 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0712 .01472 m
.0712 .01847 L
s
.11883 .01472 m
.11883 .01847 L
s
.16646 .01472 m
.16646 .01847 L
s
.2141 .01472 m
.2141 .01847 L
s
.30936 .01472 m
.30936 .01847 L
s
.35699 .01472 m
.35699 .01847 L
s
.40462 .01472 m
.40462 .01847 L
s
.45225 .01472 m
.45225 .01847 L
s
.54751 .01472 m
.54751 .01847 L
s
.59514 .01472 m
.59514 .01847 L
s
.64277 .01472 m
.64277 .01847 L
s
.6904 .01472 m
.6904 .01847 L
s
.78567 .01472 m
.78567 .01847 L
s
.8333 .01472 m
.8333 .01847 L
s
.88093 .01472 m
.88093 .01847 L
s
.92856 .01472 m
.92856 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02357 .09806 m
.02982 .09806 L
s
[(20)] .01107 .09806 1 0 Mshowa
.02357 .1814 m
.02982 .1814 L
s
[(40)] .01107 .1814 1 0 Mshowa
.02357 .26474 m
.02982 .26474 L
s
[(60)] .01107 .26474 1 0 Mshowa
.02357 .34808 m
.02982 .34808 L
s
[(80)] .01107 .34808 1 0 Mshowa
.02357 .43142 m
.02982 .43142 L
s
[(100)] .01107 .43142 1 0 Mshowa
.02357 .51476 m
.02982 .51476 L
s
[(120)] .01107 .51476 1 0 Mshowa
.02357 .5981 m
.02982 .5981 L
s
[(140)] .01107 .5981 1 0 Mshowa
.125 Mabswid
.02357 .03555 m
.02732 .03555 L
s
.02357 .05639 m
.02732 .05639 L
s
.02357 .07722 m
.02732 .07722 L
s
.02357 .11889 m
.02732 .11889 L
s
.02357 .13973 m
.02732 .13973 L
s
.02357 .16056 m
.02732 .16056 L
s
.02357 .20223 m
.02732 .20223 L
s
.02357 .22307 m
.02732 .22307 L
s
.02357 .2439 m
.02732 .2439 L
s
.02357 .28557 m
.02732 .28557 L
s
.02357 .30641 m
.02732 .30641 L
s
.02357 .32724 m
.02732 .32724 L
s
.02357 .36891 m
.02732 .36891 L
s
.02357 .38975 m
.02732 .38975 L
s
.02357 .41058 m
.02732 .41058 L
s
.02357 .45225 m
.02732 .45225 L
s
.02357 .47309 m
.02732 .47309 L
s
.02357 .49392 m
.02732 .49392 L
s
.02357 .53559 m
.02732 .53559 L
s
.02357 .55643 m
.02732 .55643 L
s
.02357 .57726 m
.02732 .57726 L
s
.25 Mabswid
.02357 0 m
.02357 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19734 m
.02499 .35575 L
.02605 .35452 L
.02846 .35167 L
.03279 .3464 L
.04262 .33379 L
.06244 .30555 L
.08265 .27251 L
.10458 .23043 L
.12534 .18118 L
.13524 .15188 L
.14008 .13509 L
.14451 .11743 L
.14913 .09506 L
.15126 .08238 L
.15353 .06554 L
.15479 .05312 L
.15594 .03644 L
.15709 .03785 L
.15817 .05322 L
.15944 .0656 L
.1606 .07476 L
.16324 .09149 L
.16802 .11488 L
.17326 .13531 L
.18386 .16816 L
.20337 .21406 L
.22428 .25241 L
.26565 .31092 L
.30549 .35442 L
.34382 .38865 L
.3846 .41917 L
.42387 .44419 L
.46162 .46505 L
.50182 .48447 L
.54051 .50091 L
.58165 .51636 L
.62127 .52958 L
.65938 .54097 L
.69994 .55188 L
.73899 .56136 L
.78049 .57046 L
.82047 .57841 L
.85893 .58538 L
.89985 .59217 L
.93926 .59815 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o001Do`@0?Ol2043o00<0ool0??l300Oo001Do`030?oo03go
00@0ool0?ol00`3oo`0oo`030?oo00Co001Eo`030?oo03oo00<0ool0>_l5043o00<0ool01?l005Ko
00<0ool0??l203go00@0ool0?_l300Oo000Eo`030?oo03oo00<0ool0?Ol00`3oo`0ko`030?l003ko
00<0ool01ol001Go00<0ool0??l0103oo`0lo`040?oo03ko0P0no`030?oo00Oo000Eo`030?oo03go
0P0no`80@?l00`3oo`0lo`@01_l001Go00<0ool0ool9o`003_oo01<0000Eo`030?oo00[o00<0ool0
2_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`03
0?oo00Wo00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0
2_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`05o`005Ol00`3oo`0no`030?oo03go00<0ool0
?_l00`3oo`0no`030?oo00Go000Eo`030?oo0?oo2Ol001Go00<0ool0ool9o`005Ol00`3oo`3oo`Wo
000Eo`808_l00`3oo`3To`005Ol00`3oo`0Qo`030?oo0>Co000Eo`030?oo027o00<0ool0i?l001Go
00<0ool08Ol20>Go000Eo`030?oo027o0P3Uo`005Ol00`3oo`0Qo`80iOl001Go0P0Ro`80iOl001Go
00<0ool08?l00`3o003Uo`005Ol00`3oo`0Po`030?l00>Go000Eo`030?oo023o00<0o`00iOl001Go
00<0ool08?l00`3o003Uo`005Ol2027o00<0o`00iOl001Go00<0ool08?l00`3o003Uo`005Ol00`3o
o`0Po`040?oo0>Co000Eo`030?oo023o00@0ool0i?l001Go00<0ool07ol01@3oool00>Co0007o`@0
0ol200Go00<0ool07ol01@3oool00>Co0007o`030?oo00?o00@0ool01?l301oo00D0oooo003To`00
2?l00`3oo`02o`040?oo00Co00<0ool07ol00`3oo`02o`030?oo0>7o0009o`050?ooo`000_l00`3o
o`02o`030?oo01oo00<0ool00_l00`3oo`3Qo`002_l0103oo`02o`030?oo00;o00<0ool07_l00`3o
o`03o`030?oo0>7o0007o`040?oo00;o00@0ool01?l00`3oo`0No`030?oo00?o00<0ool0hOl000So
0P04o`801Ol00`3oo`0No`030?oo00?o00<0ool0hOl001Go0P0Oo`030?oo00Co00<0ool0h?l001Go
00<0ool07_l00`3oo`04o`030?oo0>3o000Eo`030?oo01go00<0ool01Ol00`3oo`3Po`005Ol00`3o
o`0Mo`030?oo00Ko00<0ool0gol001Go00<0ool07Ol00`3oo`06o`030?oo0=oo000Eo`807_l00`3o
o`06o`030?oo0=oo000Eo`030?oo01co00<0ool02?l00`3oo`3No`005Ol00`3oo`0Lo`030?oo00So
00<0ool0g_l001Go00<0ool06ol00`3oo`09o`030?oo0=ko000Eo`030?oo01_o00<0ool02_l00`3o
o`3Mo`005Ol00`3oo`0Ko`030?oo00[o00<0ool0gOl001Go0P0Ko`030?oo00_o00<0ool0gOl001Go
00<0ool06_l00`3oo`0<o`030?oo0=co000Eo`030?oo01[o00<0ool03?l00`3oo`3Lo`005Ol00`3o
o`0Jo`030?oo00co00<0ool0g?l000Wo00<0ool00_l200Go00<0ool06Ol00`3oo`0>o`030?oo0=_o
0009o`050?ooo`000_l00`3oo`02o`030?oo01Wo00<0ool03_l00`3oo`3Ko`001_l500;o00@0ool0
1?l301Wo00<0ool03ol00`3oo`3Jo`001_l0103oo`03o`040?oo00Co00<0ool06?l00`3oo`0@o`03
0?oo0=[o0007o`030?l000?o00@0ool01?l00`3oo`0Ho`030?oo017o00<0ool0fOl000So0P03o`04
0?oo00Co00<0ool05ol00`3oo`0Bo`030?oo0=Wo0009o`030?oo00;o0P05o`030?oo01Oo00<0ool0
4_l00`3oo`3Io`005Ol201Oo00<0ool05?l00`3oo`3Ho`005Ol00`3oo`0Fo`030?oo01Co00<0ool0
f?l001Go00<0ool05_l00`3oo`0Eo`030?oo0=Oo000Eo`030?oo01Go00<0ool05_l00`3oo`3Go`00
5Ol00`3oo`0Eo`030?oo01Ko00<0ool0eol001Go00<0ool05?l00`3oo`0Ho`030?oo0=Ko000Eo`80
5Ol00`3oo`0Ho`030?oo0=Ko000Eo`030?oo01?o00<0ool06_l00`3oo`3Eo`005Ol00`3oo`0Co`03
0?oo01[o00<0ool0eOl001Go00<0ool04_l00`3oo`0Lo`030?oo0=Co000Eo`030?oo01;o00<0ool0
7?l00`3oo`3Do`005Ol00`3oo`0Ao`030?oo01ko00<0ool0dol001Go0P0Bo`030?oo01ko00<0ool0
dol001Go00<0ool04?l00`3oo`0Po`030?oo0=;o000Eo`030?oo013o00<0ool08?l00`3oo`3Bo`00
5Ol00`3oo`0?o`030?oo02;o00<0ool0dOl000So0P04o`801Ol00`3oo`0?o`030?oo02?o00<0ool0
d?l000Oo00@0ool00_l0103oo`04o`<03_l00`3oo`0To`030?oo0=3o0007o`040?oo00;o00@0ool0
1?l00`3oo`0>o`030?oo02Go00<0ool0col000Oo0`03o`040?oo00Co00<0ool03Ol00`3oo`0Wo`03
0?oo0<ko0007o`030?oo00?o00@0ool01?l00`3oo`0<o`030?oo02Wo00<0ool0cOl000Oo00<0ool0
0ol0103oo`04o`030?oo00co00<0ool0:Ol00`3oo`3=o`002?l300?o0P05o`030?oo00_o00<0ool0
:ol00`3oo`3<o`005Ol200_o00<0ool0;Ol00`3oo`3;o`005Ol00`3oo`0:o`030?oo02ko00<0ool0
b_l001Go00<0ool02Ol00`3oo`0_o`030?oo0<[o000Eo`030?oo00So00<0ool0<Ol00`3oo`39o`00
5Ol00`3oo`08o`030?oo03;o00<0ool0b?l001Go00<0ool01ol00`3oo`0do`030?oo0<Oo000Eo`80
1ol00`3oo`0eo`030?oo0<Oo000Eo`030?oo00Ko00<0ool0=_l00`3oo`36o`005Ol00`3oo`05o`03
0?oo03So00<0ool0aOl001Go00<0ool01Ol00`3oo`0io`030?oo0<Co000Eo`030?oo00Co00<0ool0
>ol00`3oo`33o`005Ol200Co00<0ool0?Ol00`3oo`32o`005Ol00`3oo`03o`030?oo03ko00<0ool0
`Ol001Go00<0ool00_l00`3oo`10o`030?oo0<3o000Eo`050?ooo`00@ol00`3oo`30o`005Ol0103o
o`15o`030?oo0;oo0008o`801?l200Go00<0o`00Aol00`3oo`2no`001ol0103oo`02o`040?oo00Co
0`18o`030?oo0;go0007o`040?oo00;o00@0ool01?l204[o00<0ool0_?l000So0P03o`040?oo00Co
0P1;o`030?oo0;_o0007o`040?oo00;o00@0ool01?l00`3oo`1;o`030?oo0;[o0007o`040?oo00;o
00@0ool01?l00`3oo`1<o`030?oo0;Wo0008o`801?l200Go00<0ool0COl00`3oo`2ho`005Ol204oo
00<0ool0]ol001Go00<0ool0Col20;Oo000Eo`030?oo057o00<0ool0]?l001Go00<0ool0D_l00`3o
o`2co`005Ol00`3oo`1Co`030?oo0;;o000Eo`80EOl00`3oo`2ao`005Ol00`3oo`1Eo`80/Ol001Go
00<0ool0Eol00`3oo`2^o`005Ol00`3oo`1Ho`030?oo0:go000Eo`030?oo05Wo0P2]o`005Ol00`3o
o`1Ko`030?oo0:[o000Eo`80GOl00`3oo`2Yo`005Ol00`3oo`1Mo`80ZOl001Go00<0ool0Gol00`3o
o`2Vo`005Ol00`3oo`1Po`80Y_l00003o`0000800ol200Co0P05o`030?oo06;o00<0ool0Xol000?o
00D0oooo0002o`040?oo00;o00<0ool00_l00`3oo`1So`80Xol000?o00D0oooo0002o`040?oo00;o
00<0ool00_l306Go0P2Qo`000ol01@3oool000;o00@0ool00_l00`3oo`02o`030?oo06Oo00<0ool0
W_l000?o00D0oooo0002o`040?oo00;o00<0ool00_l00`3oo`1Xo`80W_l00004o`0000?o00@0ool0
0_l0103oo`04o`030?oo06[o00<0ool0Vol000?o00<0ool00_l200Co0P05o`030?oo06_o0P2Ko`00
5Ol206ko0P2Io`005Ol00`3oo`1_o`030?oo09Ko000Eo`030?oo073o0P2Fo`005Ol00`3oo`1bo`80
U?l001Go00<0ool0M?l209;o000Eo`030?oo07Ko0P2@o`005Ol207Wo0P2>o`005Ol00`3oo`1jo`80
S?l001Go00<0ool0O?l208[o000Eo`030?oo07ko0`27o`005Ol00`3oo`21o`<0Q?l001Go00<0ool0
Q?l208;o000Eo`80Qol307oo000Eo`030?oo08Wo0`1lo`005Ol00`3oo`2<o`80N_l001Go00<0ool0
S_l207So00000ol0000200;o1003o`801Ol00`3oo`2@o`80M_l000?o00D0oooo0005o`040?oo00Co
0`2Bo`80M?l000?o00<0ool00_l00`3oo`02o`040?oo00Co00<0ool0U?l3077o0003o`030?oo00?o
00D0oooo0002o`030?oo00;o00<0ool0Uol306ko0003o`030?oo00Co00@0ool00_l00`3oo`02o`03
0?oo09[o101Zo`0000Co00000ol0103oo`02o`040?oo00Co00<0ool0W_l306Oo0003o`030?oo00;o
0P04o`801Ol00`3oo`2Qo`@0Hol001Go0P2Vo`@0Gol001Go00<0ool0ZOl305co000Eo`030?oo0:co
101Ho`005Ol00`3oo`2`o`@0E?l001Go00<0ool0]?l3057o000Eo`030?oo0;Oo101=o`005Ol20;co
1019o`005Ol00`3oo`2oo`@0AOl001Go00<0ool0`ol603oo000Eo`030?oo0<Wo100ko`005Ol00`3o
o`3=o`@0=ol001Go0P3Bo`@0<ol001Go00<0ool0eOl602go000Eo`030?oo0=_o200Uo`005Ol00`3o
o`3So`H07ol001Go00<0ool0jOl501[o00000ol0000200Co00<0ool00_l200Go00<0ool0k_l601Co
0003o`030?oo00?o00D0oooo0002o`030?oo00;o0`3do`L03Ol000?o00<0ool01@02o`040?oo00Co
00<0ool0nol600Oo0003o`040?oo00;o00D0oooo0002o`030?oo00;o00<0ool0ool9o`000ol01`3o
ool0o`000ol0103oo`04o`030?oo0?oo2Ol00004o`0000Co0P03o`040?oo00Co00<0ool0ool9o`00
0ol00`3oo`03o`030?oo00;o0P05o`030?oo0?oo2Ol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.669621, -11.1294, 
  0.0154368, 0.882249}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(Putdata[pmgabsu5i, "\<mgabsu5i.dat\>"]\), 
    \(Putdata[pmgabsu5a, "\<mgabsu5a.dat\>"]\), 
    \(Putdata[pmgabsu3i, "\<mgabsu3i.dat\>"]\), 
    \(Putdata[pmgabsu3a, "\<mgabsu3a.dat\>"]\)}], "Input"],

Cell[BoxData[{
    \(Putdata[bdbdsu5i, "\<bdbdsu5i.dat\>"]\), 
    \(Putdata[bdbdsu5a, "\<bdbdsu5a.dat\>"]\)}], "Input"],

Cell[BoxData[{
    \(Putdata[bdbdsu3i, "\<bdbdsu3i.dat\>"]\), 
    \(Putdata[bdbdsu3a, "\<bdbdsu3a.dat\>"]\)}], "Input"],

Cell[BoxData[{
    \(Putdata[kksu5i, "\<kksu5i.dat\>"]\), 
    \(Putdata[kksu5a, "\<kksu5a.dat\>"]\)}], "Input"],

Cell[BoxData[{
    \(Putdata[kksu3i, "\<kksu3i.dat\>"]\), 
    \(Putdata[kksu3a, "\<kksu3a.dat\>"]\)}], "Input"],

Cell[BoxData[
    \(\( (*\ \(--\(--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)\ *) \n
     (*\ radiative\ decay\ \ \ *) \n
     (*\ \(--\(--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)\ *) \n
    Clear[ac7e, c7sm, c7psm, c7di, c7pdi, c7mi, c7pmi, brbsg]; \n
    Clear[f1, f2, f3, f4]; \n
    f1[x_] := 
      \((\((3  x^2 - 2  x)\)/\((1 - x)\)^4\ Log[x] + 
          \((8  x^2 + 5  x - 7)\)/\((6 \((1 - x)\)^3)\))\); \n
    f2[x_] := 
      \((\((\(-3\) x^2 + 2  x)\)/\((1 - x)\)^3  Log[x] + 
          \((\(-5\) x^2 + 3  x)\)/\((2 \((1 - x)\)^2)\))\); \n
    f3[x_] := 
      \((\((1 + 4  x - 5  x^2 + 2  x \((2 + x)\) Log[x])\)/
          \((2 \((1 - x)\)^4)\))\); \n
    f4[x_] := 
      \((\((1 - 9  x - 9  x^2 + 17  x^3 - 6  x^2 \((3 + x)\) Log[x])\)/
          \((12 \((1 - x)\)^5)\))\); \nc7sm = 0; \ \ \ 
     (*\ \(-0.305\); \ \ *) \nc7di[mh_, tanb_] := 0; \ \ \ 
     (*\ \((\((\((mt/mh)\)^2)\)/\((12  tanb^2)\) f1[\((mt/mh)\)^2] + 
          1/6  f2[\((mt/mh)\)^2])\); \ \ *) \nc7psm = 0; \nc7pdi = 0; \n
    c7mi[tanb_, mgt_, a_, m_, ac_, dll_, drr_, dlr_, drl_] := 
      \((\n\t\t\((8  Sqrt[2] Pi\ alphas)\)/\((18  gf\ vts\ \((mgt/a)\)^2)\) 
          \((ddrl[m, ac, tanb, drl] mgt/mb\ f3[a^2] + \n\t\t\t\t\t
              \((ddll[m, ac, dll] + ddrr[m, ac, drr] ms/mb)\) f4[a^2]\n
            \t\t\t\t)\)\n\t\t)\); \n
    c7pmi[tanb_, mgt_, a_, m_, ac_, dll_, drr_, dlr_, drl_] := 
      \((\n\t\t\((8  Sqrt[2] Pi\ alphas)\)/\((18  gf\ vts\ \((mgt/a)\)^2)\) 
          \((ddlr[m, ac, tanb, dlr] mgt/mb\ f3[a^2] + \n\t\t\t\t\t
              \((ddll[m, ac, dll] ms/mb + ddrr[m, ac, drr])\) f4[a^2]\n
            \t\t\t\t)\)\n\t\t)\); \n
    ac7e[tanb_, mh_, mgt_, a_, m_, ac_, dll_, drr_, dlr_, drl_] := 
      Sqrt[\((c7sm + c7di[mh, tanb] + 
                c7mi[tanb, mgt, a, m, ac, dll, drr, dlr, drl])\)^2 + \n\t\t\t
          \((c7psm + c7pdi + c7pmi[tanb, mgt, a, m, ac, dll, drr, dlr, drl])
              \)^2]; \nbrbsg[tanb_, mh_, mgt_, a_, m_, ac_, dll_, drr_, dlr_, 
        drl_] := \((\n\t\t\((6\ alpha\ brsl)\)/\((Pi\ f[mcb] k[mcb])\)\n
        \t\t\tAbs[ac7e[tanb, mh, mgt, a, m, ac, dll, drr, dlr, drl]]^2)\); 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pbsgsu5a = 
      Plot[c7mi[35, mgt, 1.6, mgt, mgt, ep^2  Sqrt[5], 0, ep^2  Sqrt[5], 
          ep^4\ Sqrt[5]], {mgt, 200, 2000}]\), 
    \(pbsgsu5i = 
      Plot[c7mi[35, mgt, 1.001, mgt, 0, ep^2\ /Sqrt[5], 0, ep^2/Sqrt[5], 
          ep^4/Sqrt[5]], {mgt, 200, 2000}]\), 
    \(pbsgsu5ap = 
      Plot[c7pmi[35, mgt, 1.6, mgt, mgt, ep^2  Sqrt[5], 0, ep^2  Sqrt[5], 
          ep^4\ Sqrt[5]], {mgt, 200, 2000}]\), 
    \(pbsgsu5ip = 
      Plot[c7pmi[35, mgt, 1.001, mgt, 1, ep^2\ /Sqrt[5], 0, ep^2/Sqrt[5], 
          ep^4/Sqrt[5]], {mgt, 200, 2000}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.0147151 3.4846 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -12 -9 ]
[.5 .00222 12 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .10183 -30 -4.5 ]
[.01131 .10183 0 4.5 ]
[.01131 .18895 -24 -4.5 ]
[.01131 .18895 0 4.5 ]
[.01131 .27606 -30 -4.5 ]
[.01131 .27606 0 4.5 ]
[.01131 .36317 -18 -4.5 ]
[.01131 .36317 0 4.5 ]
[.01131 .45029 -30 -4.5 ]
[.01131 .45029 0 4.5 ]
[.01131 .5374 -24 -4.5 ]
[.01131 .5374 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(500)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1000)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1500)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10183 m
.03006 .10183 L
s
[(0.025)] .01131 .10183 1 0 Mshowa
.02381 .18895 m
.03006 .18895 L
s
[(0.05)] .01131 .18895 1 0 Mshowa
.02381 .27606 m
.03006 .27606 L
s
[(0.075)] .01131 .27606 1 0 Mshowa
.02381 .36317 m
.03006 .36317 L
s
[(0.1)] .01131 .36317 1 0 Mshowa
.02381 .45029 m
.03006 .45029 L
s
[(0.125)] .01131 .45029 1 0 Mshowa
.02381 .5374 m
.03006 .5374 L
s
[(0.15)] .01131 .5374 1 0 Mshowa
.125 Mabswid
.02381 .03214 m
.02756 .03214 L
s
.02381 .04956 m
.02756 .04956 L
s
.02381 .06698 m
.02756 .06698 L
s
.02381 .08441 m
.02756 .08441 L
s
.02381 .11925 m
.02756 .11925 L
s
.02381 .13668 m
.02756 .13668 L
s
.02381 .1541 m
.02756 .1541 L
s
.02381 .17152 m
.02756 .17152 L
s
.02381 .20637 m
.02756 .20637 L
s
.02381 .22379 m
.02756 .22379 L
s
.02381 .24121 m
.02756 .24121 L
s
.02381 .25864 m
.02756 .25864 L
s
.02381 .29348 m
.02756 .29348 L
s
.02381 .31091 m
.02756 .31091 L
s
.02381 .32833 m
.02756 .32833 L
s
.02381 .34575 m
.02756 .34575 L
s
.02381 .3806 m
.02756 .3806 L
s
.02381 .39802 m
.02756 .39802 L
s
.02381 .41544 m
.02756 .41544 L
s
.02381 .43287 m
.02756 .43287 L
s
.02381 .46771 m
.02756 .46771 L
s
.02381 .48514 m
.02756 .48514 L
s
.02381 .50256 m
.02756 .50256 L
s
.02381 .51998 m
.02756 .51998 L
s
.02381 .55483 m
.02756 .55483 L
s
.02381 .57225 m
.02756 .57225 L
s
.02381 .58967 m
.02756 .58967 L
s
.02381 .6071 m
.02756 .6071 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .60332 m
.12713 .51348 L
.13597 .4367 L
.15382 .32721 L
.1633 .2855 L
.17345 .24945 L
.19174 .20036 L
.21092 .16369 L
.22904 .13814 L
.24702 .11875 L
.26361 .10462 L
.2819 .09213 L
.29903 .08264 L
.33308 .06828 L
.36798 .05781 L
.40508 .0497 L
.44082 .04387 L
.47519 .03952 L
.51177 .03588 L
.54699 .03308 L
.58441 .03067 L
.62047 .02877 L
.65517 .02724 L
.69207 .02587 L
.72761 .02476 L
.76178 .02383 L
.79816 .02298 L
.83318 .02227 L
.87041 .02161 L
.90627 .02105 L
.94077 .02057 L
.97619 .02014 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o001Eo`<0
1?l200Co0P0[o`@00ol200Co0P04o`809ol400;o0`04o`801?l202So1003o`801?l200Co0P03o`00
F?l0103oo`02o`040?oo00;o00<0ool0:_l01@3oool000;o00@0ool00_l0103oo`02o`030?oo02Ko
00<0ool01?l0103oo`02o`040?oo00;o00<0ool09Ol00`3oo`03o`040?oo00;o00@0ool00_l0103o
o`02o`00F?l0103oo`02o`040?oo00;o00<0ool0:_l01@3oool000;o00@0ool00_l0103oo`02o`03
0?oo02Ko00<0ool01?l0103oo`02o`040?oo00;o00<0ool09_l00`3oo`02o`040?oo00;o00@0ool0
0_l0103oo`02o`00EOl300?o00@0ool00_l0103oo`0/o`050?ooo`000_l0103oo`02o`040?oo00;o
00<0ool09_l0103oool300?o00@0ool00_l0103oo`0Yo`050?ooo`000_l0103oo`02o`040?oo00;o
0@01o`7o001Eo`030?oo00?o00@0ool00_l0103oo`0/o`050?ooo`000_l0103oo`02o`040?oo00;o
00<0ool09_l01@3oool000Go00@0ool00_l0103oo`0Zo`040?oo00;o00@0ool00_l0103oo`02o`40
0Ol1o`008Ol00`3oo`0ao`030?oo00?o00@0ool00_l0103oo`0Zo`<00ol0103oo`02o`040?oo00;o
00@0ool09_l300?o00<0ool00ol0103oo`02o`040?oo02Oo00@0ool00_l0103oo`02o`040?oo00;o
00@0ool00_l0027o00<0ool0<Ol400?o0P04o`80;Ol00`3oo`02o`801?l200Co0P0Yo`040?ooo`@0
0ol200Co0P0Yo`801?l200Co0P04o`800ol0027o00<0ool0o?l0027o00<0ool0o?l001_oo`06o`00
8Ol00`3oo`0io`030?oo03[o00<0ool0>Ol00`3oo`0AobX03?l0027o00<0ool0X_lT03Ko000Qo`03
0?oo093o4P1Jo`008Ol207oo4P1/o`008Ol00`3oo`1do`X0O_l0027o00<0ool0Jol908So000Qo`03
0?oo06;o2@2Ao`008Ol205co1`2Jo`008Ol00`3oo`1Go`@0XOl0027o00<0ool0Dol40:Go000Qo`03
0?oo053o0`2Yo`008Ol00`3oo`1=o`<0[?l0027o0P1;o`<0[ol0027o00<0ool0B?l20;;o000Qo`03
0?oo04Ko0P2do`008Ol00`3oo`14o`80]_l0027o0P13o`80^?l0027o00<0ool0@?l20;[o000Qo`03
0?oo03ko0P2lo`000_l200Co00<0ool00ol200?o1002o`<01Ol00`3oo`0lo`80__l00005o`3oo`00
2?l0103oo`02o`030?oo00Ko00<0ool00_l00`3oo`0ko`030?oo0;ko00001Ol0ool000So00@0ool0
0ol00`3oo`05o`030?oo00;o0P0ko`030?oo0;oo00001Ol0ool000So00@0ool01?l0103oool300Go
00<0ool0>Ol00`3oo`30o`0000Go0?oo0008o`040?oo00Go00@0ool01ol00`3oo`0go`80`ol00005
o`3oo`002?l0103oo`02o`040?oo00;o00<0ool01Ol00`3oo`0fo`030?oo0<?o0002o`802_l200Co
0P03o`@01?l203Ko00<0ool0a?l0027o00<0ool0=?l00`3oo`35o`008Ol00`3oo`0co`030?oo0<Ko
000Qo`030?oo03?o00<0ool0a_l0027o0P0co`030?oo0<Oo000Qo`030?oo037o00<0ool0b?l0027o
00<0ool0<?l00`3oo`39o`008Ol00`3oo`0_o`030?oo0<[o000Qo`030?oo02oo00<0ool0b_l0027o
0P0_o`030?oo0<_o000Qo`030?oo02go00<0ool0c?l0027o00<0ool0;?l00`3oo`3=o`008Ol00`3o
o`0/o`030?oo0<go000Qo`80;?l00`3oo`3>o`008Ol00`3oo`0[o`030?oo0<ko000Qo`030?oo02[o
00<0ool0col000So0P04o`030?oo00?o0P03o`<01Ol00`3oo`0Zo`030?oo0<oo0007o`040?oo00So
00@0ool01Ol00`3oo`02o`030?oo02Wo00<0ool0d?l000Oo00@0ool02?l0103oo`05o`030?oo00;o
0P0Zo`030?oo0=3o0007o`040?oo00So00@0ool00_l300Go00<0ool0:?l00`3oo`3Ao`001ol0103o
o`08o`040?oo00;o00<0ool01Ol00`3oo`0Xo`030?oo0=7o0007o`040?oo00So00@0ool00_l00`3o
o`05o`030?oo02Oo00<0ool0d_l000So0P0:o`800ol400Co0P0Xo`030?oo0=;o000Qo`030?oo02Ko
00<0ool0dol0027o00<0ool09_l00`3oo`3Co`008Ol00`3oo`0Vo`030?oo0=?o000Qo`030?oo02Go
00<0ool0e?l0027o0P0Vo`030?oo0=Co000Qo`030?oo02Go00<0ool0e?l0027o00<0ool09?l00`3o
o`3Eo`008Ol00`3oo`0To`030?oo0=Go000Qo`809Ol00`3oo`3Eo`008Ol00`3oo`0So`030?oo0=Ko
000Qo`030?oo02?o00<0ool0e_l0027o00<0ool08ol00`3oo`3Fo`008Ol202?o00<0ool0eol0027o
00<0ool08_l00`3oo`3Go`008Ol00`3oo`0Ro`030?oo0=Oo000Qo`030?oo027o00<0ool0f?l000;o
0P04o`030?oo00?o0P04o`030?oo00;o0`05o`030?oo027o00<0ool0f?l00005o`3oo`002?l0103o
o`03o`030?oo00Go00<0ool00_l202;o00<0ool0f?l00005o`3oo`002?l0103oo`04o`030?oo00Co
00<0ool00_l00`3oo`0Po`030?oo0=Wo00001Ol0ool000So00@0ool01?l0103oool300Go00<0ool0
8?l00`3oo`3Io`0000Go0?oo0008o`040?oo00Go00@0ool01ol00`3oo`0Po`030?oo0=Wo00001Ol0
ool000So00@0ool00_l0103oo`02o`030?oo00Go0P0Qo`030?oo0=Wo0002o`802_l200?o1002o`@0
1?l00`3oo`0Oo`030?oo0=[o000Qo`030?oo01oo00<0ool0f_l0027o00<0ool07ol00`3oo`3Jo`00
8Ol00`3oo`0Oo`030?oo0=[o000Qo`808?l00`3oo`3Jo`008Ol00`3oo`0Oo`030?oo0=[o000Qo`03
0?oo01ko00<0ool0fol0027o00<0ool07_l00`3oo`3Ko`008Ol201oo00<0ool0fol0027o00<0ool0
7_l00`3oo`3Ko`008Ol00`3oo`0No`030?oo0=_o000Qo`030?oo01go00<0ool0g?l0027o00<0ool0
7Ol00`3oo`3Lo`008Ol201ko00<0ool0g?l0027o00<0ool07Ol00`3oo`3Lo`008Ol00`3oo`0Mo`03
0?oo0=co000>o`801?l00`3oo`02o`@01?l00`3oo`0Mo`030?oo0=co000=o`040?oo00[o00<0ool0
0ol201go00<0ool0gOl000go00@0ool02_l00`3oo`03o`030?oo01co00<0ool0gOl000go00@0ool0
2_l00`3oo`03o`030?oo01co00<0ool0gOl000go00@0ool02_l00`3oo`03o`030?oo01co00<0ool0
gOl000go00@0ool02?l300Go0P0Mo`030?oo0=go000>o`802ol00`3oo`03o`030?oo01co00<0ool0
gOl0027o00<0ool06ol00`3oo`3No`008Ol00`3oo`0Ko`030?oo0=ko000Qo`030?oo01_o00<0ool0
g_l0027o0P0Lo`030?oo0=ko000Qo`030?oo01_o00<0ool0g_l0027o00<0ool06_l00`3oo`3Oo`00
8Ol00`3oo`0Jo`030?oo0=oo000Qo`806ol00`3oo`3Oo`008Ol00`3oo`0Jo`030?oo0=oo000Qo`03
0?oo01[o00<0ool0gol0027o00<0ool06_l00`3oo`3Oo`008Ol00`3oo`0Io`030?oo0>3o000Qo`80
6_l00`3oo`3Po`008Ol00`3oo`0Io`030?oo0>3o000Qo`030?oo01Wo00<0ool0h?l000;o0P04o`03
0?oo00;o1002o`@00_l300Go00<0ool06Ol00`3oo`3Po`0000Go0?oo000:o`050?ooo`002?l00`3o
o`02o`806_l00`3oo`3Po`0000Go0?oo000:o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo01Wo
00<0ool0h?l00005o`3oo`002_l00`3oo`03o`040?ooo`<01Ol00`3oo`0Ho`030?oo0>7o00001Ol0
ool000[o00<0ool01?l0103oo`07o`030?oo01So00<0ool0hOl00005o`3oo`002?l300?o00@0ool0
0_l00`3oo`05o`030?oo01So00<0ool0hOl000;o0P0;o`030?oo00;o0P03o`@01?l201Wo00<0ool0
hOl0027o00<0ool06?l00`3oo`3Qo`008Ol00`3oo`0Ho`030?oo0>7o000Qo`030?oo01So00<0ool0
hOl0027o0P0Io`030?oo0>7o000Qo`030?oo01So00<0ool0hOl0027o00<0ool06?l00`3oo`3Qo`00
8Ol00`3oo`0Go`030?oo0>;o000Qo`806?l00`3oo`3Ro`008Ol00`3oo`0Go`030?oo0>;o000Qo`03
0?oo01Oo00<0ool0h_l0027o00<0ool05ol00`3oo`3Ro`008Ol00`3oo`0Go`030?oo0>;o000Qo`80
6?l00`3oo`3Ro`008Ol00`3oo`0Go`030?oo0>;o000Qo`030?oo01Oo00<0ool0h_l000So0P04o`03
0?oo00;o1002o`<01Ol00`3oo`0Go`030?oo0>;o0007o`040?oo00[o00<0ool01?l00`3oo`02o`80
5ol00`3oo`3So`001ol0103oo`0:o`030?oo00Co00<0ool00_l00`3oo`0Fo`030?oo0>?o0007o`04
0?oo00[o00@0oooo0`05o`030?oo01Ko00<0ool0hol000Oo00@0ool02_l01@3oool000Oo00<0ool0
5_l00`3oo`3So`001ol0103oo`08o`<00ol00`3oo`05o`030?oo01Ko00<0ool0hol000So0P0;o`04
0?ooo`@01?l201Oo00<0ool0hol0027o00<0ool05_l00`3oo`3So`008Ol00`3oo`0Fo`030?oo0>?o
000Qo`030?oo01Ko00<0ool0hol0027o0P0Go`030?oo0>?o000Qo`030?oo01Ko00<0ool0hol0027o
00<0ool05_l00`3oo`3So`008Ol00`3oo`0Eo`030?oo0>Co000Qo`030?oo01Go00<0ool0i?l0027o
0P0Fo`030?oo0>Co000Qo`030?oo01Go00<0ool0i?l0027o00<0ool05Ol00`3oo`3To`008Ol00`3o
o`0Eo`030?oo0>Co000Qo`80oOl0027o00<0ool0o?l0027o00<0ool0o?l0027o00<0ool0o?l00?oo
8Ol00?oo8Ol00?oo8Ol00?oo8Ol00?oo8Ol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-274.374, -0.0202982, 
  8.27049, 0.00113021}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.0147151 41.3927 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -12 -9 ]
[.5 .00222 12 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .0975 -30 -4.5 ]
[.01131 .0975 0 4.5 ]
[.01131 .18029 -30 -4.5 ]
[.01131 .18029 0 4.5 ]
[.01131 .26307 -30 -4.5 ]
[.01131 .26307 0 4.5 ]
[.01131 .34586 -30 -4.5 ]
[.01131 .34586 0 4.5 ]
[.01131 .42864 -24 -4.5 ]
[.01131 .42864 0 4.5 ]
[.01131 .51143 -30 -4.5 ]
[.01131 .51143 0 4.5 ]
[.01131 .59421 -30 -4.5 ]
[.01131 .59421 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(500)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1000)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1500)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .0975 m
.03006 .0975 L
s
[(0.002)] .01131 .0975 1 0 Mshowa
.02381 .18029 m
.03006 .18029 L
s
[(0.004)] .01131 .18029 1 0 Mshowa
.02381 .26307 m
.03006 .26307 L
s
[(0.006)] .01131 .26307 1 0 Mshowa
.02381 .34586 m
.03006 .34586 L
s
[(0.008)] .01131 .34586 1 0 Mshowa
.02381 .42864 m
.03006 .42864 L
s
[(0.01)] .01131 .42864 1 0 Mshowa
.02381 .51143 m
.03006 .51143 L
s
[(0.012)] .01131 .51143 1 0 Mshowa
.02381 .59421 m
.03006 .59421 L
s
[(0.014)] .01131 .59421 1 0 Mshowa
.125 Mabswid
.02381 .03541 m
.02756 .03541 L
s
.02381 .05611 m
.02756 .05611 L
s
.02381 .0768 m
.02756 .0768 L
s
.02381 .1182 m
.02756 .1182 L
s
.02381 .13889 m
.02756 .13889 L
s
.02381 .15959 m
.02756 .15959 L
s
.02381 .20098 m
.02756 .20098 L
s
.02381 .22168 m
.02756 .22168 L
s
.02381 .24237 m
.02756 .24237 L
s
.02381 .28377 m
.02756 .28377 L
s
.02381 .30446 m
.02756 .30446 L
s
.02381 .32516 m
.02756 .32516 L
s
.02381 .36655 m
.02756 .36655 L
s
.02381 .38725 m
.02756 .38725 L
s
.02381 .40795 m
.02756 .40795 L
s
.02381 .44934 m
.02756 .44934 L
s
.02381 .47003 m
.02756 .47003 L
s
.02381 .49073 m
.02756 .49073 L
s
.02381 .53212 m
.02756 .53212 L
s
.02381 .55282 m
.02756 .55282 L
s
.02381 .57352 m
.02756 .57352 L
s
.02381 .61491 m
.02756 .61491 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .60332 m
.12713 .51348 L
.13597 .4367 L
.15382 .32721 L
.1633 .2855 L
.17345 .24945 L
.19174 .20036 L
.21092 .16369 L
.22904 .13814 L
.24702 .11875 L
.26361 .10462 L
.2819 .09213 L
.29903 .08264 L
.33308 .06828 L
.36798 .05781 L
.40508 .0497 L
.44082 .04387 L
.47519 .03952 L
.51177 .03588 L
.54699 .03308 L
.58441 .03067 L
.62047 .02877 L
.65517 .02724 L
.69207 .02587 L
.72761 .02476 L
.76178 .02383 L
.79816 .02298 L
.83318 .02227 L
.87041 .02161 L
.90627 .02105 L
.94077 .02057 L
.97619 .02014 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o001Eo`<0
1?l200Co0P0[o`@00ol200Co0P04o`809ol400;o0`04o`801?l202So1003o`801?l200Co0P03o`00
F?l0103oo`02o`040?oo00;o00<0ool0:_l01@3oool000;o00@0ool00_l0103oo`02o`030?oo02Ko
00<0ool01?l0103oo`02o`040?oo00;o00<0ool09Ol00`3oo`03o`040?oo00;o00@0ool00_l0103o
o`02o`00F?l0103oo`02o`040?oo00;o00<0ool0:_l01@3oool000;o00@0ool00_l0103oo`02o`03
0?oo02Ko00<0ool01?l0103oo`02o`040?oo00;o00<0ool09_l00`3oo`02o`040?oo00;o00@0ool0
0_l0103oo`02o`00EOl300?o00@0ool00_l0103oo`0/o`050?ooo`000_l0103oo`02o`040?oo00;o
00<0ool09_l0103oool300?o00@0ool00_l0103oo`0Yo`050?ooo`000_l0103oo`02o`040?oo00;o
0@01o`7o001Eo`030?oo00?o00@0ool00_l0103oo`0/o`050?ooo`000_l0103oo`02o`040?oo00;o
00<0ool09_l01@3oool000Go00@0ool00_l0103oo`0Zo`040?oo00;o00@0ool00_l0103oo`02o`40
0Ol1o`008Ol00`3oo`0ao`030?oo00?o00@0ool00_l0103oo`0Zo`<00ol0103oo`02o`040?oo00;o
00@0ool09_l300?o00<0ool00ol0103oo`02o`040?oo02Oo00@0ool00_l0103oo`02o`040?oo00;o
00@0ool00_l0027o00<0ool0<Ol400?o0P04o`80;Ol00`3oo`02o`801?l200Co0P0Yo`040?ooo`@0
0ol200Co0P0Yo`801?l200Co0P04o`800ol0027o00<0ool0o?l0027o00<0ool0o?l001_oo`06o`00
8Ol00`3oo`0io`030?oo03[o00<0ool0>Ol00`3oo`0AobX03?l0027o00<0ool0X_lT03Ko000Qo`03
0?oo093o4P1Jo`008Ol00`3oo`1noa80K?l0027o0P1eo`X0O_l0027o00<0ool0Jol908So000Qo`03
0?oo06;o2@2Ao`008Ol00`3oo`1Ko`L0V_l0027o00<0ool0Eol40:7o000Qo`80E?l40:Go000Qo`03
0?oo053o0`2Yo`008Ol00`3oo`1=o`<0[?l0027o00<0ool0B_l30:oo000Qo`030?oo04So0P2bo`00
8Ol204Oo0P2do`008Ol00`3oo`14o`80]_l0027o00<0ool0@_l20;So000Qo`030?oo043o0P2jo`00
0_l200Co00<0ool00ol200Co0P03o`@01?l00`3oo`0no`80_?l00005o`3oo`002?l0103oo`02o`04
0?oo00;o00<0ool01Ol00`3oo`0lo`80__l00005o`3oo`002?l0103oo`02o`040?oo00?o00<0ool0
1?l203co00<0ool0__l00005o`3oo`002?l0103oo`02o`040?oo00Co00<0ool00ol00`3oo`0jo`03
0?oo0;oo00001Ol0ool000So00@0ool00_l0103oo`05o`030?oo00;o00<0ool0>Ol00`3oo`30o`00
00Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`04o`030?oo03Oo0P33o`000_l200[o0P04o`80
1?l200Go00<0ool0=_l00`3oo`33o`008Ol203Ko00<0ool0a?l0027o00<0ool0=?l00`3oo`35o`00
8Ol00`3oo`0co`030?oo0<Ko000Qo`030?oo03?o00<0ool0a_l0027o00<0ool0<_l00`3oo`37o`00
8Ol203;o00<0ool0b?l0027o00<0ool0<?l00`3oo`39o`008Ol00`3oo`0_o`030?oo0<[o000Qo`03
0?oo02oo00<0ool0b_l0027o00<0ool0;_l00`3oo`3;o`008Ol202ko00<0ool0c?l0027o00<0ool0
;?l00`3oo`3=o`008Ol00`3oo`0/o`030?oo0<go000Qo`030?oo02_o00<0ool0c_l000;o0P04o`03
0?oo00?o0P04o`801Ol00`3oo`03o`030?oo02_o00<0ool0c_l00005o`3oo`002?l0103oo`02o`04
0?oo00Co00<0ool00ol00`3oo`0Zo`030?oo0<oo00001Ol0ool000So00@0ool00_l01@3oo`3o00D0
1?l202_o00<0ool0col00005o`3oo`002?l0103oo`02o`060?oo0?l00_l00`3oo`03o`030?oo02Wo
00<0ool0d?l00005o`3oo`002?l0103oo`02o`040?oo00;o00<0o`001Ol00`3oo`0Yo`030?oo0=3o
00001Ol0ool000So00@0ool00_l0103oo`03o`801Ol00`3oo`0Xo`030?oo0=7o0002o`802_l200Co
0P05o`030?oo00?o00<0ool0:?l00`3oo`3Ao`008Ol202So00<0ool0d_l0027o00<0ool09ol00`3o
o`3Bo`008Ol00`3oo`0Vo`030?oo0=?o000Qo`030?oo02Ko00<0ool0dol0027o00<0ool09_l00`3o
o`3Co`008Ol202Ko00<0ool0e?l0027o00<0ool09Ol00`3oo`3Do`008Ol00`3oo`0Uo`030?oo0=Co
000Qo`030?oo02Co00<0ool0eOl0027o00<0ool09?l00`3oo`3Eo`008Ol202Go00<0ool0eOl0027o
00<0ool08ol00`3oo`3Fo`008Ol00`3oo`0So`030?oo0=Ko000Qo`030?oo02?o00<0ool0e_l000;o
0P04o`030?oo00?o0P04o`801?l200Go00<0ool08_l00`3oo`3Go`0000Go0?oo0008o`040?oo00;o
00@0ool00_l0103oo`04o`030?oo02;o00<0ool0eol00005o`3oo`002?l0103oo`02o`040?oo00;o
00@0ool01?l202?o00<0ool0eol00005o`3oo`002?l0103oo`02o`040?oo00;o0`05o`030?oo027o
00<0ool0f?l00005o`3oo`002?l0103oo`02o`040?oo00;o00<0ool01Ol00`3oo`0Qo`030?oo0=So
00001Ol0ool000So00@0ool00_l0103oo`02o`030?oo00Go00<0ool08Ol00`3oo`3Ho`000_l200[o
0P04o`801?l300Co00<0ool08?l00`3oo`3Io`008Ol2027o00<0ool0fOl0027o00<0ool08?l00`3o
o`3Io`008Ol00`3oo`0Po`030?oo0=Wo000Qo`030?oo01oo00<0ool0f_l0027o00<0ool07ol00`3o
o`3Jo`008Ol2023o00<0ool0f_l0027o00<0ool07ol00`3oo`3Jo`008Ol00`3oo`0Oo`030?oo0=[o
000Qo`030?oo01oo00<0ool0f_l0027o00<0ool07_l00`3oo`3Ko`008Ol201oo00<0ool0fol0027o
00<0ool07_l00`3oo`3Ko`008Ol00`3oo`0No`030?oo0=_o000Qo`030?oo01ko00<0ool0fol000;o
0P04o`030?oo00?o0P04o`801?l200Go00<0ool07Ol00`3oo`3Lo`0000Go0?oo0008o`040?oo00;o
00@0ool00_l0103oo`04o`030?oo01go00<0ool0g?l00005o`3oo`002?l0103oo`02o`040?oo00;o
00@0ool01?l201ko00<0ool0g?l00005o`3oo`002?l0103oo`02o`040?oo00?o0P05o`030?oo01go
00<0ool0g?l00005o`3oo`002?l0103oo`02o`040?oo00;o00@0ool01?l00`3oo`0Mo`030?oo0=co
00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00Co00<0ool07Ol00`3oo`3Lo`000_l200[o
0P04o`801?l200Go00<0ool07?l00`3oo`3Mo`008Ol201go00<0ool0gOl0027o00<0ool07?l00`3o
o`3Mo`008Ol00`3oo`0Lo`030?oo0=go000Qo`030?oo01co00<0ool0gOl0027o00<0ool07?l00`3o
o`3Mo`008Ol201co00<0ool0g_l0027o00<0ool06ol00`3oo`3No`008Ol00`3oo`0Ko`030?oo0=ko
000Qo`030?oo01_o00<0ool0g_l0027o00<0ool06ol00`3oo`3No`008Ol201_o00<0ool0gol0027o
00<0ool06_l00`3oo`3Oo`008Ol00`3oo`0Jo`030?oo0=oo000Qo`030?oo01[o00<0ool0gol000So
0P04o`030?oo00?o0P03o`@01?l00`3oo`0Jo`030?oo0=oo0007o`040?oo00So00@0ool01?l00`3o
o`03o`030?oo01[o00<0ool0gol000Oo00@0ool02?l0103oo`04o`030?oo00?o0P0Jo`030?oo0>3o
0007o`040?oo00So00@0ool01?l00`3oo`03o`030?oo01Wo00<0ool0h?l000Oo00@0ool02?l0103o
o`04o`030?oo00?o00<0ool06Ol00`3oo`3Po`001ol0103oo`08o`040?oo00;o0`05o`030?oo01Wo
00<0ool0h?l000So0P0:o`801Ol00`3oo`03o`030?oo01Wo00<0ool0h?l0027o0P0Jo`030?oo0>3o
000Qo`030?oo01Wo00<0ool0h?l0027o00<0ool06?l00`3oo`3Qo`008Ol00`3oo`0Ho`030?oo0>7o
000Qo`030?oo01So00<0ool0hOl0027o0P0Io`030?oo0>7o000Qo`030?oo01So00<0ool0hOl0027o
00<0ool06?l00`3oo`3Qo`008Ol00`3oo`0Ho`030?oo0>7o000Qo`030?oo01So00<0ool0hOl0027o
0P0Io`030?oo0>7o000Qo`030?oo01So00<0ool0hOl0027o00<0ool05ol00`3oo`3Ro`008Ol00`3o
o`0Go`030?oo0>;o0002o`801?l00`3oo`03o`800ol400;o1004o`030?oo01Oo00<0ool0h_l00005
o`3oo`002?l0103oo`04o`050?ooo`001ol00`3oo`0Go`030?oo0>;o00001Ol0ool000So00@0ool0
1?l00`3oo`02o`030?oo00Co0P0Ho`030?oo0>;o00001Ol0ool000So00@0ool01?l00`3oo`03o`03
0?oo00?o00<0ool05ol00`3oo`3Ro`0000Go0?oo0008o`040?oo00Co00<0ool01?l00`3oo`02o`03
0?oo01Oo00<0ool0h_l00005o`3oo`002?l0103oo`02o`<00ol0103oo`04o`030?oo01Oo00<0ool0
h_l000;o0P0:o`801Ol00`3oo`02o`801Ol00`3oo`0Go`030?oo0>;o000Qo`806?l00`3oo`3Ro`00
8Ol00`3oo`0Fo`030?oo0>?o000Qo`030?oo01Ko00<0ool0hol0027o00<0ool05_l00`3oo`3So`00
8Ol00`3oo`0Fo`030?oo0>?o000Qo`805ol00`3oo`3So`008Ol00`3oo`0Fo`030?oo0>?o000Qo`03
0?oo01Ko00<0ool0hol0027o00<0ool05_l00`3oo`3So`008Ol00`3oo`0Fo`030?oo0>?o000Qo`80
5ol00`3oo`3So`008Ol00`3oo`0Fo`030?oo0>?o000Qo`030?oo01Ko00<0ool0hol0027o00<0ool0
5Ol00`3oo`3To`000_l200Co00<0ool00ol200?o1004o`030?oo00?o00<0ool05Ol00`3oo`3To`00
00Go0?oo0008o`040?oo00Co00<0ool00ol00`3oo`03o`030?oo01Go00<0ool0i?l00005o`3oo`00
2?l0103oo`04o`030?oo00D01?l201Ko00<0ool0i?l00005o`3oo`002?l0103oo`04o`040?oo00;o
00<0ool00ol00`3oo`0Eo`030?oo0>Co00001Ol0ool000So00@0ool01?l01`3oool0o`001Ol00`3o
o`0Eo`030?oo0>Co00001Ol0ool000So00@0ool00_l300Co0P05o`030?oo0?co0002o`802_l200Go
00<0ool00ol00`3oo`03o`030?oo0?co000Qo`80oOl0027o00<0ool0o?l00?oo8Ol00?oo8Ol00?oo
8Ol00?oo8Ol00?oo8Ol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-274.374, -0.00170879, 
  8.27049, 9.51454*^-5}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.0147151 2.13659 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -12 -9 ]
[.5 .00222 12 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .12154 -24 -4.5 ]
[.01131 .12154 0 4.5 ]
[.01131 .22837 -18 -4.5 ]
[.01131 .22837 0 4.5 ]
[.01131 .3352 -24 -4.5 ]
[.01131 .3352 0 4.5 ]
[.01131 .44203 -18 -4.5 ]
[.01131 .44203 0 4.5 ]
[.01131 .54886 -24 -4.5 ]
[.01131 .54886 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(500)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1000)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1500)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12154 m
.03006 .12154 L
s
[(0.05)] .01131 .12154 1 0 Mshowa
.02381 .22837 m
.03006 .22837 L
s
[(0.1)] .01131 .22837 1 0 Mshowa
.02381 .3352 m
.03006 .3352 L
s
[(0.15)] .01131 .3352 1 0 Mshowa
.02381 .44203 m
.03006 .44203 L
s
[(0.2)] .01131 .44203 1 0 Mshowa
.02381 .54886 m
.03006 .54886 L
s
[(0.25)] .01131 .54886 1 0 Mshowa
.125 Mabswid
.02381 .03608 m
.02756 .03608 L
s
.02381 .05745 m
.02756 .05745 L
s
.02381 .07881 m
.02756 .07881 L
s
.02381 .10018 m
.02756 .10018 L
s
.02381 .14291 m
.02756 .14291 L
s
.02381 .16428 m
.02756 .16428 L
s
.02381 .18564 m
.02756 .18564 L
s
.02381 .20701 m
.02756 .20701 L
s
.02381 .24974 m
.02756 .24974 L
s
.02381 .27111 m
.02756 .27111 L
s
.02381 .29247 m
.02756 .29247 L
s
.02381 .31384 m
.02756 .31384 L
s
.02381 .35657 m
.02756 .35657 L
s
.02381 .37794 m
.02756 .37794 L
s
.02381 .3993 m
.02756 .3993 L
s
.02381 .42067 m
.02756 .42067 L
s
.02381 .4634 m
.02756 .4634 L
s
.02381 .48477 m
.02756 .48477 L
s
.02381 .50613 m
.02756 .50613 L
s
.02381 .5275 m
.02756 .5275 L
s
.02381 .57023 m
.02756 .57023 L
s
.02381 .5916 m
.02756 .5916 L
s
.02381 .61296 m
.02756 .61296 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .60332 m
.12713 .51348 L
.13597 .4367 L
.15382 .32721 L
.1633 .2855 L
.17345 .24945 L
.19174 .20036 L
.21092 .16369 L
.22904 .13814 L
.24702 .11875 L
.26361 .10462 L
.2819 .09213 L
.29903 .08264 L
.33308 .06828 L
.36798 .05781 L
.40508 .0497 L
.44082 .04387 L
.47519 .03952 L
.51177 .03588 L
.54699 .03308 L
.58441 .03067 L
.62047 .02877 L
.65517 .02724 L
.69207 .02587 L
.72761 .02476 L
.76178 .02383 L
.79816 .02298 L
.83318 .02227 L
.87041 .02161 L
.90627 .02105 L
.94077 .02057 L
.97619 .02014 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o001Ao`<01?l200Co0P0/o`@0
0ol200Co0P04o`80:Ol400;o0`04o`801?l202Wo1003o`801?l200Co0P03o`00E?l0103oo`02o`04
0?oo00;o00<0ool0:ol01@3oool000;o00@0ool00_l0103oo`02o`030?oo02So00<0ool01?l0103o
o`02o`040?oo00;o00<0ool09_l00`3oo`03o`040?oo00;o00@0ool00_l0103oo`02o`00E?l0103o
o`02o`040?oo00;o00<0ool0:ol01@3oool000;o00@0ool00_l0103oo`02o`030?oo02So00<0ool0
1?l0103oo`02o`040?oo00;o00<0ool09ol00`3oo`02o`040?oo00;o00@0ool00_l0103oo`02o`00
DOl300?o00@0ool00_l0103oo`0]o`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool0:?l0103o
ool300?o00@0ool00_l0103oo`0Zo`050?ooo`000_l0103oo`02o`040?oo00;o0@01o`7o001Ao`03
0?oo00?o00@0ool00_l0103oo`0]o`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool0:?l01@3o
ool000Go00@0ool00_l0103oo`0[o`040?oo00;o00@0ool00_l0103oo`02o`400Ol1o`006ol00`3o
o`0co`030?oo00?o00@0ool00_l0103oo`0[o`<00ol0103oo`02o`040?oo00;o00@0ool0:?l300?o
00<0ool00ol0103oo`02o`040?oo02So00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l001_o
00<0ool0<ol400?o0P04o`80;_l00`3oo`02o`801?l200Co0P0[o`040?ooo`@00ol200Co0P0Zo`80
1?l200Co0P04o`800ol001_o00<0ool0ool3o`006ol00`3oo`3oo`?o000Eool01P06o`006ol00`3o
o`09o`030?oo00[o00<0ool02Ol00`3oo`09o`030?oo00[o00<0ool02Ol00`3oo`09o`030?oo00[o
00<0ool02Ol00`3oo`0:o`030?oo00Wo00<0ool02Ol00`3oo`0:o`030?oo00Wo00<0ool02_l00`3o
o`09o`030?oo00Wo00<0ool00_lR00co000Ko`030?oo0;3o900^o`006ol00`3oo`2Doa`0D_l001_o
00<0ool0POlC06ko000Ko`80N?l:087o000Ko`030?oo06ko2@2;o`006ol00`3oo`1Wo`L0U?l001_o
00<0ool0Hol409_o000Ko`030?oo05ko1@2Oo`006ol00`3oo`1Io`D0Y?l001_o0P1Fo`@0ZOl001_o
00<0ool0D_l30:go000Ko`030?oo04oo0`2`o`006ol00`3oo`1<o`<0/ol001_o00<0ool0BOl30;Ko
000Ko`80Aol30;Wo000Ko`030?oo04Co0P2lo`006ol00`3oo`12o`80__l001_o00<0ool0@Ol00`3o
o`2no`006ol00`3oo`10o`030?oo0;oo000Ko`030?oo03ko0P32o`006ol203go0P34o`006ol00`3o
o`0ko`030?oo0<Co000Ko`030?oo03[o00<0ool0aOl001_o00<0ool0>Ol00`3oo`36o`000_l200Co
00<0ool00ol200?o0`05o`030?oo03So00<0ool0aol00005o`3oo`002?l0103oo`05o`030?oo00;o
0P0ho`030?oo0<So00001Ol0ool000So00@0ool01Ol00`3oo`02o`030?oo03Ko00<0ool0bOl00005
o`3oo`002?l0103oo`02o`<01Ol00`3oo`0eo`030?oo0<[o00001Ol0ool000So00@0ool00_l00`3o
o`05o`030?oo03Co00<0ool0bol00005o`3oo`002?l0103oo`02o`030?oo00Go00<0ool0<ol00`3o
o`3<o`000_l200[o0P03o`@01?l00`3oo`0bo`030?oo0<go000Ko`80<_l00`3oo`3>o`006ol00`3o
o`0`o`030?oo0<oo000Ko`030?oo033o00<0ool0col001_o00<0ool0;ol00`3oo`3@o`006ol00`3o
o`0^o`030?oo0=7o000Ko`030?oo02go00<0ool0d_l001_o0P0^o`030?oo0=;o000Ko`030?oo02co
00<0ool0dol001_o00<0ool0;?l00`3oo`3Co`006ol00`3oo`0[o`030?oo0=Co000Ko`030?oo02_o
00<0ool0e?l001_o0P0[o`030?oo0=Go000Ko`030?oo02[o00<0ool0eOl001_o00<0ool0:Ol00`3o
o`3Fo`006ol00`3oo`0Yo`030?oo0=Ko000Ko`030?oo02So00<0ool0eol001_o00<0ool0:?l00`3o
o`3Go`006ol202So00<0ool0f?l001_o00<0ool09ol00`3oo`3Ho`006ol00`3oo`0Wo`030?oo0=So
000Ko`030?oo02Ko00<0ool0fOl000So0P04o`030?oo00;o1004o`030?oo02Ko00<0ool0fOl000Oo
00@0ool02_l00`3oo`03o`809ol00`3oo`3Io`001ol0103oo`0:o`030?oo00?o00<0ool09_l00`3o
o`3Io`001ol0103oo`0:o`030?oo00?o00<0ool09Ol00`3oo`3Jo`001ol0103oo`0:o`030?oo00?o
00<0ool09Ol00`3oo`3Jo`001ol0103oo`08o`<01Ol00`3oo`0Uo`030?oo0=[o0008o`802ol00`3o
o`03o`030?oo02Co00<0ool0fol001_o0P0Uo`030?oo0=_o000Ko`030?oo02Co00<0ool0fol001_o
00<0ool08ol00`3oo`3Lo`006ol00`3oo`0So`030?oo0=co000Ko`030?oo02?o00<0ool0g?l001_o
0P0So`030?oo0=go000Ko`030?oo02;o00<0ool0gOl001_o00<0ool08_l00`3oo`3Mo`006ol00`3o
o`0Qo`030?oo0=ko000Ko`030?oo027o00<0ool0g_l001_o00<0ool08Ol00`3oo`3No`006ol202;o
00<0ool0g_l001_o00<0ool08?l00`3oo`3Oo`006ol00`3oo`0Po`030?oo0=oo000Ko`030?oo023o
00<0ool0gol001_o00<0ool08?l00`3oo`3Oo`006ol2027o00<0ool0gol001_o00<0ool08?l00`3o
o`3Oo`006ol00`3oo`0Oo`030?oo0>3o000Ko`030?oo01oo00<0ool0h?l001_o00<0ool07ol00`3o
o`3Po`000_l200Co00<0ool00_l400;o0`05o`030?oo01oo00<0ool0h?l00005o`3oo`002_l00`3o
o`04o`030?oo00;o0P0Po`030?oo0>3o00001Ol0ool000[o00<0ool01?l00`3oo`02o`030?oo01ko
00<0ool0hOl00005o`3oo`002_l0103oool300Go00<0ool07_l00`3oo`3Qo`0000Go0?oo000:o`05
0?ooo`001ol00`3oo`0No`030?oo0>7o00001Ol0ool000So0`03o`030?oo00Go00<0ool07_l00`3o
o`3Qo`000_l200_o00@0oooo1004o`030?oo01ko00<0ool0hOl001_o0P0Oo`030?oo0>7o000Ko`03
0?oo01go00<0ool0h_l001_o00<0ool07Ol00`3oo`3Ro`006ol00`3oo`0Mo`030?oo0>;o000Ko`03
0?oo01go00<0ool0h_l001_o0P0No`030?oo0>;o000Ko`030?oo01go00<0ool0h_l001_o00<0ool0
7?l00`3oo`3So`006ol00`3oo`0Lo`030?oo0>?o000Ko`030?oo01co00<0ool0hol001_o00<0ool0
7?l00`3oo`3So`006ol201go00<0ool0hol001_o00<0ool06ol00`3oo`3To`006ol00`3oo`0Ko`03
0?oo0>Co000Ko`030?oo01_o00<0ool0i?l001_o00<0ool06ol00`3oo`3To`006ol201co00<0ool0
i?l001_o00<0ool06ol00`3oo`3To`006ol00`3oo`0Jo`030?oo0>Go000Ko`030?oo01[o00<0ool0
iOl001_o00<0ool06_l00`3oo`3Uo`002?l200Co00<0ool00_l400Co00<0ool06_l00`3oo`3Uo`00
1ol0103oo`08o`030?oo00Go0P0Ko`030?oo0>Go0007o`040?oo00Wo00<0ool01?l00`3oo`0Jo`03
0?oo0>Go0007o`040?oo00[o00<0ool00ol00`3oo`0Jo`030?oo0>Go0007o`040?oo00_o00<0ool0
0_l00`3oo`0Jo`030?oo0>Go0007o`040?oo00So00@0ool01?l00`3oo`0Io`030?oo0>Ko0008o`80
2_l200Go0P0Jo`030?oo0>Ko000Ko`030?oo01Wo00<0ool0i_l001_o00<0ool06Ol00`3oo`3Vo`00
6ol00`3oo`0Io`030?oo0>Ko000Ko`030?oo01Wo00<0ool0i_l001_o00<0ool06Ol00`3oo`3Vo`00
6ol201[o00<0ool0i_l001_o00<0ool06Ol00`3oo`3Vo`006ol00`3oo`0Io`030?oo0>Ko000Ko`03
0?oo01So00<0ool0iol001_o00<0ool06?l00`3oo`3Wo`006ol00`3oo`0Ho`030?oo0>Oo000Ko`80
6Ol00`3oo`3Wo`006ol00`3oo`0Ho`030?oo0>Oo000Ko`030?oo01So00<0ool0iol001_o00<0ool0
6?l00`3oo`3Wo`006ol00`3oo`0Ho`030?oo0>Oo000Ko`806Ol00`3oo`3Wo`006ol00`3oo`0Ho`03
0?oo0>Oo000Ko`030?oo01So00<0ool0iol001_o00<0ool05ol00`3oo`3Xo`000_l200Co00<0ool0
0_l400;o0`05o`030?oo01Oo00<0ool0j?l00005o`3oo`002?l00`3oo`06o`030?oo00;o00<0ool0
5ol00`3oo`3Xo`0000Go0?oo0009o`030?oo00Go00<0ool00_l201So00<0ool0j?l00005o`3oo`00
2_l0103oool300Go00<0ool05ol00`3oo`3Xo`0000Go0?oo000;o`040?oo00Oo00<0ool05ol00`3o
o`3Xo`0000Go0?oo0008o`040?oo00;o00<0ool01Ol00`3oo`0Go`030?oo0>So0002o`802_l200?o
1004o`030?oo01Oo00<0ool0j?l001_o0P0Ho`030?oo0>So000Ko`030?oo01Oo00<0ool0j?l001_o
00<0ool05ol00`3oo`3Xo`006ol00`3oo`0Go`030?oo0>So000Ko`030?oo01Ko00<0ool0jOl001_o
00<0ool05_l00`3oo`3Yo`006ol201Oo00<0ool0jOl001_o00<0ool05_l00`3oo`3Yo`006ol00`3o
o`0Fo`030?oo0>Wo000Ko`030?oo01Ko00<0ool0jOl001_o00<0ool0ool3o`006ol20?oo1?l001_o
00<0ool0ool3o`006ol00`3oo`3oo`?o003oob7o003oob7o003oob7o0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-220.006, -0.0290083, 
  8.07279, 0.00179921}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00047619 0.0147151 3571.75 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -12 -9 ]
[.5 .00222 12 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .10401 -48 -4.5 ]
[.01131 .10401 0 4.5 ]
[.01131 .1933 -42 -4.5 ]
[.01131 .1933 0 4.5 ]
[.01131 .2826 -48 -4.5 ]
[.01131 .2826 0 4.5 ]
[.01131 .37189 -36 -4.5 ]
[.01131 .37189 0 4.5 ]
[.01131 .46118 -48 -4.5 ]
[.01131 .46118 0 4.5 ]
[.01131 .55048 -42 -4.5 ]
[.01131 .55048 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(500)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1000)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1500)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10401 m
.03006 .10401 L
s
[(0.000025)] .01131 .10401 1 0 Mshowa
.02381 .1933 m
.03006 .1933 L
s
[(0.00005)] .01131 .1933 1 0 Mshowa
.02381 .2826 m
.03006 .2826 L
s
[(0.000075)] .01131 .2826 1 0 Mshowa
.02381 .37189 m
.03006 .37189 L
s
[(0.0001)] .01131 .37189 1 0 Mshowa
.02381 .46118 m
.03006 .46118 L
s
[(0.000125)] .01131 .46118 1 0 Mshowa
.02381 .55048 m
.03006 .55048 L
s
[(0.00015)] .01131 .55048 1 0 Mshowa
.125 Mabswid
.02381 .03257 m
.02756 .03257 L
s
.02381 .05043 m
.02756 .05043 L
s
.02381 .06829 m
.02756 .06829 L
s
.02381 .08615 m
.02756 .08615 L
s
.02381 .12187 m
.02756 .12187 L
s
.02381 .13973 m
.02756 .13973 L
s
.02381 .15759 m
.02756 .15759 L
s
.02381 .17544 m
.02756 .17544 L
s
.02381 .21116 m
.02756 .21116 L
s
.02381 .22902 m
.02756 .22902 L
s
.02381 .24688 m
.02756 .24688 L
s
.02381 .26474 m
.02756 .26474 L
s
.02381 .30046 m
.02756 .30046 L
s
.02381 .31831 m
.02756 .31831 L
s
.02381 .33617 m
.02756 .33617 L
s
.02381 .35403 m
.02756 .35403 L
s
.02381 .38975 m
.02756 .38975 L
s
.02381 .40761 m
.02756 .40761 L
s
.02381 .42547 m
.02756 .42547 L
s
.02381 .44332 m
.02756 .44332 L
s
.02381 .47904 m
.02756 .47904 L
s
.02381 .4969 m
.02756 .4969 L
s
.02381 .51476 m
.02756 .51476 L
s
.02381 .53262 m
.02756 .53262 L
s
.02381 .56834 m
.02756 .56834 L
s
.02381 .58619 m
.02756 .58619 L
s
.02381 .60405 m
.02756 .60405 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.13307 .61803 m
.13597 .56673 L
.14521 .44887 L
.15382 .3674 L
.16341 .29887 L
.17214 .2511 L
.18222 .20836 L
.19174 .17692 L
.20047 .1538 L
.20972 .13384 L
.22631 .10661 L
.24389 .08609 L
.26037 .07205 L
.27859 .06049 L
.29526 .05248 L
.31235 .04609 L
.331 .04066 L
.35018 .0363 L
.36758 .03315 L
.4028 .02843 L
.42012 .02669 L
.43885 .02512 L
.47576 .02275 L
.5113 .0211 L
.54547 .01991 L
.58185 .01895 L
.61687 .01824 L
.6541 .01764 L
.68996 .01719 L
.72445 .01684 L
.76116 .01653 L
.7965 .01629 L
.83047 .0161 L
.86666 .01593 L
.90147 .01579 L
.9385 .01566 L
.97416 .01556 L
.97619 .01555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10@40000100010P<41@H720T:2``=
3Pl@4A8C51DF5aPI6Q/L7AhO824R8b@U9RLX:BX[;2d^;c0a<S<d=CHg>3Tj>c`m?Sm0@D93A4E6AdQ9
BT]<CDi?D55BDeAEEUMHFEYKG5eNGf1QHV=TIFIWJ6UZJfa]KVm`LG9cM7EfMgQiNW]lOGioP862PhB5
QXN8RHZ;S8f>Si2ATY>DUIJGV9VJVibMWYnPXJ:SY:FVYjRYZZ^/[Jj_/;6b/kBe][Nh^KZk_;fn_l31
`/?4aLK7b<W:blc=c/o@dM;Ce=GFemSIf]_LgMkOh>7RhnCUi^OXjN[[k>g^ko3al_?dmOKgn?Wjnocm
o_ooob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o
003oob7o003oob7o003oob7o003oob7o003oob7o001Ro`<01?l200Co0P0Vo`@00ol200Co0P04o`80
8ol400;o0`04o`801?l202Co1003o`801?l200Co0P03o`00IOl0103oo`02o`040?oo00;o00<0ool0
9Ol01@3oool000;o00@0ool00_l0103oo`02o`030?oo02;o00<0ool01?l0103oo`02o`040?oo00;o
00<0ool08Ol00`3oo`03o`040?oo00;o00@0ool00_l0103oo`02o`00IOl0103oo`02o`040?oo00;o
00<0ool09Ol01@3oool000;o00@0ool00_l0103oo`02o`030?oo02;o00<0ool01?l0103oo`02o`04
0?oo00;o00<0ool08_l00`3oo`02o`040?oo00;o00@0ool00_l0103oo`02o`00H_l300?o00@0ool0
0_l0103oo`0Wo`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool08_l0103oool300?o00@0ool0
0_l0103oo`0Uo`050?ooo`000_l0103oo`02o`040?oo00;o0@01o`7o001Ro`030?oo00?o00@0ool0
0_l0103oo`0Wo`050?ooo`000_l0103oo`02o`040?oo00;o00<0ool08_l01@3oool000Go00@0ool0
0_l0103oo`0Vo`040?oo00;o00@0ool00_l0103oo`02o`400Ol1o`00<_l00`3oo`0]o`030?oo00?o
00@0ool00_l0103oo`0Uo`<00ol0103oo`02o`040?oo00;o00@0ool08_l300?o00<0ool00ol0103o
o`02o`040?oo02?o00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l003;o00<0ool0;Ol400?o
0P04o`80:?l00`3oo`02o`801?l200Co0P0Uo`040?ooo`@00ol200Co0P0Uo`801?l200Co0P04o`80
0ol003;o00<0ool0jol002gok007o`00<_l00`3oo`09o`030?oo00So00<0ool02?l00`3oo`08o`03
0?oo00So00<0ool02Ol00`3oo`08o`030?oo00So00<0ool02?l00`3oo`08o`030?oo00Co<`0:o`03
0?oo00So00<0ool02?l00`3oo`08o`030?oo00Wo00<0ool02_l003;o00<0ool0=Ol00`3oo`0UoaL0
<Ol00`3oo`0fo`030?oo00[o000bo`030?oo05?o2P2>o`00<_l204go1`2Ho`00<_l00`3oo`18o`@0
Wol003;o00<0ool0A?l40:?o000bo`030?oo043o102Wo`00<_l203oo0P2[o`00<_l00`3oo`0lo`80
[Ol003;o00<0ool0>_l20:oo000bo`030?oo03Wo00<0ool0[ol003;o00<0ool0=ol20;;o000bo`80
=ol00`3oo`2bo`00<_l00`3oo`0eo`030?oo0;?o000bo`030?oo03?o0P2fo`00<_l00`3oo`0bo`03
0?oo0;Ko000bo`80<_l00`3oo`2go`00<_l00`3oo`0`o`030?oo0;So000bo`030?oo02oo00<0ool0
^Ol000;o0P04o`030?oo00?o0P04o`801?l200Co0P03o`@00_l300Co00<0ool0;ol00`3oo`2io`00
00Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00;o00<0ool01_l0103oool302ko
00<0ool0^_l00005o`3oo`002?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`03o`030?oo00Go
00D0oooo000_o`030?oo0;_o00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00;o00@0ool0
1?l0103oool300Co00<0ool0;?l00`3oo`2lo`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103o
o`02o`040?oo00Go00@0ool01_l00`3oo`0/o`030?oo0;co00001Ol0ool000So00@0ool00_l0103o
o`02o`040?oo00;o00@0ool00_l0103oo`02o`030?oo00Co0P0/o`030?oo0;go0002o`802_l200Co
0P04o`801?l200Co0P03o`@00ol00`3oo`0Zo`030?oo0;ko000bo`030?oo02[o00<0ool0__l003;o
00<0ool0:Ol00`3oo`2oo`00<_l202[o00<0ool0_ol003;o00<0ool0:?l00`3oo`30o`00<_l00`3o
o`0Xo`030?oo0<3o000bo`030?oo02Oo00<0ool0`Ol003;o00<0ool09ol00`3oo`31o`00<_l202So
00<0ool0`Ol003;o00<0ool09_l00`3oo`32o`00<_l00`3oo`0Vo`030?oo0<;o000bo`030?oo02Go
00<0ool0`ol003;o0P0Vo`030?oo0<?o000bo`030?oo02Go00<0ool0`ol003;o00<0ool09Ol00`3o
o`33o`002?l200Co00<0ool00ol200Co0P04o`801?l200?o0`04o`030?oo02Co00<0ool0a?l000Oo
00@0ool02?l0103oo`02o`040?oo00;o00@0ool00_l0103oo`05o`040?ooo`<09?l00`3oo`34o`00
1ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00Go00D0oooo000Vo`030?oo0<Co
0007o`040?oo00So00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l300Co00<0ool09?l00`3o
o`34o`001ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00;o00<0ool01?l00`3o
o`0So`030?oo0<Go0007o`040?oo00So00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l00`3o
o`04o`809?l00`3oo`35o`002?l200[o0P04o`801?l200Co0P03o`@00ol00`3oo`0So`030?oo0<Go
000bo`030?oo02;o00<0ool0a_l003;o00<0ool08_l00`3oo`36o`00<_l202?o00<0ool0a_l003;o
00<0ool08_l00`3oo`36o`00<_l00`3oo`0Qo`030?oo0<Oo000bo`030?oo027o00<0ool0aol003;o
00<0ool08Ol00`3oo`37o`00<_l2027o00<0ool0b?l003;o00<0ool08?l00`3oo`38o`00<_l00`3o
o`0Po`030?oo0<So000bo`030?oo023o00<0ool0b?l003;o0P0Po`030?oo0<Wo000bo`030?oo01oo
00<0ool0bOl003;o00<0ool07ol00`3oo`39o`000_l200Co00<0ool00ol200Co0P04o`801?l200Co
00<0ool00_l300Co00<0ool07ol00`3oo`39o`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103o
o`02o`040?oo00?o00<0ool01Ol0103oool301oo00<0ool0bOl00005o`3oo`002?l0103oo`02o`04
0?oo00;o00@0ool00_l0103oo`04o`030?oo00Co00D0oooo000Qo`030?oo0<Wo00001Ol0ool000So
00@0ool00_l0103oo`02o`040?oo00;o00@0ool01?l0103oool300Co00<0ool07_l00`3oo`3:o`00
00Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`02o`040?oo00Go00@0ool01_l00`3oo`0No`03
0?oo0<[o00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00;o00@0ool00_l0103oo`02o`03
0?oo00Co0P0Oo`030?oo0<[o0002o`802_l200Co0P04o`801?l200?o1002o`@00ol00`3oo`0No`03
0?oo0<[o000bo`030?oo01ko00<0ool0b_l003;o00<0ool07_l00`3oo`3:o`00<_l201oo00<0ool0
b_l003;o00<0ool07Ol00`3oo`3;o`00<_l00`3oo`0Mo`030?oo0<_o000bo`030?oo01go00<0ool0
bol003;o00<0ool07Ol00`3oo`3;o`00<_l201ko00<0ool0bol003;o00<0ool07Ol00`3oo`3;o`00
<_l00`3oo`0Mo`030?oo0<_o000bo`030?oo01go00<0ool0bol003;o0P0Mo`030?oo0<co000bo`03
0?oo01co00<0ool0c?l003;o00<0ool07?l00`3oo`3<o`003_l200Co00<0ool00ol200Co0P04o`80
0ol400?o00<0ool07?l00`3oo`3<o`003Ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`04o`03
0?oo00;o0`0Lo`030?oo0<co000=o`040?oo00So00@0ool00_l0103oo`02o`040?oo00Co00<0ool0
0_l00`3oo`0Lo`030?oo0<co000=o`040?oo00So00@0ool00_l0103oo`02o`040?oo00Co00<0ool0
0_l00`3oo`0Lo`030?oo0<co000=o`040?oo00So00@0ool00_l0103oo`02o`040?oo00Co00<0ool0
0_l00`3oo`0Lo`030?oo0<co000=o`040?oo00So00@0ool00_l0103oo`02o`040?oo00;o0`04o`80
7?l00`3oo`3=o`003_l200[o0P04o`801?l200Go00<0ool00_l00`3oo`0Ko`030?oo0<go000bo`03
0?oo01_o00<0ool0cOl003;o00<0ool06ol00`3oo`3=o`00<_l201co00<0ool0cOl003;o00<0ool0
6ol00`3oo`3=o`00<_l00`3oo`0Ko`030?oo0<go000bo`030?oo01_o00<0ool0cOl003;o00<0ool0
6ol00`3oo`3=o`00<_l201co00<0ool0cOl003;o00<0ool06_l00`3oo`3>o`00<_l00`3oo`0Jo`03
0?oo0<ko000bo`030?oo01[o00<0ool0c_l003;o0P0Ko`030?oo0<ko000bo`030?oo01[o00<0ool0
c_l003;o00<0ool06_l00`3oo`3>o`000_l200Co00<0ool00ol200Co0P04o`800ol400;o1002o`<0
1?l00`3oo`0Jo`030?oo0<ko00001Ol0ool000So00@0ool00_l0103oo`02o`040?oo00Co00D0oooo
0008o`040?ooo`<06_l00`3oo`3>o`0000Go0?oo0008o`040?oo00;o00@0ool00_l0103oo`04o`03
0?oo00;o00<0ool01Ol01@3oool001co00<0ool0c_l00005o`3oo`002?l0103oo`02o`040?oo00;o
00@0ool01?l00`3oo`03o`040?ooo`<01?l00`3oo`0Jo`030?oo0<ko00001Ol0ool000So00@0ool0
0_l0103oo`02o`040?oo00Co00<0ool01?l0103oo`06o`030?oo01[o00<0ool0c_l00005o`3oo`00
2?l0103oo`02o`040?oo00;o00@0ool00_l300?o00@0ool00_l00`3oo`04o`806ol00`3oo`3>o`00
0_l200[o0P04o`801?l200Go00<0ool00_l200?o1003o`030?oo01Wo00<0ool0col003;o00<0ool0
6Ol00`3oo`3?o`00<_l00`3oo`0Io`030?oo0<oo000bo`806_l00`3oo`3?o`00<_l00`3oo`0Io`03
0?oo0<oo000bo`030?oo01Wo00<0ool0col003;o00<0ool06Ol00`3oo`3?o`00<_l00`3oo`0Io`03
0?oo0<oo000bo`806_l00`3oo`3?o`00<_l00`3oo`0Io`030?oo0<oo000bo`030?oo01Wo00<0ool0
col003;o00<0ool06Ol00`3oo`3?o`00<_l201[o00<0ool0col003;o00<0ool06Ol00`3oo`3?o`00
<_l00`3oo`0Ho`030?oo0=3o0008o`801?l00`3oo`03o`801?l200Co0P03o`@00_l300Co00<0ool0
6?l00`3oo`3@o`001ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`04o`030?oo00Co00@0oooo
0`0Ho`030?oo0=3o0007o`040?oo00So00@0ool00_l0103oo`02o`040?oo00Co00<0ool01?l01@3o
ool001[o00<0ool0d?l000Oo00@0ool02?l0103oo`02o`040?oo00;o00@0ool01?l0103oool300Co
00<0ool06?l00`3oo`3@o`001ol0103oo`08o`040?oo00;o00@0ool00_l0103oo`04o`050?ooo`00
1_l00`3oo`0Ho`030?oo0=3o0007o`040?oo00So00@0ool00_l0103oo`02o`040?oo00;o0`03o`03
0?oo00Co0P0Io`030?oo0=3o0008o`802_l200Co0P04o`801Ol0103oool400?o00<0ool06?l00`3o
o`3@o`00<_l00`3oo`0Ho`030?oo0=3o000bo`030?oo01So00<0ool0d?l003;o0P0Io`030?oo0=3o
000bo`030?oo01So00<0ool0d?l003;o00<0ool06?l00`3oo`3@o`00<_l00`3oo`0Go`030?oo0=7o
000bo`030?oo01Oo00<0ool0dOl003;o0P0Ho`030?oo0=7o000bo`030?oo01Oo00<0ool0dOl003;o
00<0ool05ol00`3oo`3Ao`00<_l00`3oo`0Go`030?oo0=7o003oob7o003oob7o003oob7o003oob7o
003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o003oob7o0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-454.722, -2.79315*^-5, 
  8.9263, 1.19007*^-6}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(pbsgsu5a = 
      Plot[c7mi[35, mgt, 1.6, mgt, mgt, ep^2  Sqrt[5], 0, ep^2  Sqrt[5], 
          ep^4\ Sqrt[5]], {mgt, 200, 2000}]\), 
    \(pbsgsu5i = 
      Plot[c7mi[35, mgt, 1.001, mgt, 0, ep^2\ /Sqrt[5], 0, ep^2/Sqrt[5], 
          ep^4/Sqrt[5]], {mgt, 200, 2000}]\)}], "Input"],

Cell[BoxData[{
    \(Putdata[pbsgsu5a, "\<c7esu5a.dat\>"]\), 
    \(Putdata[pbsgsu5i, "\<c7esu5i.dat\>"]\), 
    \(Putdata[pbsgsu5ap, "\<c7esu5ap.dat\>"]\), 
    \(Putdata[pbsgsu5ip, "\<c7esu5ip.dat\>"]\)}], "Input"]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{814, 843},
WindowMargins->{{Automatic, 35}, {13, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 963, 16, 331, "Input"],
Cell[2675, 67, 1109, 19, 555, "Input"],
Cell[3787, 88, 511, 10, 107, "Input"],
Cell[4301, 100, 242, 4, 107, "Input"],
Cell[4546, 106, 4633, 82, 683, "Input"],
Cell[9182, 190, 3759, 61, 491, "Input"],

Cell[CellGroupData[{
Cell[12966, 255, 192, 4, 43, "Input"],
Cell[13161, 261, 54, 1, 27, "Output"],
Cell[13218, 264, 54, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13309, 270, 515, 11, 139, "Input"],
Cell[13827, 283, 9920, 311, 186, 3147, 223, "GraphicsData", 
"PostScript", "Graphics"],
Cell[23750, 596, 130, 3, 27, "Output"],
Cell[23883, 601, 9455, 303, 186, 3056, 219, "GraphicsData", 
"PostScript", "Graphics"],
Cell[33341, 906, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33508, 914, 498, 10, 139, "Input"],
Cell[34009, 926, 10511, 353, 186, 3713, 265, "GraphicsData", 
"PostScript", "Graphics"],
Cell[44523, 1281, 130, 3, 27, "Output"],
Cell[44656, 1286, 10530, 337, 186, 3507, 246, "GraphicsData", 
"PostScript", "Graphics"],
Cell[55189, 1625, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55356, 1633, 511, 11, 139, "Input"],
Cell[55870, 1646, 10705, 326, 186, 3230, 229, "GraphicsData", 
"PostScript", "Graphics"],
Cell[66578, 1974, 130, 3, 27, "Output"],
Cell[66711, 1979, 12707, 438, 186, 5280, 342, "GraphicsData", 
"PostScript", "Graphics"],
Cell[79421, 2419, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79588, 2427, 494, 10, 139, "Input"],
Cell[80085, 2439, 11583, 372, 186, 3796, 271, "GraphicsData", 
"PostScript", "Graphics"],
Cell[91671, 2813, 130, 3, 27, "Output"],
Cell[91804, 2818, 11131, 345, 186, 3474, 246, "GraphicsData", 
"PostScript", "Graphics"],
Cell[102938, 3165, 130, 3, 27, "Output"]
}, Open  ]],
Cell[103083, 3171, 1030, 18, 219, "Input"],
Cell[104116, 3191, 973, 16, 155, "Input"],

Cell[CellGroupData[{
Cell[105114, 3211, 580, 12, 107, "Input"],
Cell[105697, 3225, 11147, 387, 186, 4192, 297, "GraphicsData", 
"PostScript", "Graphics"],
Cell[116847, 3614, 130, 3, 27, "Output"],
Cell[116980, 3619, 10829, 384, 186, 4185, 297, "GraphicsData", 
"PostScript", "Graphics"],
Cell[127812, 4005, 130, 3, 27, "Output"],
Cell[127945, 4010, 11423, 391, 186, 4196, 297, "GraphicsData", 
"PostScript", "Graphics"],
Cell[139371, 4403, 130, 3, 27, "Output"],
Cell[139504, 4408, 10934, 364, 186, 3921, 273, "GraphicsData", 
"PostScript", "Graphics"],
Cell[150441, 4774, 130, 3, 27, "Output"]
}, Open  ]],
Cell[150586, 4780, 220, 4, 75, "Input"],
Cell[150809, 4786, 120, 2, 43, "Input"],
Cell[150932, 4790, 120, 2, 43, "Input"],
Cell[151055, 4794, 112, 2, 43, "Input"],
Cell[151170, 4798, 112, 2, 43, "Input"],
Cell[151285, 4802, 2141, 38, 475, "Input"],

Cell[CellGroupData[{
Cell[153451, 4844, 586, 12, 123, "Input"],
Cell[154040, 4858, 10734, 363, 186, 3808, 273, "GraphicsData", 
"PostScript", "Graphics"],
Cell[164777, 5223, 130, 3, 27, "Output"],
Cell[164910, 5228, 11207, 358, 186, 3728, 261, "GraphicsData", 
"PostScript", "Graphics"],
Cell[176120, 5588, 130, 3, 27, "Output"],
Cell[176253, 5593, 10300, 340, 186, 3516, 252, "GraphicsData", 
"PostScript", "Graphics"],
Cell[186556, 5935, 130, 3, 27, "Output"],
Cell[186689, 5940, 11962, 380, 186, 3880, 276, "GraphicsData", 
"PostScript", "Graphics"],
Cell[198654, 6322, 130, 3, 27, "Output"]
}, Open  ]],
Cell[198799, 6328, 303, 6, 59, "Input"],
Cell[199105, 6336, 216, 4, 75, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

